@@ -6,6 +6,7 @@ import (
 	"crypto/x509"
 	"flag"
 	"fmt"
+	"runtime"
 
 	"io/ioutil"
 	"net/http"
@@ -19,6 +20,7 @@ import (
 	"github.com/openshift/console/pkg/auth"
 	"github.com/openshift/console/pkg/bridge"
 	"github.com/openshift/console/pkg/crypto"
+	"github.com/openshift/console/pkg/helm/chartproxy"
 	"github.com/openshift/console/pkg/proxy"
 	"github.com/openshift/console/pkg/server"
 	"github.com/openshift/console/pkg/serverconfig"
@@ -78,7 +80,7 @@ func main() {
 	fK8sModeOffClusterEndpoint := fs.String("k8s-mode-off-cluster-endpoint", "", "URL of the Kubernetes API server.")
 	fK8sModeOffClusterSkipVerifyTLS := fs.Bool("k8s-mode-off-cluster-skip-verify-tls", false, "DEV ONLY. When true, skip verification of certs presented by k8s API server.")
 	fK8sModeOffClusterPrometheus := fs.String("k8s-mode-off-cluster-prometheus", "", "DEV ONLY. URL of the cluster's Prometheus server.")
-	fK8sModeOffClusterThanos := fs.String("k8s-mode-off-cluster-thanos", "", "DEV ONLY. URL of the cluster's Prometheus server.")
+	fK8sModeOffClusterThanos := fs.String("k8s-mode-off-cluster-thanos", "", "DEV ONLY. URL of the cluster's Thanos server.")
 	fK8sModeOffClusterAlertmanager := fs.String("k8s-mode-off-cluster-alertmanager", "", "DEV ONLY. URL of the cluster's AlertManager server.")
 	fK8sModeOffClusterMetering := fs.String("k8s-mode-off-cluster-metering", "", "DEV ONLY. URL of the cluster's metering server.")
 
@@ -106,8 +108,15 @@ func main() {
 	fStatuspageID := fs.String("statuspage-id", "", "Unique ID assigned by statuspage.io page that provides status info.")
 	fDocumentationBaseURL := fs.String("documentation-base-url", "", "The base URL for documentation links.")
 
+	fAlermanagerPublicURL := fs.String("alermanager-public-url", "", "Public URL of the cluster's AlertManager server.")
+	fGrafanaPublicURL := fs.String("grafana-public-url", "", "Public URL of the cluster's Grafana server.")
+	fPrometheusPublicURL := fs.String("prometheus-public-url", "", "Public URL of the cluster's Prometheus server.")
+	fThanosPublicURL := fs.String("thanos-public-url", "", "Public URL of the cluster's Thanos server.")
+
 	fLoadTestFactor := fs.Int("load-test-factor", 0, "DEV ONLY. The factor used to multiply k8s API list responses for load testing purposes.")
 
+	helmConfig := chartproxy.RegisterFlags(fs)
+
 	if err := fs.Parse(os.Args[1:]); err != nil {
 		fmt.Fprintln(os.Stderr, err.Error())
 		os.Exit(1)
@@ -156,6 +165,23 @@ func main() {
 		documentationBaseURL = bridge.ValidateFlagIsURL("documentation-base-url", *fDocumentationBaseURL)
 	}
 
+	alertManagerPublicURL := &url.URL{}
+	if *fAlermanagerPublicURL != "" {
+		alertManagerPublicURL = bridge.ValidateFlagIsURL("alermanager-public-url", *fAlermanagerPublicURL)
+	}
+	grafanaPublicURL := &url.URL{}
+	if *fGrafanaPublicURL != "" {
+		grafanaPublicURL = bridge.ValidateFlagIsURL("grafana-public-url", *fGrafanaPublicURL)
+	}
+	prometheusPublicURL := &url.URL{}
+	if *fPrometheusPublicURL != "" {
+		prometheusPublicURL = bridge.ValidateFlagIsURL("prometheus-public-url", *fPrometheusPublicURL)
+	}
+	thanosPublicURL := &url.URL{}
+	if *fThanosPublicURL != "" {
+		thanosPublicURL = bridge.ValidateFlagIsURL("thanos-public-url", *fThanosPublicURL)
+	}
+
 	branding := *fBranding
 	if branding == "origin" {
 		branding = "okd"
@@ -178,15 +204,25 @@ func main() {
 	}
 
 	srv := &server.Server{
-		PublicDir:            *fPublicDir,
-		BaseURL:              baseURL,
-		LogoutRedirect:       logoutRedirect,
-		Branding:             branding,
-		CustomProductName:    *fCustomProductName,
-		CustomLogoFile:       *fCustomLogoFile,
-		StatuspageID:         *fStatuspageID,
-		DocumentationBaseURL: documentationBaseURL,
-		LoadTestFactor:       *fLoadTestFactor,
+		PublicDir:             *fPublicDir,
+		BaseURL:               baseURL,
+		LogoutRedirect:        logoutRedirect,
+		Branding:              branding,
+		CustomProductName:     *fCustomProductName,
+		CustomLogoFile:        *fCustomLogoFile,
+		StatuspageID:          *fStatuspageID,
+		DocumentationBaseURL:  documentationBaseURL,
+		AlertManagerPublicURL: alertManagerPublicURL,
+		GrafanaPublicURL:      grafanaPublicURL,
+		PrometheusPublicURL:   prometheusPublicURL,
+		ThanosPublicURL:       thanosPublicURL,
+		LoadTestFactor:        *fLoadTestFactor,
+	}
+
+	// if !in-cluster (dev) we should not pass these values to the frontend
+	if *fK8sMode == "in-cluster" {
+		srv.GOARCH = runtime.GOARCH
+		srv.GOOS = runtime.GOOS
 	}
 
 	if (*fKubectlClientID == "") != (*fKubectlClientSecret == "" && *fKubectlClientSecretFile == "") {
@@ -476,21 +512,43 @@ func main() {
 		bridge.FlagFatalf("user-auth", "must be one of: oidc, disabled")
 	}
 
+	var resourceListerToken string
 	switch *fK8sAuth {
 	case "service-account":
 		bridge.ValidateFlagIs("k8s-mode", *fK8sMode, "in-cluster")
 		srv.StaticUser = &auth.User{
 			Token: k8sAuthServiceAccountBearerToken,
 		}
+		resourceListerToken = k8sAuthServiceAccountBearerToken
 	case "bearer-token":
 		bridge.ValidateFlagNotEmpty("k8s-auth-bearer-token", *fK8sAuthBearerToken)
 		srv.StaticUser = &auth.User{
 			Token: *fK8sAuthBearerToken,
 		}
+		resourceListerToken = *fK8sAuthBearerToken
 	case "oidc", "openshift":
 		bridge.ValidateFlagIs("user-auth", *fUserAuth, "oidc", "openshift")
+		resourceListerToken = k8sAuthServiceAccountBearerToken
 	default:
-		bridge.FlagFatalf("k8s-mode", "must be one of: service-account, bearer-token, oidc")
+		bridge.FlagFatalf("k8s-mode", "must be one of: service-account, bearer-token, oidc, openshift")
+	}
+
+	srv.MonitoringDashboardConfigMapLister = &server.ResourceLister{
+		BearerToken: resourceListerToken,
+		RequestURL: &url.URL{
+			Scheme: k8sEndpoint.Scheme,
+			Host:   k8sEndpoint.Host,
+			Path:   "/api/v1/namespaces/openshift-config-managed/configmaps",
+			RawQuery: url.Values{
+				"labelSelector": {"console.openshift.io/dashboard=true"},
+			}.Encode(),
+		},
+
+		Client: &http.Client{
+			Transport: &http.Transport{
+				TLSClientConfig: srv.K8sProxyConfig.TLSClientConfig,
+			},
+		},
 	}
 
 	listenURL := bridge.ValidateFlagIsURL("listen", *fListen)
@@ -503,9 +561,13 @@ func main() {
 		bridge.FlagFatalf("listen", "scheme must be one of: http, https")
 	}
 
+	helmConfig.Configure(srv)
+
 	httpsrv := &http.Server{
 		Addr:    listenURL.Host,
 		Handler: srv.HTTPHandler(),
+		// Disable HTTP/2, which breaks WebSockets.
+		TLSNextProto: make(map[string]func(*http.Server, *tls.Conn, http.Handler)),
 	}
 
 	log.Infof("Binding to %s...", httpsrv.Addr)
