@@ -1,7 +1,6 @@
 import * as React from 'react';
 import { ShallowWrapper, shallow } from 'enzyme';
 import Spy = jasmine.Spy;
-import { Form } from 'patternfly-react';
 
 import {
   ConnectedStorageClassForm,
@@ -10,9 +9,7 @@ import {
 } from '../../public/components/storage-class-form';
 
 describe(ConnectedStorageClassForm.displayName, () => {
-  const Component: React.ComponentType<
-    StorageClassFormProps
-  > = ConnectedStorageClassForm.WrappedComponent as any;
+  const Component: React.ComponentType<StorageClassFormProps> = ConnectedStorageClassForm.WrappedComponent as any;
   let wrapper: ShallowWrapper<StorageClassFormProps, StorageClassFormState>;
   let onClose: Spy;
   let watchK8sList: Spy;
@@ -40,7 +37,7 @@ describe(ConnectedStorageClassForm.displayName, () => {
   });
 
   it('renders a form', () => {
-    expect(wrapper.find(Form).exists()).toBe(true);
+    expect(wrapper.find('[data-test-id="storage-class-form"]').exists()).toBe(true);
   });
 
   it('renders a dropdown for selecting the reclaim policy', () => {
