@@ -1,11 +1,14 @@
 import { browser, ExpectedConditions as until } from 'protractor';
 
-import { checkLogs, checkErrors, firstElementByTestID } from '../protractor.conf';
+import { checkLogs, checkErrors, firstElementByTestID, appHost } from '../protractor.conf';
+import { dropdownMenuForTestID } from '../views/form.view';
 import * as crudView from '../views/crud.view';
+import * as yamlView from '../views/yaml.view';
 import * as monitoringView from '../views/monitoring.view';
 import * as namespaceView from '../views/namespace.view';
 import * as sidenavView from '../views/sidenav.view';
 import * as horizontalnavView from '../views/horizontal-nav.view';
+import { execSync } from 'child_process';
 
 const testAlertName = 'Watchdog';
 
@@ -46,20 +49,20 @@ describe('Monitoring: Alerts', () => {
     expect(firstElementByTestID('alert-resource-link').getText()).toContain(testAlertName);
     await firstElementByTestID('alert-resource-link').click();
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingAlertIcon));
-    testDetailsPage('Alert Overview', testAlertName);
+    testDetailsPage('Alert Detail', testAlertName);
   });
 
   it('links to the Alerting Rule details page', async () => {
     expect(monitoringView.ruleLink.getText()).toContain(testAlertName);
     await monitoringView.ruleLink.click();
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingRuleIcon));
-    testDetailsPage('Alerting Rule Overview', testAlertName, false);
+    testDetailsPage('Alerting Rule Details', testAlertName, false);
 
     // Active Alerts list should contain a link back to the Alert details page
     await monitoringView.wait(until.elementToBeClickable(monitoringView.firstAlertsListLink));
     await monitoringView.firstAlertsListLink.click();
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingAlertIcon));
-    testDetailsPage('Alert Overview', testAlertName);
+    testDetailsPage('Alert Details', testAlertName);
   });
 
   it('creates a new Silence from an existing alert', async () => {
@@ -70,7 +73,7 @@ describe('Monitoring: Alerts', () => {
 
     // After creating the Silence, should be redirected to its details page
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingSilenceIcon));
-    testDetailsPage('Silence Overview', testAlertName);
+    testDetailsPage('Silence Details', testAlertName);
   });
 
   it('shows the silenced Alert in the Silenced Alerts list', async () => {
@@ -80,7 +83,7 @@ describe('Monitoring: Alerts', () => {
     // Click the link to navigate back to the Alert details link
     await monitoringView.firstAlertsListLink.click();
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingAlertIcon));
-    testDetailsPage('Alert Overview', testAlertName);
+    testDetailsPage('Alert Details', testAlertName);
   });
 
   it('shows the newly created Silence in the Silenced By list', async () => {
@@ -92,7 +95,7 @@ describe('Monitoring: Alerts', () => {
     // Click the link to navigate back to the Silence details page
     await firstElementByTestID('silence-resource-link').click();
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingSilenceIcon));
-    testDetailsPage('Silence Overview', testAlertName);
+    testDetailsPage('Silence Details', testAlertName);
   });
 
   it('expires the Silence', async () => {
@@ -134,7 +137,7 @@ describe('Monitoring: Silences', () => {
   // After creating the Silence, should be redirected to its details page
   it('displays detail view for new Silence', async () => {
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingSilenceIcon));
-    testDetailsPage('Silence Overview', testAlertName);
+    testDetailsPage('Silence Details', testAlertName);
   });
 
   it('filters Silences by name', async () => {
@@ -153,7 +156,7 @@ describe('Monitoring: Silences', () => {
     expect(firstElementByTestID('silence-resource-link').getText()).toContain(testAlertName);
     await firstElementByTestID('silence-resource-link').click();
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingSilenceIcon));
-    testDetailsPage('Silence Overview', testAlertName);
+    testDetailsPage('Silence Details', testAlertName);
   });
 
   it('edits the Silence', async () => {
@@ -165,7 +168,7 @@ describe('Monitoring: Silences', () => {
 
     // After editing the Silence, should be redirected to its details page, where we check that the edit is reflected
     await monitoringView.wait(until.presenceOf(monitoringView.detailsHeadingSilenceIcon));
-    testDetailsPage('Silence Overview', testAlertName);
+    testDetailsPage('Silence Details', testAlertName);
     expect(monitoringView.silenceComment.getText()).toEqual('Test Comment');
   });
 
@@ -199,32 +202,32 @@ describe('Alertmanager: YAML', () => {
     await firstElementByTestID('alertmanager').click();
     await crudView.isLoaded();
     await horizontalnavView.clickHorizontalTab('YAML');
-    await crudView.isLoaded();
-    expect(monitoringView.alertManagerYamlForm.isPresent()).toBe(true);
+    await yamlView.isLoaded();
+    expect(yamlView.yamlEditor.isPresent()).toBe(true);
   });
 
   it('saves Alertmanager YAML', async () => {
     expect(monitoringView.successAlert.isPresent()).toBe(false);
-    await monitoringView.saveButton.click();
-    await crudView.isLoaded();
+    await yamlView.saveButton.click();
+    await yamlView.isLoaded();
     expect(monitoringView.successAlert.isPresent()).toBe(true);
   });
 });
 
 describe('Alertmanager: Configuration', () => {
+  afterAll(() => {
+    execSync(
+      `kubectl patch secret 'alertmanager-main' -n 'openshift-monitoring' --type='json' -p='[{ op: 'replace', path: '/data/alertmanager.yaml', value: ${monitoringView.defaultAlertmanagerYaml}}]'`,
+    );
+  });
+
   afterEach(() => {
     checkLogs();
     checkErrors();
   });
 
-  it('displays the Alermanager Configuration Overview page', async () => {
-    await sidenavView.clickNavLink(['Administration', 'Cluster Settings']);
-    await crudView.isLoaded();
-    await horizontalnavView.clickHorizontalTab('Global Configuration');
-    await crudView.isLoaded();
-    await monitoringView.wait(until.elementToBeClickable(firstElementByTestID('alertmanager')));
-    expect(firstElementByTestID('alertmanager').getText()).toContain('Alertmanager');
-    await firstElementByTestID('alertmanager').click();
+  it('displays the Alermanager Configuration Details page', async () => {
+    await browser.get(`${appHost}/monitoring/alertmanagerconfig`);
     await crudView.isLoaded();
     expect(monitoringView.alertRoutingHeader.getText()).toContain('Alert Routing');
   });
@@ -245,15 +248,14 @@ describe('Alertmanager: Configuration', () => {
 
     await monitoringView.saveButton.click();
     await crudView.isLoaded();
-    expect(firstElementByTestID('group_by_value').getText()).toEqual('job, cluster');
+    expect(firstElementByTestID('group_by_value').getText()).toContain(', cluster');
     expect(firstElementByTestID('group_wait_value').getText()).toEqual('60s');
     expect(firstElementByTestID('group_interval_value').getText()).toEqual('10m');
     expect(firstElementByTestID('repeat_interval_value').getText()).toEqual('24h');
   });
 
-  it('creates PagerDuty Receiver correctly', async () => {
+  it('creates a receiver correctly', async () => {
     await crudView.isLoaded();
-    expect(firstElementByTestID('create-receiver').isPresent()).toBe(true);
     await firstElementByTestID('create-receiver').click();
     await crudView.isLoaded();
 
@@ -262,15 +264,11 @@ describe('Alertmanager: Configuration', () => {
     expect(firstElementByTestID('receiver-routing-labels-editor').isPresent()).toBe(false);
     expect(monitoringView.saveButton.isEnabled()).toBe(false);
 
-    expect(firstElementByTestID('receiver-name').isPresent()).toBe(true);
     await firstElementByTestID('receiver-name').sendKeys('MyReceiver');
-
-    expect(firstElementByTestID('dropdown-button').isDisplayed()).toBe(true);
     await firstElementByTestID('dropdown-button').click();
     await crudView.isLoaded();
 
-    expect(firstElementByTestID('dropdown-menu').isDisplayed()).toBe(true);
-    await firstElementByTestID('dropdown-menu').click();
+    await dropdownMenuForTestID('pagerduty_configs').click();
     await crudView.isLoaded();
 
     // these should be shown after receiverType selected
@@ -280,23 +278,42 @@ describe('Alertmanager: Configuration', () => {
     expect(firstElementByTestID('pagerduty-key-label').getText()).toEqual('Routing Key');
     await firstElementByTestID('integration-type-prometheus').click();
     expect(firstElementByTestID('pagerduty-key-label').getText()).toEqual('Service Key');
+
+    // pagerduty subform should still be invalid at this point, thus save button should be disabled
+    expect(monitoringView.saveButton.isEnabled()).toBe(false);
     await firstElementByTestID('integration-key').sendKeys('<integration_key>');
 
-    expect(monitoringView.saveButton.isEnabled()).toBe(true); // should be enabled at this point
-
+    // labels
+    expect(firstElementByTestID('invalid-label-name-error').isPresent()).toBe(false);
+    await firstElementByTestID('label-name-0').sendKeys('9abcgo'); // invalid, cannot start with digit
+    expect(firstElementByTestID('invalid-label-name-error').isPresent()).toBe(true);
+    await firstElementByTestID('label-name-0').clear();
+    await firstElementByTestID('label-name-0').sendKeys('_abcd'); // valid, can start with and contain '_'
+    expect(firstElementByTestID('invalid-label-name-error').isPresent()).toBe(false);
+    await firstElementByTestID('label-name-0').clear();
+    await firstElementByTestID('label-name-0').sendKeys('abcd@#$R@T%'); // invalid chars
+    expect(firstElementByTestID('invalid-label-name-error').isPresent()).toBe(true);
+    await firstElementByTestID('label-name-0').clear();
+    expect(firstElementByTestID('duplicate-label-name-error').isPresent()).toBe(false);
     await firstElementByTestID('label-name-0').sendKeys('severity');
+    expect(firstElementByTestID('invalid-label-name-error').isPresent()).toBe(false);
     await firstElementByTestID('label-value-0').sendKeys('warning');
+    await firstElementByTestID('add-routing-label').click();
+    await firstElementByTestID('label-name-1').sendKeys('severity');
+    await firstElementByTestID('label-value-1').sendKeys('warning');
+    expect(firstElementByTestID('duplicate-label-name-error').isPresent()).toBe(true);
+    await firstElementByTestID('remove-routing-label').click();
+    expect(firstElementByTestID('duplicate-label-name-error').isPresent()).toBe(false);
 
+    expect(monitoringView.saveButton.isEnabled()).toBe(true); // subform valid & labels provided, save should be enabled at this point
     await monitoringView.saveButton.click();
-
     await crudView.isLoaded();
-
     monitoringView.getFirstRowAsText().then((text) => {
       expect(text).toEqual('MyReceiver pagerduty severity = warning');
     });
   });
 
-  it('edits PagerDuty Receiver correctly', async () => {
+  it('edits a receiver correctly', async () => {
     await crudView.isLoaded();
     expect(crudView.resourceRows.count()).toBe(2);
     await monitoringView.clickFirstRowKebabAction('Edit Receiver');
@@ -327,7 +344,8 @@ describe('Alertmanager: Configuration', () => {
     });
   });
 
-  it('deletes PagerDuty Receiver correctly', async () => {
+  it('deletes a receiver correctly', async () => {
+    await horizontalnavView.clickHorizontalTab('Details');
     await crudView.isLoaded();
     expect(crudView.resourceRows.count()).toBe(2);
 
@@ -359,17 +377,15 @@ describe('Alertmanager: Configuration', () => {
 receivers:
 - name: 'team-X-pager'
 - name: 'team-DB-pager'`;
-
     await crudView.isLoaded();
     await horizontalnavView.clickHorizontalTab('YAML');
-    await crudView.isLoaded();
-    await firstElementByTestID('alert-manager-yaml-textarea').clear();
-    await firstElementByTestID('alert-manager-yaml-textarea').sendKeys(yaml);
-    await monitoringView.saveButton.click();
-    await crudView.isLoaded();
+    await yamlView.isLoaded();
+    await yamlView.setEditorContent(yaml);
+    await yamlView.saveButton.click();
+    await yamlView.isLoaded();
     expect(monitoringView.successAlert.isPresent()).toBe(true);
 
-    await horizontalnavView.clickHorizontalTab('Overview');
+    await horizontalnavView.clickHorizontalTab('Details');
     await monitoringView.openFirstRowKebabMenu();
     expect(monitoringView.disabledDeleteReceiverMenuItem.isPresent()).toBe(true);
     expect(crudView.actionForLabel('Edit YAML').isPresent()).toBe(true); // should be 'Edit YAML' not 'Edit Receiver'
