@@ -6,6 +6,8 @@ export const passwordInput = $('#inputPassword');
 export const submitButton = $('button[type=submit]');
 export const logOutLink = element(by.linkText('Log out'));
 export const userDropdown = $('[data-test=user-dropdown] .pf-c-app-launcher__toggle');
+export const pf3Login = until.presenceOf($('.login-pf'));
+export const pf4Login = until.presenceOf($('[data-test-id="login"]'));
 
 export const selectProvider = async (provider: string) => {
   const idpLink = element(by.cssContainingText('.idp', provider));
@@ -32,5 +34,5 @@ export const logout = async () => {
   await userDropdown.click();
   await browser.wait(until.presenceOf(logOutLink));
   await logOutLink.click();
-  await browser.wait(until.presenceOf($('.login-pf')));
+  await browser.wait(until.or(pf3Login, pf4Login));
 };
