@@ -1,26 +1,39 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import { Firehose, FieldLevelHelp } from '@console/internal/components/utils';
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import { InfrastructureModel } from '@console/internal/models';
+import { K8sResourceKind, StorageClassResourceKind, k8sGet } from '@console/internal/module/k8s';
 import { StorageClassDropdownInner } from '@console/internal/components/utils/storage-class-dropdown';
-import { cephStorageProvisioners } from '@console/shared';
-import { storageClassTooltip } from '../../constants/ocs-install';
+import { getInfrastructurePlatform, getName } from '@console/shared';
+import { infraProvisionerMap, storageClassTooltip } from '../../constants/ocs-install';
 import './storage-class-dropdown.scss';
 
 const StorageClassDropdown = (props: any) => {
   const scConfig = _.cloneDeep(props);
+  const [infrastructure, setInfrastructure] = React.useState<K8sResourceKind>();
+  const [infrastructureError, setInfrastructureError] = React.useState();
   /* 'S' of Storage should be Capital as its defined key in resourses object */
   const scLoaded = _.get(scConfig.resources.StorageClass, 'loaded');
-  const scData = _.get(scConfig.resources.StorageClass, 'data', []) as K8sResourceKind[];
+  const scData = _.get(scConfig.resources.StorageClass, 'data', []) as StorageClassResourceKind[];
 
-  const filteredSCData = scData.filter((sc: K8sResourceKind) => {
-    return cephStorageProvisioners.every(
-      (provisioner: string) => !_.get(sc, 'provisioner').includes(provisioner),
-    );
-  });
+  React.useEffect(() => {
+    const fetchInfrastructure = async () => {
+      try {
+        const infra = await k8sGet(InfrastructureModel, 'cluster');
+        setInfrastructure(infra);
+      } catch (error) {
+        setInfrastructureError(error);
+      }
+    };
+    fetchInfrastructure();
+  }, []);
 
-  if (scLoaded) {
-    scConfig.resources.StorageClass.data = filteredSCData;
+  const infrastructurePlatform = getInfrastructurePlatform(infrastructure);
+
+  if (scLoaded && !infrastructureError && !!infrastructurePlatform) {
+    // find infra supported provisioner
+    const provisioner: string = infraProvisionerMap[_.toLower(infrastructurePlatform)];
+    scConfig.resources.StorageClass.data = _.filter(scData, (sc) => sc.provisioner === provisioner);
   }
 
   return <StorageClassDropdownInner {...scConfig} />;
@@ -30,8 +43,10 @@ export const OCSStorageClassDropdown: React.FC<OCSStorageClassDropdownProps> = (
   const { onChange, defaultClass } = props;
 
   const handleStorageClass = (sc: K8sResourceKind) => {
-    onChange(sc.metadata.name);
+    const name = getName(sc);
+    onChange(name);
   };
+
   return (
     <>
       <label className="control-label" htmlFor="storageClass">
