@@ -5,7 +5,7 @@ import { FirehoseResult } from '@console/internal/components/utils';
 import { cephStorageProvisioners } from '@console/shared/src/utils';
 import { OCS_OPERATOR } from '../constants';
 
-const cephStorageLabel = 'cluster.ocs.openshift.io/openshift-storage';
+export const cephStorageLabel = 'cluster.ocs.openshift.io/openshift-storage';
 
 export const filterCephAlerts = (alerts: Alert[]): Alert[] =>
   alerts.filter((alert) => _.get(alert, 'annotations.storage_type') === 'ceph');
@@ -57,5 +57,5 @@ export const getOCSVersion = (items: FirehoseResult): string => {
     itemsData,
     (item) => _.get(item, 'spec.name') === OCS_OPERATOR,
   );
-  return _.get(operator, 'status.currentCSV');
+  return _.get(operator, 'status.installedCSV');
 };
