@@ -1,36 +1,41 @@
 import * as _ from 'lodash';
-import { FlagsObject } from '@console/internal/reducers/features';
+
 import {
+  ActivePlugin,
   Extension,
   ExtensionTypeGuard,
-  ActivePlugin,
-  isModelDefinition,
-  isFeatureFlag,
-  isNavItem,
-  isResourceListPage,
-  isResourceDetailsPage,
-  isPerspective,
-  isYAMLTemplate,
-  isRoutePage,
-  isDashboardsOverviewHealthSubsystem,
-  isDashboardsCard,
-  isDashboardsTab,
-  isDashboardsOverviewInventoryItem,
-  isDashboardsInventoryItemGroup,
-  isDashboardsOverviewUtilizationItem,
-  isOverviewResourceTab,
-  isOverviewCRD,
-  isOverviewTabSection,
-  isGlobalConfig,
   isClusterServiceVersionAction,
-  isKebabActions,
-  isDevCatalogModel,
-  isDashboardsOverviewResourceActivity,
+  isDashboardsCard,
+  isDashboardsInventoryItemGroup,
+  isDashboardsOverviewHealthSubsystem,
+  isDashboardsOverviewInventoryItem,
+  isDashboardsOverviewInventoryItemReplacement,
   isDashboardsOverviewPrometheusActivity,
+  isDashboardsOverviewResourceActivity,
+  isDashboardsOverviewUtilizationItem,
+  isDashboardsTab,
+  isDevCatalogModel,
+  isFeatureFlag,
+  isGlobalConfig,
+  isKebabActions,
+  isModelDefinition,
+  isOverviewCRD,
+  isOverviewResourceTab,
+  isOverviewTabSection,
+  isPerspective,
   isProjectDashboardInventoryItem,
   isReduxReducer,
+  isResourceDetailsPage,
+  isResourceListPage,
+  isResourceTabPage,
+  isRoutePage,
+  isYAMLTemplate,
 } from './typings';
 
+import { FlagsObject } from '@console/internal/reducers/features';
+
+// TODO(vojtech): legacy, remove
+
 /**
  * Registry used to query for Console extensions.
  */
@@ -41,22 +46,25 @@ export class ExtensionRegistry {
     this.extensions = _.flatMap(plugins.map((p) => p.extensions));
   }
 
-  public get<E extends Extension>(typeGuard: ExtensionTypeGuard<E>): E[] {
-    return this.extensions.filter(typeGuard);
-  }
-
-  public getRequiredFlags(typeGuards: ExtensionTypeGuard<ExtensionWithFlags>[]) {
-    return _.flatMap(typeGuards.map((tg) => this.extensions.filter(tg)))
-      .filter((e) => e.properties.required)
-      .reduce(
-        (requiredFlags, e) => _.uniq([...requiredFlags, ..._.castArray(e.properties.required)]),
-        [] as string[],
-      );
+  public getGatingFlagNames(typeGuards: ExtensionTypeGuard<ExtensionWithFlags>[]) {
+    return _.flatMap(typeGuards.map((tg) => this.extensions.filter(tg))).reduce(
+      (gatingFlags, e) =>
+        _.uniq([
+          ...gatingFlags,
+          ..._.castArray(e.properties.required || []),
+          ..._.castArray(e.properties.disallowed || []),
+        ]),
+      [] as string[],
+    );
   }
 
   public isExtensionInUse(e: ExtensionWithFlags, flags: FlagsObject) {
-    const requiredFlags = e.properties.required ? _.castArray(e.properties.required) : [];
-    return _.every(requiredFlags, (f) => flags[f]);
+    const requiredFlags = _.castArray(e.properties.required || []);
+    const disallowedFlags = _.castArray(e.properties.disallowed || []);
+    return (
+      _.every(requiredFlags, (f) => flags[f] === true) &&
+      _.every(disallowedFlags, (f) => flags[f] === false)
+    );
   }
 
   public getModelDefinitions() {
@@ -67,10 +75,6 @@ export class ExtensionRegistry {
     return this.extensions.filter(isFeatureFlag);
   }
 
-  public getNavItems() {
-    return this.extensions.filter(isNavItem);
-  }
-
   public getResourceListPages() {
     return this.extensions.filter(isResourceListPage);
   }
@@ -83,6 +87,10 @@ export class ExtensionRegistry {
     return this.extensions.filter(isRoutePage);
   }
 
+  public getResourceTabPages() {
+    return this.extensions.filter(isResourceTabPage);
+  }
+
   public getPerspectives() {
     return this.extensions.filter(isPerspective);
   }
@@ -158,6 +166,13 @@ export class ExtensionRegistry {
   public getProjectDashboardInventoryItems() {
     return this.extensions.filter(isProjectDashboardInventoryItem);
   }
+
+  public getDashboardsOverviewInventoryItemReplacements() {
+    return this.extensions.filter(isDashboardsOverviewInventoryItemReplacement);
+  }
 }
 
-type ExtensionWithFlags = Extension<{ required?: string | string[] }>;
+type ExtensionWithFlags = Extension<{
+  required?: string | string[];
+  disallowed?: string | string[];
+}>;
