@@ -4,7 +4,7 @@ import {
   ResourceNSLinkProps,
   ResourceClusterLinkProps,
 } from '@console/internal/components/nav/items';
-import { Extension } from './extension';
+import { Extension } from './base';
 
 namespace ExtensionProperties {
   interface NavItem {
@@ -13,12 +13,9 @@ namespace ExtensionProperties {
     /** Nav section to which this item belongs to. If not specified, render item as top-level link. */
     section?: string;
     /** Props to pass to the corresponding `NavLink` component. */
-    componentProps: Pick<
-      NavLinkProps,
-      'name' | 'required' | 'disallowed' | 'startsWith' | 'testID'
-    >;
-    /** Nav item after which this item should be placed. */
-    mergeAfter?: string;
+    componentProps: Pick<NavLinkProps, 'name' | 'startsWith' | 'testID'>;
+    /** Nav item before which this item should be placed. */
+    mergeBefore?: string;
   }
 
   export interface HrefNavItem extends NavItem {
