@@ -7,3 +7,5 @@ export * from './validation';
 export * from './table-utils';
 export * from './storage-utils';
 export * from './useCombineRefs';
+export * from './icon-utils';
+export * from './namespace';
