@@ -108,6 +108,19 @@ export const getResourceList = (namespace: string, resList?: any) => {
       namespace,
       prop: 'statefulSets',
     },
+    {
+      isList: true,
+      kind: 'Secret',
+      namespace,
+      prop: 'secrets',
+      optional: true,
+    },
+    {
+      isList: true,
+      kind: 'Event',
+      namespace,
+      prop: 'events',
+    },
   ];
 
   let utils = [];
@@ -233,6 +246,10 @@ const getDeploymentConfigVersion = (obj: K8sResourceKind): number => {
   return version && parseInt(version, 10);
 };
 
+const getDeploymentConfigName = (obj: K8sResourceKind): string => {
+  return _.get(obj, 'metadata.ownerReferences[0].name', null);
+};
+
 export const sortReplicaSetsByRevision = (replicaSets: K8sResourceKind[]): K8sResourceKind[] => {
   return sortByRevision(replicaSets, getDeploymentRevision);
 };
@@ -273,7 +290,7 @@ const getAnnotatedTriggers = (obj: K8sResourceKind) => {
   }
 };
 
-const getDeploymentPhase = (rc: K8sResourceKind): string =>
+const getDeploymentPhase = (rc: K8sResourceKind): DEPLOYMENT_PHASE =>
   _.get(rc, ['metadata', 'annotations', DEPLOYMENT_PHASE_ANNOTATION]);
 
 // Only show an alert once if multiple pods have the same error for the same owner.
@@ -326,7 +343,8 @@ const combinePodAlerts = (pods: K8sResourceKind[]): OverviewItemAlerts =>
 const getReplicationControllerAlerts = (rc: K8sResourceKind): OverviewItemAlerts => {
   const phase = getDeploymentPhase(rc);
   const version = getDeploymentConfigVersion(rc);
-  const label = _.isFinite(version) ? `#${version}` : rc.metadata.name;
+  const name = getDeploymentConfigName(rc);
+  const label = _.isFinite(version) ? `${name} #${version}` : rc.metadata.name;
   const key = `${rc.metadata.uid}--Rollout${phase}`;
   switch (phase) {
     case 'Cancelled':
@@ -401,6 +419,21 @@ const getRolloutStatus = (
   return notFailedOrCancelled && previous && previous.pods.length > 0;
 };
 
+const isDeploymentInProgressOrCompleted = (resource: K8sResourceKind): boolean => {
+  return (
+    [
+      DEPLOYMENT_PHASE.new,
+      DEPLOYMENT_PHASE.pending,
+      DEPLOYMENT_PHASE.running,
+      DEPLOYMENT_PHASE.complete,
+    ].indexOf(getDeploymentPhase(resource)) > -1
+  );
+};
+
+const isReplicationControllerVisible = (resource: K8sResourceKind): boolean => {
+  return !!_.get(resource, ['status', 'replicas'], isDeploymentInProgressOrCompleted(resource));
+};
+
 export class TransformResourceData {
   private resources: any;
 
@@ -435,23 +468,25 @@ export class TransformResourceData {
     };
   };
 
-  getActiveReplicationControllers = (resource: K8sResourceKind): K8sResourceKind[] => {
-    const { replicationControllers } = this.resources;
-    const currentVersion = _.get(resource, 'status.latestVersion');
-    const ownedRC = getOwnedResources(resource, replicationControllers.data);
-    return _.filter(
-      ownedRC,
-      (rc) => _.get(rc, 'status.replicas') || getDeploymentConfigVersion(rc) >= currentVersion - 1,
-    );
-  };
-
   getReplicationControllersForResource = (
     resource: K8sResourceKind,
-  ): PodControllerOverviewItem[] => {
-    const replicationControllers = this.getActiveReplicationControllers(resource);
-    return sortReplicationControllersByRevision(replicationControllers).map((rc) =>
-      getIdledStatus(this.toReplicationControllerItem(rc), resource),
-    );
+  ): {
+    mostRecentRC: K8sResourceKind;
+    visibleReplicationControllers: PodControllerOverviewItem[];
+  } => {
+    const { replicationControllers } = this.resources;
+    const ownedRC = getOwnedResources(resource, replicationControllers.data);
+    const sortedRCs = sortReplicationControllersByRevision(ownedRC);
+    // get the most recent RCs included failed or canceled to show warnings
+    const [mostRecentRC] = sortedRCs;
+    // get the visible RCs except failed/canceled
+    const visibleReplicationControllers = _.filter(sortedRCs, isReplicationControllerVisible);
+    return {
+      mostRecentRC,
+      visibleReplicationControllers: visibleReplicationControllers.map((rc) =>
+        getIdledStatus(this.toReplicationControllerItem(rc), resource),
+      ),
+    };
   };
 
   toReplicaSetItem = (rs: K8sResourceKind): PodControllerOverviewItem => {
@@ -566,6 +601,20 @@ export class TransformResourceData {
     });
   };
 
+  public getEventsForPods = (pods) => {
+    const { events } = this.resources;
+    const kind = 'Pod';
+    const podNameList = _.map(pods, 'metadata.name');
+    const podEvents =
+      events &&
+      _.filter(events.data, (event) => {
+        return (
+          event.involvedObject.kind === kind && podNameList.includes(event.involvedObject.name)
+        );
+      });
+    return podEvents;
+  };
+
   public getServicesForResource = (resource: K8sResourceKind): K8sResourceKind[] => {
     const { services } = this.resources;
     const template: PodTemplate = this.getPodTemplate(resource);
@@ -582,17 +631,24 @@ export class TransformResourceData {
         apiVersion: apiVersionForModel(DeploymentConfigModel),
         kind: DeploymentConfigModel.kind,
       };
-      const replicationControllers = this.getReplicationControllersForResource(obj);
-      const [current, previous] = replicationControllers;
+      const {
+        mostRecentRC,
+        visibleReplicationControllers,
+      } = this.getReplicationControllersForResource(obj);
+      const [current, previous] = visibleReplicationControllers;
       const isRollingOut = getRolloutStatus(obj, current, previous);
       const buildConfigs = this.getBuildConfigsForResource(obj);
       const services = this.getServicesForResource(obj);
       const routes = this.getRoutesForServices(services);
+      const rolloutAlerts = mostRecentRC ? getReplicationControllerAlerts(mostRecentRC) : {};
       const alerts = {
         ...getResourcePausedAlert(obj),
         ...getBuildAlerts(buildConfigs),
+        ...rolloutAlerts,
       };
       const status = resourceStatus(obj, current, isRollingOut);
+      const pods = [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])];
+      const events = this.getEventsForPods(pods);
       const overviewItems = {
         alerts,
         buildConfigs,
@@ -600,10 +656,11 @@ export class TransformResourceData {
         isRollingOut,
         obj,
         previous,
-        pods: [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])],
+        pods,
         routes,
         services,
         status,
+        events,
       };
 
       if (this.utils) {
@@ -635,6 +692,8 @@ export class TransformResourceData {
         ...getBuildAlerts(buildConfigs),
       };
       const status = resourceStatus(obj, current, isRollingOut);
+      const pods = [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])];
+      const events = this.getEventsForPods(pods);
       const overviewItems = {
         alerts,
         buildConfigs,
@@ -642,10 +701,11 @@ export class TransformResourceData {
         isRollingOut,
         obj,
         previous,
-        pods: [..._.get(current, 'pods', []), ..._.get(previous, 'pods', [])],
+        pods,
         routes,
         services,
         status,
+        events,
       };
 
       if (this.utils) {
@@ -673,6 +733,7 @@ export class TransformResourceData {
         ...getBuildAlerts(buildConfigs),
       };
       const status = resourceStatus(obj);
+      const events = this.getEventsForPods(pods);
       return {
         alerts,
         buildConfigs,
@@ -681,6 +742,7 @@ export class TransformResourceData {
         routes,
         services,
         status,
+        events,
       };
     });
   };
@@ -701,6 +763,7 @@ export class TransformResourceData {
       const services = this.getServicesForResource(obj);
       const routes = this.getRoutesForServices(services);
       const status = resourceStatus(obj);
+      const events = this.getEventsForPods(pods);
 
       return {
         alerts,
@@ -710,6 +773,7 @@ export class TransformResourceData {
         routes,
         services,
         status,
+        events,
       };
     });
   };
@@ -756,8 +820,8 @@ export class TransformResourceData {
         apiVersion: apiVersionForModel(DeploymentConfigModel),
         kind: DeploymentConfigModel.kind,
       };
-      const replicationControllers = this.getReplicationControllersForResource(obj);
-      const [current, previous] = replicationControllers;
+      const { visibleReplicationControllers } = this.getReplicationControllersForResource(obj);
+      const [current, previous] = visibleReplicationControllers;
       const isRollingOut = getRolloutStatus(obj, current, previous);
       return {
         obj,
