@@ -1,25 +1,22 @@
 import * as React from 'react';
 import { useFormikContext, FormikValues, useField } from 'formik';
-import { Alert, TextInputTypes } from '@patternfly/react-core';
+import { Alert, TextInputTypes, ValidatedOptions } from '@patternfly/react-core';
 import { getGitService, GitProvider } from '@console/git-service';
-import { LoadingInline } from '@console/internal/components/utils';
-import { CheckCircleIcon } from '@patternfly/react-icons';
-import { InputField, DropdownField } from '../../formik-fields';
+import { InputField, DropdownField, useFormikValidationFix } from '@console/shared';
 import { GitReadableTypes, GitTypes } from '../import-types';
 import { detectGitType, detectGitRepoName } from '../import-validation-utils';
 import { getSampleRepo, getSampleRef, getSampleContextDir } from '../../../utils/imagestream-utils';
 import FormSection from '../section/FormSection';
 import SampleRepo from './SampleRepo';
 import AdvancedGitOptions from './AdvancedGitOptions';
+import { UNASSIGNED_KEY } from '../../../const';
 
 export interface GitSectionProps {
   showSample?: boolean;
 }
 
 const GitSection: React.FC<GitSectionProps> = ({ showSample }) => {
-  const { values, setFieldValue, setFieldTouched, setFieldError, validateForm } = useFormikContext<
-    FormikValues
-  >();
+  const { values, setFieldValue, setFieldTouched } = useFormikContext<FormikValues>();
   const [, { touched: gitTypeTouched }] = useField('git.type');
   const tag = values.image.tagObj;
   const sampleRepo = showSample && getSampleRepo(tag);
@@ -38,6 +35,7 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample }) => {
     gitRepoName && !values.name && setFieldValue('name', gitRepoName);
     gitRepoName &&
       !values.application.name &&
+      values.application.selectedKey !== UNASSIGNED_KEY &&
       setFieldValue('application.name', `${gitRepoName}-app`);
     setFieldTouched('git.url', true);
     showGitType && setFieldTouched('git.type', false);
@@ -46,7 +44,7 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample }) => {
     const isReachable = gitService && (await gitService.isRepoReachable());
     setFieldValue('git.isUrlValidating', false);
     if (isReachable) {
-      setFieldValue('git.isUrlValidated', true);
+      setFieldValue('git.urlValidation', ValidatedOptions.success);
       setFieldValue('image.isRecommending', true);
       const buildTools = await gitService.detectBuildTypes();
       setFieldValue('image.isRecommending', false);
@@ -61,23 +59,19 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample }) => {
     } else {
       setFieldValue('image.recommended', '');
       setFieldValue('image.couldNotRecommend', false);
-      setFieldValue('git.isUrlValidated', false);
-      setFieldError('git.url', 'Git repository is not reachable.');
+      setFieldValue('git.urlValidation', ValidatedOptions.error);
     }
-
-    validateForm();
   }, [
-    setFieldError,
     setFieldTouched,
     setFieldValue,
-    validateForm,
     values.application.name,
+    values.application.selectedKey,
     values.git,
     values.name,
   ]);
 
   const handleGitUrlChange: React.ReactEventHandler = React.useCallback(() => {
-    setFieldValue('git.isUrlValidated', false);
+    setFieldValue('git.urlValidation', ValidatedOptions.default);
     values.image.recommended && setFieldValue('image.recommended', '');
     values.image.couldNotRecommend && setFieldValue('image.couldNotRecommend', false);
   }, [setFieldValue, values.image.couldNotRecommend, values.image.recommended]);
@@ -89,42 +83,37 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample }) => {
     const gitType = detectGitType(url);
     const name = values.name || values.image.selected;
     values.name !== name && setFieldValue('name', name);
-    !values.application.name && setFieldValue('application.name', `${name}-app`);
+    !values.application.name &&
+      values.application.selectedKey !== UNASSIGNED_KEY &&
+      setFieldValue('application.name', `${name}-app`);
     setFieldValue('git.url', url);
     setFieldValue('git.dir', dir);
     setFieldValue('git.ref', ref);
     setFieldValue('git.type', gitType);
     setFieldTouched('git.url', true);
-    validateForm();
   }, [
     sampleRepo,
     setFieldTouched,
     setFieldValue,
     tag,
-    validateForm,
     values.application.name,
+    values.application.selectedKey,
     values.image.selected,
     values.name,
   ]);
 
   const getHelpText = () => {
     if (values.git.isUrlValidating) {
-      return (
-        <span style={{ fontWeight: 'bold' }}>
-          <LoadingInline /> Validating...
-        </span>
-      );
+      return 'Validating...';
     }
-    if (values.git.isUrlValidated) {
-      return (
-        <span style={{ fontWeight: 'bold', color: 'var(--pf-global--success-color--200)' }}>
-          <CheckCircleIcon /> Validated
-        </span>
-      );
+    if (values.git.urlValidation === ValidatedOptions.success) {
+      return 'Validated';
     }
     return '';
   };
 
+  useFormikValidationFix(values.git.url);
+
   return (
     <FormSection title="Git">
       <InputField
@@ -132,8 +121,11 @@ const GitSection: React.FC<GitSectionProps> = ({ showSample }) => {
         name="git.url"
         label="Git Repo URL"
         helpText={getHelpText()}
+        helpTextInvalid="Git repository is not reachable."
+        validated={values.git.urlValidation}
         onChange={handleGitUrlChange}
         onBlur={handleGitUrlBlur}
+        data-test-id="git-form-input-url"
         required
       />
       {values.git.showGitType && (
