@@ -1,12 +1,10 @@
 import * as React from 'react';
 import { useFormikContext, FormikValues } from 'formik';
+import { RadioButtonField } from '@console/shared';
 import FormSection from '../section/FormSection';
 import { imageRegistryType } from '../../../utils/imagestream-utils';
-import RadioButtonField from '../../formik-fields/RadioButtonField';
 import ImageStream from './ImageStream';
 import ImageSearch from './ImageSearch';
-import SearchStatus from './SearchStatus';
-import SearchResults from './SearchResults';
 
 const ImageSearchSection: React.FC = () => {
   const { values, setFieldValue, initialValues } = useFormikContext<FormikValues>();
@@ -38,17 +36,17 @@ const ImageSearchSection: React.FC = () => {
           {
             label: imageRegistryType.External.label,
             value: imageRegistryType.External.value,
+            isDisabled: values.formType === 'edit' && values.registry === 'internal',
             activeChildren: <ImageSearch />,
           },
           {
             label: imageRegistryType.Internal.label,
             value: imageRegistryType.Internal.value,
+            isDisabled: values.formType === 'edit' && values.registry === 'external',
             activeChildren: <ImageStream />,
           },
         ]}
       />
-      <SearchStatus />
-      <SearchResults />
     </FormSection>
   );
 };
