@@ -9,14 +9,27 @@ import {
   ServiceModel,
   RouteModel,
 } from '@console/internal/models';
-import { k8sCreate, K8sResourceKind } from '@console/internal/module/k8s';
+import { k8sCreate, K8sResourceKind, k8sUpdate, K8sVerb } from '@console/internal/module/k8s';
 import {
   getKnativeServiceDepResource,
   ServiceModel as KnServiceModel,
 } from '@console/knative-plugin';
 import { SecretType } from '@console/internal/components/secrets/create-secret';
-import { getAppLabels, getPodLabels, getAppAnnotations } from '../../utils/resource-label-utils';
-import { createService, createRoute, dryRunOpt } from '../../utils/shared-submit-utils';
+import * as plugins from '@console/internal/plugins';
+import { history } from '@console/internal/components/utils';
+import {
+  getAppLabels,
+  getPodLabels,
+  getAppAnnotations,
+  mergeData,
+} from '../../utils/resource-label-utils';
+import {
+  createService,
+  createRoute,
+  dryRunOpt,
+  getRandomChars,
+} from '../../utils/shared-submit-utils';
+import { AppResources } from '../edit-application/edit-application-types';
 import {
   GitImportFormData,
   ProjectData,
@@ -47,11 +60,17 @@ export const createProject = (projectData: ProjectData): Promise<K8sResourceKind
   return k8sCreate(ProjectRequestModel, project);
 };
 
-export const createImageStream = (
+export const createOrUpdateImageStream = (
   formData: GitImportFormData,
   imageStreamData: K8sResourceKind,
   dryRun: boolean,
+  appResources: AppResources,
+  verb: K8sVerb = 'create',
+  generatedImageStreamName: string = '',
 ): Promise<K8sResourceKind> => {
+  const imageStreamList = appResources?.imageStream?.data;
+  const imageStreamFilterData = _.orderBy(imageStreamList, ['metadata.resourceVersion'], ['desc']);
+  const originalImageStream = (imageStreamFilterData.length && imageStreamFilterData[0]) || {};
   const {
     name,
     project: { name: namespace },
@@ -63,18 +82,20 @@ export const createImageStream = (
   const imageStreamName = imageStreamData && imageStreamData.metadata.name;
   const defaultLabels = getAppLabels(name, application, imageStreamName, tag);
   const defaultAnnotations = getAppAnnotations(repository, ref);
-  const imageStream = {
+  const newImageStream = {
     apiVersion: 'image.openshift.io/v1',
     kind: 'ImageStream',
     metadata: {
-      name,
+      name: `${generatedImageStreamName || name}`,
       namespace,
       labels: { ...defaultLabels, ...userLabels },
       annotations: defaultAnnotations,
     },
   };
-
-  return k8sCreate(ImageStreamModel, imageStream, dryRun ? dryRunOpt : {});
+  const imageStream = mergeData(originalImageStream, newImageStream);
+  return verb === 'update'
+    ? k8sUpdate(ImageStreamModel, imageStream)
+    : k8sCreate(ImageStreamModel, newImageStream, dryRun ? dryRunOpt : {});
 };
 
 export const createWebhookSecret = (
@@ -102,10 +123,13 @@ export const createWebhookSecret = (
   return k8sCreate(SecretModel, webhookSecret, dryRun ? dryRunOpt : {});
 };
 
-export const createBuildConfig = (
+export const createOrUpdateBuildConfig = (
   formData: GitImportFormData,
   imageStream: K8sResourceKind,
   dryRun: boolean,
+  originalBuildConfig?: K8sResourceKind,
+  verb: K8sVerb = 'create',
+  generatedImageStreamName: string = '',
 ): Promise<K8sResourceKind> => {
   const {
     name,
@@ -152,7 +176,7 @@ export const createBuildConfig = (
     },
   };
 
-  const buildConfig = {
+  const newBuildConfig = {
     apiVersion: 'build.openshift.io/v1',
     kind: 'BuildConfig',
     metadata: {
@@ -165,7 +189,7 @@ export const createBuildConfig = (
       output: {
         to: {
           kind: 'ImageStreamTag',
-          name: `${name}:latest`,
+          name: `${generatedImageStreamName || name}:latest`,
         },
       },
       source: {
@@ -195,20 +219,30 @@ export const createBuildConfig = (
     },
   };
 
-  return k8sCreate(BuildConfigModel, buildConfig, dryRun ? dryRunOpt : {});
+  const buildConfig = mergeData(originalBuildConfig, newBuildConfig);
+
+  return verb === 'update'
+    ? k8sUpdate(BuildConfigModel, buildConfig)
+    : k8sCreate(BuildConfigModel, buildConfig, dryRun ? dryRunOpt : {});
 };
 
-export const createDeployment = (
+export const createOrUpdateDeployment = (
   formData: GitImportFormData,
   imageStream: K8sResourceKind,
   dryRun: boolean,
+  originalDeployment?: K8sResourceKind,
+  verb: K8sVerb = 'create',
 ): Promise<K8sResourceKind> => {
   const {
     name,
     project: { name: namespace },
     application: { name: application },
     image: { ports, tag },
-    deployment: { env, replicas },
+    deployment: {
+      env,
+      replicas,
+      triggers: { image: imageChange },
+    },
     labels: userLabels,
     limits: { cpu, memory },
     git: { url: repository, ref },
@@ -223,12 +257,13 @@ export const createDeployment = (
       {
         from: { kind: 'ImageStreamTag', name: `${name}:latest` },
         fieldPath: `spec.template.spec.containers[?(@.name=="${name}")].image`,
+        pause: `${!imageChange}`,
       },
     ]),
   };
   const podLabels = getPodLabels(name);
 
-  const deployment = {
+  const newDeployment = {
     apiVersion: 'apps/v1',
     kind: 'Deployment',
     metadata: {
@@ -275,14 +310,19 @@ export const createDeployment = (
       },
     },
   };
+  const deployment = mergeData(originalDeployment, newDeployment);
 
-  return k8sCreate(DeploymentModel, deployment, dryRun ? dryRunOpt : {});
+  return verb === 'update'
+    ? k8sUpdate(DeploymentModel, deployment)
+    : k8sCreate(DeploymentModel, deployment, dryRun ? dryRunOpt : {});
 };
 
-export const createDeploymentConfig = (
+export const createOrUpdateDeploymentConfig = (
   formData: GitImportFormData,
   imageStream: K8sResourceKind,
   dryRun: boolean,
+  originalDeploymentConfig?: K8sResourceKind,
+  verb: K8sVerb = 'create',
 ): Promise<K8sResourceKind> => {
   const {
     name,
@@ -300,7 +340,7 @@ export const createDeploymentConfig = (
   const defaultAnnotations = getAppAnnotations(repository, ref);
   const podLabels = getPodLabels(name);
 
-  const deploymentConfig = {
+  const newDeploymentConfig = {
     apiVersion: 'apps.openshift.io/v1',
     kind: 'DeploymentConfig',
     metadata: {
@@ -357,18 +397,25 @@ export const createDeploymentConfig = (
       ],
     },
   };
+  const deploymentConfig = mergeData(originalDeploymentConfig, newDeploymentConfig);
 
-  return k8sCreate(DeploymentConfigModel, deploymentConfig, dryRun ? dryRunOpt : {});
+  return verb === 'update'
+    ? k8sUpdate(DeploymentConfigModel, deploymentConfig)
+    : k8sCreate(DeploymentConfigModel, deploymentConfig, dryRun ? dryRunOpt : {});
 };
 
-export const createResources = async (
+export const createOrUpdateResources = async (
   formData: GitImportFormData,
   imageStream: K8sResourceKind,
   createNewProject?: boolean,
   dryRun: boolean = false,
+  verb: K8sVerb = 'create',
+  appResources?: AppResources,
 ): Promise<K8sResourceKind[]> => {
   const {
-    route: { create: canCreateRoute },
+    name,
+    project: { name: namespace },
+    route: { create: canCreateRoute, disable },
     image: { ports },
     build: {
       strategy: buildStrategy,
@@ -376,56 +423,125 @@ export const createResources = async (
     },
     git: { url: repository, type: gitType, ref },
     pipeline,
+    resources,
   } = formData;
   const imageStreamName = _.get(imageStream, 'metadata.name');
 
   createNewProject && (await createProject(formData.project));
 
-  const requests: Promise<K8sResourceKind>[] = [
-    createImageStream(formData, imageStream, dryRun),
-    createBuildConfig(formData, imageStream, dryRun),
-    createWebhookSecret(formData, 'generic', dryRun),
-  ];
+  const requests: Promise<K8sResourceKind>[] = [];
+  let generatedImageStreamName: string = '';
+  const imageStreamList = appResources?.imageStream?.data;
+  if (
+    resources === Resources.KnativeService &&
+    imageStreamList &&
+    imageStreamList.length &&
+    verb === 'update'
+  ) {
+    generatedImageStreamName = `${name}-${getRandomChars()}`;
+  }
+  requests.push(
+    createOrUpdateImageStream(
+      formData,
+      imageStream,
+      dryRun,
+      appResources,
+      generatedImageStreamName ? 'create' : verb,
+      generatedImageStreamName,
+    ),
+    createOrUpdateBuildConfig(
+      formData,
+      imageStream,
+      dryRun,
+      _.get(appResources, 'buildConfig.data'),
+      verb,
+      generatedImageStreamName,
+    ),
+  );
+
+  verb === 'create' && requests.push(createWebhookSecret(formData, 'generic', dryRun));
 
   const defaultAnnotations = getAppAnnotations(repository, ref);
 
+  if (pipeline.enabled && pipeline.template && !dryRun) {
+    requests.push(createPipelineForImportFlow(formData));
+  }
+
   if (formData.resources === Resources.KnativeService) {
     // knative service doesn't have dry run capability so returning the promises.
     if (dryRun) {
       return Promise.all(requests);
     }
-
     const [imageStreamResponse] = await Promise.all(requests);
+    const imageStreamURL = imageStreamResponse.status.dockerImageRepository;
+    const originalAnnotations = appResources?.editAppResource?.data?.metadata?.annotations || {};
+    const newAnnotations = { ...originalAnnotations, ...defaultAnnotations };
     const knDeploymentResource = getKnativeServiceDepResource(
       formData,
-      imageStreamResponse.status.dockerImageRepository,
+      imageStreamURL,
       imageStreamName,
-      defaultAnnotations,
+      undefined,
+      undefined,
+      newAnnotations,
+      _.get(appResources, 'editAppResource.data'),
     );
-    return Promise.all([k8sCreate(KnServiceModel, knDeploymentResource)]);
+    return Promise.all([
+      verb === 'update'
+        ? k8sUpdate(KnServiceModel, knDeploymentResource)
+        : k8sCreate(KnServiceModel, knDeploymentResource),
+    ]);
   }
+
   if (formData.resources === Resources.Kubernetes) {
-    requests.push(createDeployment(formData, imageStream, dryRun));
+    requests.push(
+      createOrUpdateDeployment(
+        formData,
+        imageStream,
+        dryRun,
+        _.get(appResources, 'editAppResource.data'),
+        verb,
+      ),
+    );
   } else if (formData.resources === Resources.OpenShift) {
-    requests.push(createDeploymentConfig(formData, imageStream, dryRun));
+    requests.push(
+      createOrUpdateDeploymentConfig(
+        formData,
+        imageStream,
+        dryRun,
+        _.get(appResources, 'editAppResource.data'),
+        verb,
+      ),
+    );
   }
 
   if (!_.isEmpty(ports) || buildStrategy === 'Docker') {
-    const service = createService(formData, imageStream);
-    requests.push(k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {}));
-    if (canCreateRoute) {
-      const route = createRoute(formData, imageStream);
+    const originalService = _.get(appResources, 'service.data');
+    const service = createService(formData, imageStream, originalService);
+    requests.push(
+      verb === 'update'
+        ? k8sUpdate(ServiceModel, service)
+        : k8sCreate(ServiceModel, service, dryRun ? dryRunOpt : {}),
+    );
+    const originalRoute = _.get(appResources, 'route.data');
+    const route = createRoute(formData, imageStream, originalRoute);
+    if (verb === 'update' && disable) {
+      requests.push(k8sUpdate(RouteModel, route, namespace, name));
+    } else if (canCreateRoute) {
       requests.push(k8sCreate(RouteModel, route, dryRun ? dryRunOpt : {}));
     }
   }
 
-  if (pipeline.enabled && pipeline.template && !dryRun) {
-    requests.push(createPipelineForImportFlow(formData));
-  }
-
-  if (webhookTrigger) {
+  if (webhookTrigger && verb === 'create') {
     requests.push(createWebhookSecret(formData, gitType, dryRun));
   }
 
   return Promise.all(requests);
 };
+
+export const handleRedirect = (project: string, perspective: string) => {
+  const perspectiveData = plugins.registry
+    .getPerspectives()
+    .find((item) => item.properties.id === perspective);
+  const redirectURL = perspectiveData.properties.getImportRedirectURL(project);
+  history.push(redirectURL);
+};
