@@ -2,18 +2,12 @@ import * as _ from 'lodash';
 import { k8sCreate, K8sResourceKind } from '@console/internal/module/k8s';
 import { SecretModel } from '@console/internal/models';
 import { PipelineResourceModel } from '../../../models';
+import { getRandomChars } from '../../../utils/shared-submit-utils';
 
 export interface ParamData {
   [key: string]: any;
 }
 
-export const getRandomChars = (digit = 6): string => {
-  return Math.random()
-    .toString(36)
-    .replace(/[^a-z0-9]+/g, '')
-    .substr(1, digit);
-};
-
 export const getDefinedObj = (objData: ParamData): ParamData => {
   return _.omitBy(objData, (v) => _.isUndefined(v) || _.isNull(v) || v === '');
 };
