@@ -2,14 +2,14 @@ import * as React from 'react';
 import { Firehose } from '@console/internal/components/utils';
 import { withStartGuide } from '@console/internal/components/start-guide';
 import ProjectListPage from '../projects/ProjectListPage';
-import ProjectAccess, { ProjectAccessProps } from './ProjectAccess';
+import ProjectAccess from './ProjectAccess';
 
 export interface RenderProjectAccessPageProps {
   namespace: string;
 }
 
-const RenderProjectAccessPage: React.FC<RenderProjectAccessPageProps> = ({ namespace }) => {
-  const props: ProjectAccessProps = {
+export const RenderProjectAccessPage: React.FC<RenderProjectAccessPageProps> = ({ namespace }) => {
+  const props: React.ComponentProps<typeof ProjectAccess> = {
     formName: 'project access',
     namespace,
   };
