@@ -22,6 +22,17 @@ describe('TopologyDataController', () => {
         resourceList={[]}
         application={undefined}
         namespace="namespace"
+        filters={{
+          display: {
+            podCount: true,
+            eventSources: true,
+            knativeServices: true,
+            appGrouping: true,
+            operatorGrouping: true,
+            helmGrouping: true,
+          },
+          searchQuery: null,
+        }}
         {...props}
       />,
     );
