@@ -12,13 +12,15 @@ import {
   ResourceDetailsPage,
   Perspective,
   RoutePage,
+  OverviewResourceTab,
   OverviewCRD,
   YAMLTemplate,
   OverviewTabSection,
+  ReduxReducer,
 } from '@console/plugin-sdk';
 import { NamespaceRedirect } from '@console/internal/components/utils/namespace-redirect';
 import { CodeIcon } from '@patternfly/react-icons';
-import { FLAGS } from '@console/internal/const';
+import { FLAGS } from '@console/shared/src/constants';
 import { referenceForModel } from '@console/internal/module/k8s';
 import * as models from './models';
 import { getKebabActionsForKind } from './utils/kebab-actions';
@@ -34,6 +36,7 @@ import {
   newPipelineResourceTemplate,
   newClusterTaskTemplate,
 } from './templates';
+import reducer from './utils/reducer';
 
 const {
   ClusterTaskModel,
@@ -54,7 +57,9 @@ type ConsumedExtensions =
   | ResourceDetailsPage
   | Perspective
   | RoutePage
+  | ReduxReducer
   | KebabActions
+  | OverviewResourceTab
   | OverviewCRD
   | YAMLTemplate
   | OverviewTabSection;
@@ -98,10 +103,26 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Topology',
         href: '/topology',
-        required: FLAGS.OPENSHIFT,
         testID: 'topology-header',
       },
     },
+    flags: {
+      required: [FLAGS.OPENSHIFT],
+    },
+  },
+  {
+    type: 'NavItem/Href',
+    properties: {
+      perspective: 'dev',
+      componentProps: {
+        name: 'Monitoring',
+        href: '/dev-monitoring',
+        testID: 'monitoring-header',
+      },
+    },
+    flags: {
+      required: [FLAGS.OPENSHIFT],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -110,10 +131,12 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: 'Builds',
         resource: 'buildconfigs',
-        required: FLAGS.OPENSHIFT,
         testID: 'build-header',
       },
     },
+    flags: {
+      required: [FLAGS.OPENSHIFT],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -122,70 +145,64 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: PipelineModel.labelPlural,
         resource: referenceForModel(PipelineModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
         testID: 'pipeline-header',
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
+  },
+  {
+    type: 'NavItem/Href',
+    properties: {
+      section: 'More',
+      perspective: 'dev',
+      componentProps: {
+        name: 'Search',
+        href: '/search',
+        testID: 'more-search-header',
+      },
+    },
+  },
+  {
+    type: 'NavItem/Href',
+    properties: {
+      section: 'More',
+      perspective: 'dev',
+      componentProps: {
+        name: 'Helm',
+        href: '/helm-releases',
+        testID: 'helm-releases-header',
+      },
+    },
+    flags: {
+      required: [FLAGS.OPENSHIFT],
+    },
   },
   {
     type: 'NavItem/ResourceCluster',
     properties: {
-      section: 'Advanced',
+      section: 'More',
       perspective: 'dev',
       componentProps: {
         name: 'Project Details',
         resource: 'projects',
-        required: FLAGS.OPENSHIFT,
-        testID: 'advanced-project-header',
+        testID: 'more-project-header',
       },
     },
+    flags: {
+      required: [FLAGS.OPENSHIFT],
+    },
   },
   {
     type: 'NavItem/Href',
     properties: {
-      section: 'Advanced',
+      section: 'More',
       perspective: 'dev',
       componentProps: {
         name: 'Project Access',
         href: '/project-access',
-        testID: 'advanced-project-access-header',
-      },
-    },
-  },
-  {
-    type: 'NavItem/Href',
-    properties: {
-      section: 'Advanced',
-      perspective: 'dev',
-      componentProps: {
-        name: 'Metrics',
-        href: '/metrics',
-        required: FLAGS.OPENSHIFT,
-        testID: 'metrics-header',
-      },
-    },
-  },
-  {
-    type: 'NavItem/Href',
-    properties: {
-      section: 'Advanced',
-      perspective: 'dev',
-      componentProps: {
-        name: 'Search',
-        href: '/search',
-        testID: 'advanced-search-header',
-      },
-    },
-  },
-  {
-    type: 'NavItem/ResourceNS',
-    properties: {
-      section: 'Advanced',
-      perspective: 'dev',
-      componentProps: {
-        name: 'Events',
-        resource: 'events',
-        testID: 'advanced-events-header',
+        testID: 'more-project-access-header',
       },
     },
   },
@@ -205,9 +222,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: PipelineModel.labelPlural,
         resource: referenceForModel(PipelineModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -217,9 +236,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: PipelineRunModel.labelPlural,
         resource: referenceForModel(PipelineRunModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -229,9 +250,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: PipelineResourceModel.labelPlural,
         resource: referenceForModel(PipelineResourceModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -241,9 +264,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: TaskModel.labelPlural,
         resource: referenceForModel(TaskModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -253,9 +278,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: TaskRunModel.labelPlural,
         resource: referenceForModel(TaskRunModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
   },
   {
     type: 'NavItem/ResourceCluster',
@@ -265,9 +292,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: ClusterTaskModel.labelPlural,
         resource: referenceForModel(ClusterTaskModel),
-        required: FLAG_OPENSHIFT_PIPELINE,
       },
     },
+    flags: {
+      required: [FLAG_OPENSHIFT_PIPELINE],
+    },
   },
   {
     type: 'Overview/Section',
@@ -279,14 +308,27 @@ const plugin: Plugin<ConsumedExtensions> = [
         ).then((m) => m.default),
     },
   },
+  {
+    type: 'Overview/Resource',
+    properties: {
+      name: 'Monitoring',
+      key: 'events',
+      loader: () =>
+        import(
+          './components/monitoring/overview/MonitoringTab' /* webpackChunkName: "monitoring-overview" */
+        ).then((m) => m.default),
+    },
+  },
   {
     type: 'Page/Resource/Details',
     properties: {
       model: PipelineModel,
       loader: async () =>
-        (await import(
-          './components/pipelines/PipelineDetailsPage' /* webpackChunkName: "pipeline-details" */
-        )).default,
+        (
+          await import(
+            './components/pipelines/PipelineDetailsPage' /* webpackChunkName: "pipeline-details" */
+          )
+        ).default,
     },
   },
   {
@@ -294,9 +336,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: PipelineRunModel,
       loader: async () =>
-        (await import(
-          './components/pipelineruns/PipelineRunDetailsPage' /* webpackChunkName: "pipelinerun-details" */
-        )).default,
+        (
+          await import(
+            './components/pipelineruns/PipelineRunDetailsPage' /* webpackChunkName: "pipelinerun-details" */
+          )
+        ).default,
     },
   },
   {
@@ -304,9 +348,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: TaskRunModel,
       loader: async () =>
-        (await import(
-          './components/taskruns/TaskRunDetailsPage' /* webpackChunkName: "taskrun-details" */
-        )).default,
+        (
+          await import(
+            './components/taskruns/TaskRunDetailsPage' /* webpackChunkName: "taskrun-details" */
+          )
+        ).default,
     },
   },
   {
@@ -314,9 +360,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: PipelineModel,
       loader: async () =>
-        (await import(
-          './components/pipelines/PipelinesResourceList' /* webpackChunkName: "pipeline-resource-list" */
-        )).default,
+        (
+          await import(
+            './components/pipelines/PipelinesResourceList' /* webpackChunkName: "pipeline-resource-list" */
+          )
+        ).default,
     },
   },
   {
@@ -324,9 +372,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: PipelineRunModel,
       loader: async () =>
-        (await import(
-          './components/pipelineruns/PipelineRunsResourceList' /* webpackChunkName: "pipelinerun-resource-list" */
-        )).default,
+        (
+          await import(
+            './components/pipelineruns/PipelineRunsResourceList' /* webpackChunkName: "pipelinerun-resource-list" */
+          )
+        ).default,
     },
   },
   {
@@ -348,10 +398,10 @@ const plugin: Plugin<ConsumedExtensions> = [
         '/add',
         '/import',
         '/topology',
-        '/topology1',
         '/deploy-image',
-        '/metrics',
         '/project-access',
+        '/dev-monitoring',
+        '/helm-releases',
       ],
       component: NamespaceRedirect,
     },
@@ -372,29 +422,43 @@ const plugin: Plugin<ConsumedExtensions> = [
       path: [
         '/topology/all-namespaces',
         '/topology/ns/:name',
+        '/topology/all-namespaces/graph',
+        '/topology/ns/:name/graph',
         '/topology/all-namespaces/list',
         '/topology/ns/:name/list',
       ],
       loader: async () =>
-        (await import(
-          './components/topology2/TopologyPage' /* webpackChunkName: "dev-console-topology" */
-        )).default,
+        (
+          await import(
+            './components/topology/TopologyPage' /* webpackChunkName: "dev-console-topology" */
+          )
+        ).default,
     },
   },
   {
     type: 'Page/Route',
     properties: {
       exact: true,
-      path: [
-        '/topology1/all-namespaces',
-        '/topology1/ns/:name',
-        '/topology1/all-namespaces/list',
-        '/topology1/ns/:name/list',
-      ],
+      path: ['/catalog/helm-install'],
       loader: async () =>
-        (await import(
-          './components/topology/TopologyPage' /* webpackChunkName: "dev-console-topology1" */
-        )).default,
+        (
+          await import(
+            './components/helm/HelmInstallPage' /* webpackChunkName: "dev-console-helm-install" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: '/edit/ns/:ns',
+      loader: async () =>
+        (
+          await import(
+            './components/edit-application/EditApplicationPage' /* webpackChunkName: "dev-console-edit" */
+          )
+        ).default,
     },
   },
   {
@@ -403,9 +467,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       exact: true,
       path: ['/import/all-namespaces', '/import/ns/:ns'],
       loader: async () =>
-        (await import(
-          './components/import/ImportPage' /* webpackChunkName: "dev-console-import" */
-        )).default,
+        (
+          await import(
+            './components/import/ImportPage' /* webpackChunkName: "dev-console-import" */
+          )
+        ).default,
     },
   },
   {
@@ -414,9 +480,24 @@ const plugin: Plugin<ConsumedExtensions> = [
       exact: true,
       path: ['/catalog/source-to-image'],
       loader: async () =>
-        (await import(
-          './components/import/ImportPage' /* webpackChunkName: "dev-console-import" */
-        )).default,
+        (
+          await import(
+            './components/import/ImportPage' /* webpackChunkName: "dev-console-import" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      path: ['/helm-releases/ns/:ns/release/:name'],
+      exact: false,
+      loader: async () =>
+        (
+          await import(
+            './components/helm/HelmReleaseDetails' /* webpackChunkName: "dev-console-helmReleaseDetails" */
+          )
+        ).default,
     },
   },
   {
@@ -426,9 +507,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       exact: true,
       path: ['/k8s/all-namespaces/buildconfigs', '/k8s/ns/:ns/buildconfigs'],
       loader: async () =>
-        (await import(
-          './components/BuildConfigPage' /* webpackChunkName: "dev-console-buildconfigs" */
-        )).default,
+        (
+          await import(
+            './components/BuildConfigPage' /* webpackChunkName: "dev-console-buildconfigs" */
+          )
+        ).default,
     },
   },
   {
@@ -441,9 +524,37 @@ const plugin: Plugin<ConsumedExtensions> = [
         `/k8s/ns/:ns/${referenceForModel(PipelineModel)}`,
       ],
       loader: async () =>
-        (await import(
-          './components/pipelines/PipelinesPage' /* webpackChunkName: "pipeline-page" */
-        )).PipelinesPage,
+        (
+          await import(
+            './components/pipelines/PipelinesPage' /* webpackChunkName: "pipeline-page" */
+          )
+        ).PipelinesPage,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: [`/k8s/ns/:ns/${referenceForModel(PipelineModel)}/~new/builder`],
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/pipeline-builder/PipelineBuilderPage' /* webpackChunkName: "pipeline-builder-page" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: true,
+      path: [`/k8s/ns/:ns/${referenceForModel(PipelineModel)}/:pipelineName/builder`],
+      loader: async () =>
+        (
+          await import(
+            './components/pipelines/pipeline-builder/PipelineBuilderEditPage' /* webpackChunkName: "pipeline-builder-edit-page" */
+          )
+        ).default,
     },
   },
   {
@@ -456,9 +567,11 @@ const plugin: Plugin<ConsumedExtensions> = [
         `/k8s/ns/:ns/${referenceForModel(PipelineRunModel)}`,
       ],
       loader: async () =>
-        (await import(
-          './components/pipelineruns/PipelineRunsPage' /* webpackChunkName: "pipelinerun-page" */
-        )).default,
+        (
+          await import(
+            './components/pipelineruns/PipelineRunsPage' /* webpackChunkName: "pipelinerun-page" */
+          )
+        ).default,
     },
   },
   {
@@ -467,9 +580,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       exact: true,
       path: ['/deploy-image/all-namespaces', '/deploy-image/ns/:ns'],
       loader: async () =>
-        (await import(
-          './components/import/DeployImagePage' /* webpackChunkName: "dev-console-deployImage" */
-        )).default,
+        (
+          await import(
+            './components/import/DeployImagePage' /* webpackChunkName: "dev-console-deployImage" */
+          )
+        ).default,
     },
   },
   {
@@ -479,9 +594,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       exact: true,
       path: ['/k8s/cluster/projects'],
       loader: async () =>
-        (await import(
-          './components/projects/details/AllProjectsDetailList' /* webpackChunkName: "all-projects-detail-list" */
-        )).default,
+        (
+          await import(
+            './components/projects/details/AllProjectsDetailList' /* webpackChunkName: "all-projects-detail-list" */
+          )
+        ).default,
     },
   },
   {
@@ -490,19 +607,24 @@ const plugin: Plugin<ConsumedExtensions> = [
       perspective: 'dev',
       path: ['/k8s/cluster/projects/:name'],
       loader: async () =>
-        (await import(
-          './components/projects/details/ProjectDetailsPage' /* webpackChunkName: "project-details" */
-        )).default,
+        (
+          await import(
+            './components/projects/details/ProjectDetailsPage' /* webpackChunkName: "project-details" */
+          )
+        ).default,
     },
   },
   {
     type: 'Page/Route',
     properties: {
       exact: true,
-      path: ['/metrics/all-namespaces', '/metrics/ns/:ns'],
+      path: ['/helm-releases/all-namespaces', '/helm-releases/ns/:ns'],
       loader: async () =>
-        (await import('./components/MetricsPage' /* webpackChunkName: "dev-console-metrics" */))
-          .default,
+        (
+          await import(
+            './components/helm/HelmReleasePage' /* webpackChunkName: "dev-console-helm-releases" */
+          )
+        ).default,
     },
   },
   {
@@ -511,9 +633,31 @@ const plugin: Plugin<ConsumedExtensions> = [
       exact: true,
       path: ['/project-access/all-namespaces', '/project-access/ns/:ns'],
       loader: async () =>
-        (await import(
-          './components/project-access/ProjectAccessPage' /* webpackChunkName: "dev-console-projectAccess" */
-        )).default,
+        (
+          await import(
+            './components/project-access/ProjectAccessPage' /* webpackChunkName: "dev-console-projectAccess" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'Page/Route',
+    properties: {
+      exact: false,
+      path: ['/dev-monitoring/all-namespaces', '/dev-monitoring/ns/:ns'],
+      loader: async () =>
+        (
+          await import(
+            './components/monitoring/MonitoringPage' /* webpackChunkName: "dev-console-monitoring" */
+          )
+        ).default,
+    },
+  },
+  {
+    type: 'ReduxReducer',
+    properties: {
+      namespace: 'devconsole',
+      reducer,
     },
   },
   {
