@@ -158,9 +158,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: models.ServiceModel.labelPlural,
         resource: referenceForModel(models.ServiceModel),
-        required: FLAG_KNATIVE_SERVING_SERVICE,
       },
     },
+    flags: {
+      required: [FLAG_KNATIVE_SERVING_SERVICE],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -169,9 +171,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: models.RevisionModel.labelPlural,
         resource: referenceForModel(models.RevisionModel),
-        required: FLAG_KNATIVE_SERVING_REVISION,
       },
     },
+    flags: {
+      required: [FLAG_KNATIVE_SERVING_REVISION],
+    },
   },
   {
     type: 'NavItem/ResourceNS',
@@ -180,9 +184,11 @@ const plugin: Plugin<ConsumedExtensions> = [
       componentProps: {
         name: models.RouteModel.labelPlural,
         resource: referenceForModel(models.RouteModel),
-        required: FLAG_KNATIVE_SERVING_ROUTE,
       },
     },
+    flags: {
+      required: [FLAG_KNATIVE_SERVING_ROUTE],
+    },
   },
   {
     type: 'Overview/Resource',
@@ -272,9 +278,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: models.RevisionModel,
       loader: async () =>
-        (await import(
-          './components/revisions/RevisionsPage' /* webpackChunkName: "knative-revisions-page" */
-        )).default,
+        (
+          await import(
+            './components/revisions/RevisionsPage' /* webpackChunkName: "knative-revisions-page" */
+          )
+        ).default,
     },
   },
   {
@@ -282,19 +290,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: models.ServiceModel,
       loader: async () =>
-        (await import(
-          './components/services/ServicesPage' /* webpackChunkName: "knative-services-page" */
-        )).default,
-    },
-  },
-  {
-    type: 'Page/Resource/Details',
-    properties: {
-      model: models.ServiceModel,
-      loader: async () =>
-        (await import(
-          './components/services/ServiceDetailsPage' /* webpackChunkName: "knative-service-details-page" */
-        )).default,
+        (
+          await import(
+            './components/services/ServicesPage' /* webpackChunkName: "knative-services-page" */
+          )
+        ).default,
     },
   },
   {
@@ -302,19 +302,11 @@ const plugin: Plugin<ConsumedExtensions> = [
     properties: {
       model: models.RouteModel,
       loader: async () =>
-        (await import(
-          './components/routes/RoutesPage' /* webpackChunkName: "knative-routes-page" */
-        )).default,
-    },
-  },
-  {
-    type: 'Page/Resource/Details',
-    properties: {
-      model: models.RouteModel,
-      loader: async () =>
-        (await import(
-          './components/routes/RouteDetailsPage' /* webpackChunkName: "knative-route-details-page" */
-        )).default,
+        (
+          await import(
+            './components/routes/RoutesPage' /* webpackChunkName: "knative-routes-page" */
+          )
+        ).default,
     },
   },
   {
