@@ -1,17 +1,18 @@
 import * as _ from 'lodash';
 import { testName } from '@console/internal-integration-tests/protractor.conf';
-import { isLoaded, resourceTitle } from '@console/internal-integration-tests/views/crud.view';
+import { resourceTitle } from '@console/internal-integration-tests/views/crud.view';
 import { asyncForEach, createResource, deleteResource } from '@console/shared/src/test-utils/utils';
 import * as vmView from '../views/virtualMachine.view';
 import { getVMManifest, basicVMConfig } from './utils/mocks';
-import { exposeServices } from './utils/utils';
+import { exposeServices, pauseVM } from './utils/utils';
 import { VirtualMachine } from './models/virtualMachine';
 import {
-  TABS,
-  DASH,
+  TAB,
   VM_BOOTUP_TIMEOUT_SECS,
-  VM_ACTIONS,
+  VM_ACTION,
+  VM_STATUS,
   COMMON_TEMPLATES_VERSION,
+  NOT_AVAILABLE,
 } from './utils/consts';
 import { NodePortService } from './utils/types';
 
@@ -51,27 +52,27 @@ describe('Test VM overview', () => {
   });
 
   beforeEach(async () => {
-    await vm.navigateToTab(TABS.OVERVIEW);
-    await isLoaded();
+    await vm.navigateToTab(TAB.Details);
   });
 
   it('Check VM details in overview when VM is off', async () => {
     const expectation = {
       name: vmName,
+      status: VM_STATUS.Off,
       description: testName,
       os: basicVMConfig.operatingSystem,
       profile: basicVMConfig.workloadProfile,
       template: `rhel7-desktop-tiny-${COMMON_TEMPLATES_VERSION}`,
-      bootOrder: ['rootdisk', 'nic0', 'cloudinitdisk'],
-      flavor: basicVMConfig.flavor,
-      ip: DASH,
-      pod: DASH,
-      node: DASH,
-      offIconPresent: true,
+      bootOrder: ['rootdisk (Disk)', 'nic0 (NIC)', 'cloudinitdisk (Disk)'],
+      flavor: 'Tiny: 1 vCPU, 1 GiB Memory',
+      ip: NOT_AVAILABLE,
+      pod: NOT_AVAILABLE,
+      node: NOT_AVAILABLE,
     };
 
     const found = {
       name: await resourceTitle.getText(),
+      status: await vm.getStatus(),
       description: await vmView.vmDetailDesc(testName, vmName).getText(),
       os: await vmView.vmDetailOS(testName, vmName).getText(),
       profile: await vmView.vmDetailWorkloadProfile(testName, vmName).getText(),
@@ -81,7 +82,6 @@ describe('Test VM overview', () => {
       ip: await vmView.vmDetailIP(testName, vmName).getText(),
       pod: await vmView.vmDetailPod(testName, vmName).getText(),
       node: await vmView.vmDetailNode(testName, vmName).getText(),
-      offIconPresent: await vmView.statusIcon(vmView.statusIcons.off).isPresent(),
     };
 
     const equal = _.isEqual(found, expectation);
@@ -95,9 +95,9 @@ describe('Test VM overview', () => {
   it(
     'Check VM details in overview when VM is running',
     async () => {
-      await vm.action(VM_ACTIONS.START);
+      await vm.action(VM_ACTION.Start);
       // Empty fields turn into non-empty
-      expect(await vmView.vmDetailIP(testName, vmName).getText()).not.toEqual(DASH);
+      expect(await vmView.vmDetailIP(testName, vmName).getText()).not.toEqual(NOT_AVAILABLE);
       expect(
         await vmView
           .vmDetailPod(testName, vmName)
@@ -109,13 +109,12 @@ describe('Test VM overview', () => {
           .vmDetailNode(testName, vmName)
           .$('a')
           .getText(),
-      ).not.toEqual(DASH);
+      ).not.toEqual(NOT_AVAILABLE);
     },
     VM_BOOTUP_TIMEOUT_SECS,
   );
 
   it('Check vm services', async () => {
-    await vm.navigateToTab(TABS.OVERVIEW);
     await asyncForEach(nodePortServices, async (srv) => {
       expect(await vmView.vmDetailService(srv.exposeName).getText()).toEqual(srv.exposeName);
       expect(await vmView.vmDetailService(srv.exposeName).getAttribute('href')).toContain(
@@ -123,4 +122,12 @@ describe('Test VM overview', () => {
       );
     });
   });
+
+  it('Check unpause VM when VM is running', async () => {
+    await vm.action(VM_ACTION.Start);
+    pauseVM(vmName, testName);
+    expect(await vm.getStatus()).toEqual(VM_STATUS.Paused);
+    await vm.modalEditStatus();
+    expect(await vm.getStatus()).toEqual(VM_STATUS.Running);
+  });
 });
