@@ -1,27 +1,21 @@
-import { $, browser, ExpectedConditions as until } from 'protractor';
+import { $, browser, ExpectedConditions as until, element, by } from 'protractor';
 import { resourceRows } from '@console/internal-integration-tests/views/crud.view';
 import { click } from '@console/shared/src/test-utils/utils';
 
-export const createNic = $('#create-nic-btn');
-export const createDisk = $('#create-disk-btn');
+export const createNICButton = $('#create-nic-btn');
+export const createDiskButton = $('#create-disk-btn');
 
-export const nicName = $('#nic-name');
-export const macAddress = $('#nic-mac-address');
-export const networkTypeDropdownId = '#nic-network-type';
-export const networkBindingId = '#nic-binding';
-
-export const diskName = $('#disk-name');
-export const diskSize = $('#disk-size');
-export const diskStorageClassDropdownId = '#disk-storage-class';
-
-export const cancelBtn = $('button.kubevirt-cancel-accept-buttons.btn-default');
-export const applyBtn = $('button.kubevirt-cancel-accept-buttons.btn-primary');
+export const modalSubmitButton = $('.modal-content .pf-m-primary');
+export const cancelButton = element(by.buttonText('Cancel'));
+export const applyButton = element(by.buttonText('Add'));
+export const saveButton = element(by.buttonText('Save'));
 
 // Used to determine presence of a new row by looking for confirmation buttons
 export const newResourceRow = $('.kubevirt-vm-create-device-row__confirmation-buttons');
 
 const tableContent = $('.ReactVirtualized__VirtualGrid.ReactVirtualized__List');
-export const tableRows = () => tableContent.getText().then((text) => text.split('\n'));
+export const tableRows = () =>
+  tableContent.getAttribute('innerText').then((text) => text.split('\n'));
 export const tableRowForName = (name: string) =>
   resourceRows
     .filter((row) =>
