@@ -7,6 +7,7 @@ export const REVIEW_AND_CREATE = 'Review and create';
 export const NO_TEMPLATE = 'None';
 export const SELECT_TEMPLATE = '--- Select Template ---';
 export const NO_TEMPLATE_AVAILABLE = 'No template available';
+export const NO_OPENSHIFT_TEMPLATES = 'Non-Openshift Cluster detected - Templates are Unavailable';
 export const WIZARD_CLOSE_PROMPT =
   "Are you sure you want to navigate away from this form? Any data you've added will be lost.";
 
@@ -18,6 +19,7 @@ export const TabTitleResolver = {
   [VMWizardTab.NETWORKING]: 'Networking',
   [VMWizardTab.STORAGE]: 'Storage',
   [VMWizardTab.ADVANCED_CLOUD_INIT]: 'Cloud-init',
+  [VMWizardTab.ADVANCED_VIRTUAL_HARDWARE]: 'Virtual Hardware',
   [VMWizardTab.REVIEW]: 'Review',
   [VMWizardTab.RESULT]: 'Result',
 };
