@@ -6,13 +6,12 @@ import {
   HandlePromiseProps,
   withHandlePromise,
 } from '@console/internal/components/utils';
-import { isWindows } from 'kubevirt-web-ui-components';
 import { ModalTitle, ModalBody, ModalComponentProps } from '@console/internal/components/factory';
 import { PlusCircleIcon, OutlinedQuestionCircleIcon } from '@patternfly/react-icons';
 import { k8sPatch } from '@console/internal/module/k8s';
 import { ModalFooter } from '../modal/modal-footer';
 import { getCDsPatch } from '../../../k8s/patches/vm/vm-cdrom-patches';
-import { getVMLikeModel, asVM } from '../../../selectors/vm';
+import { getVMLikeModel, asVM, isWindows } from '../../../selectors/vm';
 import {
   getCDRoms,
   getContainerImageByDisk,
@@ -23,11 +22,39 @@ import {
   isVMRunning,
 } from '../../../selectors/vm/selectors';
 import { isValidationError, validateURL } from '../../../utils/validations/common';
-import { VMKind, VMLikeEntityKind } from '../../../types';
+import { VMLikeEntityKind } from '../../../types/vmLike';
 import { CDRomRow } from './cdrom-row';
-import { initialDisk, WINTOOLS_CONTAINER_NAMES, StorageType, CD, CDMap } from './constants';
 import { getAvailableCDName } from './helpers';
+import { initialDisk, WINTOOLS_CONTAINER_NAMES, StorageType } from './constants';
 import './cdrom-modal.scss';
+import { CD, CDMap } from './types';
+import { VMKind } from '../../../types/vm';
+
+export const AddCDButton = ({ className, text, onClick, isDisabled }: AddCDButtonProps) => (
+  <div className={className}>
+    <Button
+      className="pf-m-link--align-left"
+      id="vm-cd-add-btn"
+      variant="link"
+      onClick={onClick}
+      isDisabled={isDisabled}
+      icon={<PlusCircleIcon />}
+    >
+      {text}
+    </Button>
+    {isDisabled && (
+      <Tooltip
+        position="bottom"
+        trigger="click mouseenter"
+        entryDelay={0}
+        exitDelay={0}
+        content="You have reached the maximum amount of CD-ROM drives"
+      >
+        <OutlinedQuestionCircleIcon />
+      </Tooltip>
+    )}
+  </div>
+);
 
 export const CDRomModal = withHandlePromise((props: CDRomModalProps) => {
   const {
@@ -52,17 +79,16 @@ export const CDRomModal = withHandlePromise((props: CDRomModalProps) => {
           name,
           cdrom,
           bootOrder,
-          isInVM: true,
         };
         const container = getContainerImageByDisk(vm, name);
         if (container) {
-          if (_.includes(WINTOOLS_CONTAINER_NAMES, container))
+          if (_.includes(WINTOOLS_CONTAINER_NAMES, container)) {
             cd = {
               ...cd,
               type: StorageType.WINTOOLS,
               windowsTools: container,
             };
-          else {
+          } else {
             cd = { ...cd, type: StorageType.CONTAINER, container };
           }
         }
@@ -117,9 +143,6 @@ export const CDRomModal = withHandlePromise((props: CDRomModalProps) => {
     setCDs({ ...cds, [name]: newCD });
   };
 
-  const onCDEject = (cdName: string) =>
-    setCDs({ ...cds, [cdName]: { ...cds[cdName], ejected: true } });
-
   const onCDDelete = (cdName: string) => {
     setShouldPatch(true);
     setCDs(_.omit(cds, cdName));
@@ -171,7 +194,6 @@ export const CDRomModal = withHandlePromise((props: CDRomModalProps) => {
                 inProgress={inProgress}
                 onChange={onCDChange}
                 onDelete={onCDDelete}
-                onEject={onCDEject}
               />
             ))
           ) : (
@@ -179,26 +201,12 @@ export const CDRomModal = withHandlePromise((props: CDRomModalProps) => {
               This virtual machine does not have any CD-ROMs attached.
             </Text>
           )}
-          <div className="kubevirt-add-cd-btn">
-            <Button
-              className="pf-m-link--align-left"
-              id="vm-cd-add-btn"
-              variant="link"
-              onClick={onCDAdd}
-              isDisabled={_.size(cds) > 1}
-              icon={<PlusCircleIcon />}
-            >
-              Add CD-ROM
-            </Button>
-            {_.size(cds) > 1 && (
-              <Tooltip
-                position="bottom"
-                content="You have reached the maximum amount of CD-ROM drives"
-              >
-                <OutlinedQuestionCircleIcon />
-              </Tooltip>
-            )}
-          </div>
+          <AddCDButton
+            className="kubevirt-add-cd-btn"
+            text="Add CD-ROM"
+            onClick={onCDAdd}
+            isDisabled={_.size(cds) > 1}
+          />
         </Form>
       </ModalBody>
       <ModalFooter
@@ -217,6 +225,13 @@ export const CDRomModal = withHandlePromise((props: CDRomModalProps) => {
   );
 });
 
+type AddCDButtonProps = {
+  className: string;
+  text: string;
+  isDisabled: boolean;
+  onClick: () => void;
+};
+
 type CDRomModalProps = HandlePromiseProps &
   ModalComponentProps & {
     vmLikeEntity: VMLikeEntityKind;
