@@ -6,18 +6,16 @@ import {
   KebabOption,
   LoadingInline,
 } from '@console/internal/components/utils';
-import { dimensifyRow, getDeletetionTimestamp, DASH } from '@console/shared';
+import { DASH, dimensifyRow, getDeletetionTimestamp } from '@console/shared';
 import { TemplateModel } from '@console/internal/models';
 import { deleteDeviceModal, DeviceType } from '../modals/delete-device-modal';
-import { VMLikeEntityKind } from '../../types';
-import { asVM, isVM, isVMRunning } from '../../selectors/vm';
+import { VMLikeEntityKind } from '../../types/vmLike';
+import { asVM, isVM, isVMI, isVMRunning } from '../../selectors/vm';
 import { VirtualMachineModel } from '../../models';
 import { ValidationCell } from '../table/validation-cell';
 import { VMNicRowActionOpts } from '../vm-nics/types';
 import { diskModalEnhanced } from '../modals/disk-modal/disk-modal-enhanced';
-import { VMCDRomModal } from '../modals/cdrom-vm-modal';
 import { CombinedDisk } from '../../k8s/wrapper/vm/combined-disk';
-import { DiskType } from '../../constants';
 import {
   StorageBundle,
   StorageSimpleData,
@@ -25,30 +23,26 @@ import {
   VMStorageRowActionOpts,
   VMStorageRowCustomData,
 } from './types';
+import { validateDisk } from '../../utils/validations/vm/disk';
 
 const menuActionEdit = (
   disk: CombinedDisk,
   vmLikeEntity: VMLikeEntityKind,
-  { withProgress }: VMNicRowActionOpts,
+  { withProgress, templateValidations }: VMStorageRowActionOpts,
 ): KebabOption => ({
   label: 'Edit',
   callback: () =>
-    disk.getType() !== DiskType.CDROM
-      ? withProgress(
-          diskModalEnhanced({
-            vmLikeEntity,
-            disk: disk.diskWrapper.asResource(),
-            volume: disk.volumeWrapper.asResource(),
-            dataVolume: disk.dataVolumeWrapper && disk.dataVolumeWrapper.asResource(),
-          }).result,
-        )
-      : withProgress(
-          VMCDRomModal({
-            vmLikeEntity,
-            dataVolume: disk.dataVolumeWrapper && disk.dataVolumeWrapper.asResource(),
-            modalClassName: 'modal-lg',
-          }).result,
-        ),
+    withProgress(
+      diskModalEnhanced({
+        vmLikeEntity,
+        isEditing: true,
+        blocking: true,
+        disk: disk.diskWrapper.asResource(),
+        volume: disk.volumeWrapper.asResource(),
+        dataVolume: disk.dataVolumeWrapper && disk.dataVolumeWrapper.asResource(),
+        templateValidations,
+      }).result,
+    ),
   accessReview: asAccessReview(
     isVM(vmLikeEntity) ? VirtualMachineModel : TemplateModel,
     vmLikeEntity,
@@ -83,12 +77,12 @@ const getActions = (
   opts: VMStorageRowActionOpts,
 ) => {
   const actions = [];
-  if (isVMRunning(asVM(vmLikeEntity))) {
+  if (isVMI(vmLikeEntity) || isVMRunning(asVM(vmLikeEntity))) {
     return actions;
   }
 
   const isTemplate = vmLikeEntity && !isVM(vmLikeEntity);
-  if (isTemplate || disk.isEditingSupported()) {
+  if (disk.isEditingSupported(isTemplate)) {
     actions.push(menuActionEdit);
   }
 
@@ -106,7 +100,7 @@ export type VMDiskSimpleRowProps = {
 };
 
 export const DiskSimpleRow: React.FC<VMDiskSimpleRowProps> = ({
-  data: { name, type, size, diskInterface, storageClass },
+  data: { name, source, size, diskInterface, storageClass },
   validation = {},
   columnClasses,
   actionsComponent,
@@ -122,6 +116,9 @@ export const DiskSimpleRow: React.FC<VMDiskSimpleRowProps> = ({
       <TableData className={dimensify()}>
         <ValidationCell validation={validation.name}>{name}</ValidationCell>
       </TableData>
+      <TableData className={dimensify()}>
+        <ValidationCell validation={validation.source}>{source || DASH}</ValidationCell>
+      </TableData>
       <TableData className={dimensify()}>
         {isSizeLoading && <LoadingInline />}
         {!isSizeLoading && (
@@ -131,9 +128,6 @@ export const DiskSimpleRow: React.FC<VMDiskSimpleRowProps> = ({
       <TableData className={dimensify()}>
         <ValidationCell validation={validation.diskInterface}>{diskInterface}</ValidationCell>
       </TableData>
-      <TableData className={dimensify()}>
-        <ValidationCell validation={validation.type}>{type || DASH}</ValidationCell>
-      </TableData>
       <TableData className={dimensify()}>
         {isStorageClassLoading && <LoadingInline />}
         {!isStorageClassLoading && (
@@ -156,13 +150,31 @@ export type VMDiskRowProps = {
 
 export const DiskRow: React.FC<VMDiskRowProps> = ({
   obj: { disk, ...restData },
-  customData: { isDisabled, withProgress, vmLikeEntity, columnClasses },
+  customData: { isDisabled, withProgress, vmLikeEntity, columnClasses, templateValidations },
   index,
   style,
 }) => {
+  const diskValidations = validateDisk(
+    disk.diskWrapper,
+    disk.volumeWrapper,
+    disk.dataVolumeWrapper,
+    disk.persistentVolumeClaimWrapper,
+    { templateValidations },
+  );
   return (
     <DiskSimpleRow
       data={restData}
+      validation={
+        diskValidations && {
+          name: diskValidations.validations.name,
+          size: diskValidations.validations.size,
+          diskInterface: diskValidations.validations.diskInterface,
+          source:
+            diskValidations.validations.url ||
+            diskValidations.validations.container ||
+            diskValidations.validations.pvc,
+        }
+      }
       columnClasses={columnClasses}
       index={index}
       style={style}
@@ -170,9 +182,13 @@ export const DiskRow: React.FC<VMDiskRowProps> = ({
         <Kebab
           options={getActions(disk, vmLikeEntity, {
             withProgress,
+            templateValidations,
           })}
           isDisabled={
-            isDisabled || !!getDeletetionTimestamp(vmLikeEntity) || isVMRunning(asVM(vmLikeEntity))
+            isDisabled ||
+            isVMI(vmLikeEntity) ||
+            !!getDeletetionTimestamp(vmLikeEntity) ||
+            isVMRunning(asVM(vmLikeEntity))
           }
           id={`kebab-for-${disk.getName()}`}
         />
