@@ -1,30 +1,37 @@
 import * as React from 'react';
 import { Button, ButtonVariant } from '@patternfly/react-core';
 import { Table } from '@console/internal/components/factory';
-import { PersistentVolumeClaimModel } from '@console/internal/models';
-import { Firehose, FirehoseResult } from '@console/internal/components/utils';
+import { PersistentVolumeClaimModel, TemplateModel } from '@console/internal/models';
+import { Firehose, FirehoseResult, EmptyBox } from '@console/internal/components/utils';
 import { useSafetyFirst } from '@console/internal/components/safety-first';
-import { K8sResourceKind } from '@console/internal/module/k8s';
+import { K8sResourceKind, TemplateKind } from '@console/internal/module/k8s';
 import { dimensifyHeader, getNamespace } from '@console/shared';
 import { sortable } from '@patternfly/react-table';
 import { DataVolumeModel } from '../../models';
-import { VMLikeEntityKind } from '../../types';
+import { VMGenericLikeEntityKind } from '../../types/vmLike';
 import { VMLikeEntityTabProps } from '../vms/types';
-import { getResource } from '../../utils';
+import { getResource, getLoadedData } from '../../utils';
 import { wrapWithProgress } from '../../utils/utils';
 import { diskModalEnhanced } from '../modals/disk-modal/disk-modal-enhanced';
 import { CombinedDiskFactory } from '../../k8s/wrapper/vm/combined-disk';
 import { V1alpha1DataVolume } from '../../types/vm/disk/V1alpha1DataVolume';
+import { VHW_TYPES } from '../create-vm-wizard/tabs/virtual-hardware-tab/types';
 import { StorageBundle } from './types';
 import { DiskRow } from './disk-row';
 import { diskTableColumnClasses } from './utils';
+import { isVMI } from '../../selectors/vm';
+import { ADD_DISK } from '../../utils/strings';
+import {
+  getVMTemplateNamespacedName,
+  getTemplateValidationsFromTemplate,
+} from '../../selectors/vm-template/selectors';
 
 const getStoragesData = ({
   vmLikeEntity,
   datavolumes,
   pvcs,
 }: {
-  vmLikeEntity: VMLikeEntityKind;
+  vmLikeEntity: VMGenericLikeEntityKind;
   pvcs: FirehoseResult<K8sResourceKind[]>;
   datavolumes: FirehoseResult<V1alpha1DataVolume[]>;
 }): StorageBundle[] => {
@@ -34,17 +41,18 @@ const getStoragesData = ({
     pvcs,
   );
 
-  return combinedDiskFactory.getCombinedDisks().map((disk) => {
-    return {
+  return combinedDiskFactory
+    .getCombinedDisks()
+    .filter((storage) => !VHW_TYPES.has(storage.diskWrapper.getType()))
+    .map((disk) => ({
       disk,
       // for sorting
       name: disk.getName(),
-      type: disk.getTypeValue(),
+      source: disk.getSourceValue(),
       diskInterface: disk.getDiskInterface(),
       size: disk.getReadableSize(),
       storageClass: disk.getStorageClassName(),
-    };
-  });
+    }));
 };
 
 export type VMDisksTableProps = {
@@ -54,6 +62,8 @@ export type VMDisksTableProps = {
   columnClasses: string[];
 };
 
+const NoDataEmptyMsg = () => <EmptyBox label="Disks" />;
+
 export const VMDisksTable: React.FC<VMDisksTableProps> = ({
   data,
   customData,
@@ -64,6 +74,7 @@ export const VMDisksTable: React.FC<VMDisksTableProps> = ({
     <Table
       aria-label="VM Disks List"
       data={data}
+      NoDataEmptyMsg={NoDataEmptyMsg}
       Header={() =>
         dimensifyHeader(
           [
@@ -72,6 +83,11 @@ export const VMDisksTable: React.FC<VMDisksTableProps> = ({
               sortField: 'name',
               transforms: [sortable],
             },
+            {
+              title: 'Source',
+              sortField: 'source',
+              transforms: [sortable],
+            },
             {
               title: 'Size',
               sortField: 'size',
@@ -82,11 +98,6 @@ export const VMDisksTable: React.FC<VMDisksTableProps> = ({
               sortField: 'diskInterface',
               transforms: [sortable],
             },
-            {
-              title: 'Type',
-              sortField: 'type',
-              transforms: [sortable],
-            },
             {
               title: 'Storage Class',
               sortField: 'storageClass',
@@ -108,35 +119,46 @@ export const VMDisksTable: React.FC<VMDisksTableProps> = ({
 };
 
 type VMDisksProps = {
-  vmLikeEntity?: VMLikeEntityKind;
+  vmLikeEntity?: VMGenericLikeEntityKind;
   pvcs?: FirehoseResult<K8sResourceKind[]>;
   datavolumes?: FirehoseResult<V1alpha1DataVolume[]>;
+  vmTemplate?: FirehoseResult<TemplateKind>;
 };
 
-export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, pvcs, datavolumes }) => {
+export const VMDisks: React.FC<VMDisksProps> = ({
+  vmLikeEntity,
+  pvcs,
+  datavolumes,
+  vmTemplate,
+}) => {
   const [isLocked, setIsLocked] = useSafetyFirst(false);
   const withProgress = wrapWithProgress(setIsLocked);
+  const templateValidations = getTemplateValidationsFromTemplate(getLoadedData(vmTemplate));
+
   return (
     <div className="co-m-list">
-      <div className="co-m-pane__filter-bar">
-        <div className="co-m-pane__filter-bar-group">
-          <Button
-            variant={ButtonVariant.primary}
-            id="create-disk-btn"
-            onClick={() =>
-              withProgress(
-                diskModalEnhanced({
-                  blocking: true,
-                  vmLikeEntity,
-                }).result,
-              )
-            }
-            isDisabled={isLocked}
-          >
-            Create Disk
-          </Button>
+      {!isVMI(vmLikeEntity) && (
+        <div className="co-m-pane__filter-bar">
+          <div className="co-m-pane__filter-bar-group">
+            <Button
+              variant={ButtonVariant.primary}
+              id="create-disk-btn"
+              onClick={() =>
+                withProgress(
+                  diskModalEnhanced({
+                    blocking: true,
+                    vmLikeEntity,
+                    templateValidations,
+                  }).result,
+                )
+              }
+              isDisabled={isLocked}
+            >
+              {ADD_DISK}
+            </Button>
+          </div>
         </div>
-      </div>
+      )}
       <div className="co-m-pane__body">
         <VMDisksTable
           data={getStoragesData({ vmLikeEntity, pvcs, datavolumes })}
@@ -144,6 +166,7 @@ export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, pvcs, datavolume
             vmLikeEntity,
             withProgress,
             isDisabled: isLocked,
+            templateValidations,
           }}
           row={DiskRow}
           columnClasses={diskTableColumnClasses}
@@ -155,6 +178,7 @@ export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, pvcs, datavolume
 
 export const VMDisksFirehose: React.FC<VMLikeEntityTabProps> = ({ obj: vmLikeEntity }) => {
   const namespace = getNamespace(vmLikeEntity);
+  const vmTemplate = getVMTemplateNamespacedName(vmLikeEntity);
 
   const resources = [
     getResource(PersistentVolumeClaimModel, {
@@ -165,6 +189,12 @@ export const VMDisksFirehose: React.FC<VMLikeEntityTabProps> = ({ obj: vmLikeEnt
       namespace,
       prop: 'datavolumes',
     }),
+    getResource(TemplateModel, {
+      name: vmTemplate?.name,
+      namespace: vmTemplate?.namespace,
+      isList: false,
+      prop: 'vmTemplate',
+    }),
   ];
 
   return (
