@@ -1,28 +1,26 @@
-import { last } from 'lodash';
-import {
-  BOOT_ORDER_SECOND,
-  BOOT_ORDER_FIRST,
-  getBootableDevicesInOrder,
-} from 'kubevirt-web-ui-components';
+import { last, includes } from 'lodash';
 import { getName } from '@console/shared';
 import { Volume, k8sGet } from '@console/internal/module/k8s';
-import { CD, StorageType } from '../../../components/modals/cdrom-vm-modal/constants';
-import { DataVolumeWrapper } from '../../wrapper/vm/data-volume-wrapper';
+import { PatchBuilder, PatchOperation } from '@console/shared/src/k8s';
+import { StorageType } from '../../../components/modals/cdrom-vm-modal/constants';
+import { MutableDataVolumeWrapper } from '../../wrapper/vm/data-volume-wrapper';
 import {
-  getDefaultSCAccessMode,
+  getDefaultSCAccessModes,
   getDefaultSCVolumeMode,
 } from '../../../selectors/config-map/sc-defaults';
 import { getStorageClassConfigMap } from '../../requests/config-map/storage-class';
-import { PatchBuilder, PatchOperation } from '../../utils/patch';
-import { VMLikeEntityKind } from '../../../types';
+import { VMLikeEntityKind } from '../../../types/vmLike';
 import {
   getVolumes,
   getDataVolumeTemplates,
   getDisks,
   getVolumeDataVolumeName,
   asVM,
+  getBootableDevicesInOrder,
 } from '../../../selectors/vm';
 import { getVMLikePatches } from '../vm-template';
+import { BOOT_ORDER_FIRST, BOOT_ORDER_SECOND, DiskBus } from '../../../constants';
+import { CD } from '../../../components/modals/cdrom-vm-modal/types';
 
 const getNextAvailableBootOrderIndex = (vm: VMLikeEntityKind) => {
   const sortedBootableDevices = getBootableDevicesInOrder(vm);
@@ -60,7 +58,7 @@ export const getCDsPatch = async (vm: VMLikeEntityKind, cds: CD[]) => {
       const disk: CD = {
         name,
         bootOrder: existingCD ? bootOrder : newBootOrder,
-        cdrom: { bus: bus || 'virtio' },
+        cdrom: { bus: bus || DiskBus.SATA.getValue() },
       };
       let volume: Volume = { name };
       let finalDataVolume;
@@ -95,16 +93,15 @@ export const getCDsPatch = async (vm: VMLikeEntityKind, cds: CD[]) => {
           },
         };
 
-        const dataVolumeWrapper = DataVolumeWrapper.initialize(newDataVolume);
+        const dataVolumeWrapper = new MutableDataVolumeWrapper(newDataVolume);
         const storageClassName = dataVolumeWrapper.getStorageClassName();
 
-        finalDataVolume = DataVolumeWrapper.mergeWrappers(
-          DataVolumeWrapper.initializeFromSimpleData({
-            accessModes: [getDefaultSCAccessMode(storageClassConfigMap, storageClassName)],
-            volumeMode: getDefaultSCVolumeMode(storageClassConfigMap, storageClassName),
-          }),
-          dataVolumeWrapper,
-        ).asResource();
+        finalDataVolume = dataVolumeWrapper
+          .assertDefaultModes(
+            getDefaultSCVolumeMode(storageClassConfigMap, storageClassName),
+            getDefaultSCAccessModes(storageClassConfigMap, storageClassName),
+          )
+          .asMutableResource();
 
         volume = {
           name,
@@ -144,10 +141,12 @@ export const getCDsPatch = async (vm: VMLikeEntityKind, cds: CD[]) => {
       if (type !== StorageType.URL) {
         // remove unnecessary dataVolumeTemplates
         DATATEMPLATES = DATATEMPLATES.filter((dataVol) =>
-          VOLS.some((vol) => getVolumeDataVolumeName(vol) === getName(dataVol)),
+          includes(
+            VOLS.map((vol) => getVolumeDataVolumeName(vol)),
+            dataVol.metadata.name,
+          ),
         );
       }
-
       if (!existingCD) {
         newBootOrder++;
       }
