@@ -8,11 +8,12 @@ import {
   TEMPLATE_OS_NAME_ANNOTATION,
   TEMPLATE_WORKLOAD_LABEL,
 } from '../../constants/vm';
-import { V1Network, V1NetworkInterface, VMKind, VMLikeEntityKind, CPURaw } from '../../types';
+import { V1Network, V1NetworkInterface, VMKind, VMIKind, CPURaw } from '../../types';
 import { findKeySuffixValue, getSimpleName, getValueByPrefix } from '../utils';
 import { getAnnotations, getLabels } from '../selectors';
 import { NetworkWrapper } from '../../k8s/wrapper/vm/network-wrapper';
 import { getDataVolumeStorageSize, getDataVolumeStorageClassName } from '../dv/selectors';
+import { V1Disk } from '../../types/vm/disk/V1Disk';
 import { getDiskBus } from './disk';
 import {
   getVolumeContainerImage,
@@ -20,37 +21,57 @@ import {
   getVolumeCloudInitNoCloud,
 } from './volume';
 import { vCPUCount } from './cpu';
+import { getVMIDisks } from '../vmi/basic';
+import { VirtualMachineModel } from '../../models';
+import { V1Volume } from '../../types/vm/disk/V1Volume';
+import { VMGenericLikeEntityKind, VMILikeEntityKind } from '../../types/vmLike';
 
 export const getMemory = (vm: VMKind) =>
   _.get(vm, 'spec.template.spec.domain.resources.requests.memory');
 export const getCPU = (vm: VMKind): CPURaw => _.get(vm, 'spec.template.spec.domain.cpu');
-export const getDisks = (vm: VMKind, defaultValue = []) =>
+export const getResourcesRequestsCPUCount = (vm: VMKind): string =>
+  vm?.spec?.template?.spec?.domain?.resources?.requests?.cpu;
+export const getResourcesLimitsCPUCount = (vm: VMKind): string =>
+  vm?.spec?.template?.spec?.domain?.resources?.limits?.cpu;
+export const isDedicatedCPUPlacement = (vm: VMKind) =>
+  _.get(vm, 'spec.template.spec.domain.cpu.dedicatedCpuPlacement');
+export const getDisks = (vm: VMKind, defaultValue: V1Disk[] = []): V1Disk[] =>
   _.get(vm, 'spec.template.spec.domain.devices.disks') == null
     ? defaultValue
     : vm.spec.template.spec.domain.devices.disks;
-export const getInterfaces = (vm: VMKind, defaultValue = []): V1NetworkInterface[] =>
+export const getInterfaces = (
+  vm: VMKind,
+  defaultValue: V1NetworkInterface[] = [],
+): V1NetworkInterface[] =>
   _.get(vm, 'spec.template.spec.domain.devices.interfaces') == null
     ? defaultValue
     : vm.spec.template.spec.domain.devices.interfaces;
 
-export const getNetworks = (vm: VMKind, defaultValue = []): V1Network[] =>
+export const getNetworks = (vm: VMKind, defaultValue: V1Network[] = []): V1Network[] =>
   _.get(vm, 'spec.template.spec.networks') == null ? defaultValue : vm.spec.template.spec.networks;
-export const getVolumes = (vm: VMKind, defaultValue = []) =>
+export const getVolumes = (vm: VMKind, defaultValue: V1Volume[] = []): V1Volume[] =>
   _.get(vm, 'spec.template.spec.volumes') == null ? defaultValue : vm.spec.template.spec.volumes;
 export const getDataVolumeTemplates = (vm: VMKind, defaultValue = []) =>
   _.get(vm, 'spec.dataVolumeTemplates') == null ? defaultValue : vm.spec.dataVolumeTemplates;
 
-export const getOperatingSystem = (vm: VMLikeEntityKind) =>
-  findKeySuffixValue(getLabels(vm), TEMPLATE_OS_LABEL);
-export const getOperatingSystemName = (vm: VMKind) =>
-  getValueByPrefix(getAnnotations(vm), `${TEMPLATE_OS_NAME_ANNOTATION}/${getOperatingSystem(vm)}`);
-export const getWorkloadProfile = (vm: VMLikeEntityKind) =>
+export const getOperatingSystem = (vmLike: VMGenericLikeEntityKind): string =>
+  findKeySuffixValue(getLabels(vmLike), TEMPLATE_OS_LABEL);
+export const getOperatingSystemName = (vmLike: VMGenericLikeEntityKind) =>
+  getValueByPrefix(
+    getAnnotations(vmLike),
+    `${TEMPLATE_OS_NAME_ANNOTATION}/${getOperatingSystem(vmLike)}`,
+  );
+
+export const getWorkloadProfile = (vm: VMGenericLikeEntityKind) =>
   findKeySuffixValue(getLabels(vm), TEMPLATE_WORKLOAD_LABEL);
-export const getFlavor = (vmLike: VMLikeEntityKind) =>
+export const getFlavor = (vmLike: VMGenericLikeEntityKind) =>
   findKeySuffixValue(getLabels(vmLike), TEMPLATE_FLAVOR_LABEL);
 
 export const isVMRunning = (value: VMKind) =>
-  _.get(value, 'spec.running', false) as VMKind['spec']['running'];
+  (_.get(value, 'spec.runStrategy', null) === null &&
+    _.get(value, 'spec.running', null) === true) ||
+  (_.get(value, 'spec.running', null) === null &&
+    _.get(value, 'spec.runStrategy', null) !== 'Halted');
 
 export const isVMReady = (value: VMKind) =>
   _.get(value, 'status.ready', false) as VMKind['status']['ready'];
@@ -81,7 +102,7 @@ export const getFlavorDescription = (vm: VMKind) => {
   return resourceStr || undefined;
 };
 
-export const getVMStatusConditions = (vm: VMKind) =>
+export const getVMStatusConditions = (vm: VMILikeEntityKind) =>
   _.get(vm, 'status.conditions', []) as VMKind['status']['conditions'];
 
 export const getCloudInitVolume = (vm: VMKind) => {
@@ -100,7 +121,10 @@ export const getCloudInitVolume = (vm: VMKind) => {
 export const hasAutoAttachPodInterface = (vm: VMKind, defaultValue = false) =>
   _.get(vm, 'spec.template.spec.domain.devices.autoattachPodInterface', defaultValue);
 
-export const getCDRoms = (vm: VMKind) => getDisks(vm).filter((device) => !!device.cdrom);
+export const getCDRoms = (vm: VMILikeEntityKind) =>
+  vm.kind === VirtualMachineModel.kind
+    ? getDisks(vm as VMKind).filter((device) => !!device.cdrom)
+    : getVMIDisks(vm as VMIKind).filter((device) => !!device.cdrom);
 
 export const getContainerImageByDisk = (vm: VMKind, name: string) =>
   getVolumeContainerImage(getVolumes(vm).find((vol) => name === vol.name));
