@@ -3,7 +3,7 @@ import { K8sResourceKind } from '@console/internal/module/k8s';
 import { VMIKind, VMKind } from '../../types/vm';
 import { getMigrationVMIName, isMigrating } from './selectors';
 
-export const findVMIMigration = (migrations: K8sResourceKind[], vmi: VMIKind | VMKind) => {
+export const findVMIMigration = (vmi: VMIKind | VMKind, migrations?: K8sResourceKind[]) => {
   if (!migrations) {
     return null;
   }
