@@ -7,7 +7,7 @@ import {
   getMigrationStatusPhase,
 } from '../../selectors/vmi-migration';
 import {
-  findVMPod,
+  findVMIPod,
   getVMImporterPods,
   getPodStatusPhase,
   getPodContainerStatuses,
@@ -18,6 +18,7 @@ import {
   isVMCreated,
   findConversionPod,
   getVMStatusConditions,
+  isVMI,
 } from '../../selectors/vm';
 import { getPodStatus } from '../pod/pod';
 import {
@@ -43,14 +44,17 @@ import {
   VM_STATUS_STOPPING,
   VM_STATUS_VMI_WAITING,
   VM_STATUS_UNKNOWN,
-  VM_SIMPLE_STATUS_OTHER,
   VM_STATUS_V2V_CONVERSION_PENDING,
   CONVERSION_PROGRESS_ANNOTATION,
   VM_STATUS_IMPORT_PENDING,
+  VM_STATUS_PAUSED,
 } from './constants';
 import { Status } from '..';
+import { isVMIPaused } from '../../selectors/vmi/basic';
+import { getPhase } from '@console/noobaa-storage-plugin/src/utils';
+import { VMILikeEntityKind } from '../../types/vmLike';
 
-const isBeingMigrated = (vm: VMKind, migrations?: K8sResourceKind[]): VMStatus => {
+const isBeingMigrated = (vm: VMILikeEntityKind, migrations?: K8sResourceKind[]): VMStatus => {
   const migration = findVMIMigration(vm, migrations);
   if (isMigrating(migration)) {
     return { status: VM_STATUS_MIGRATING, message: getMigrationStatusPhase(migration) };
@@ -58,7 +62,11 @@ const isBeingMigrated = (vm: VMKind, migrations?: K8sResourceKind[]): VMStatus =
   return NOT_HANDLED;
 };
 
-const isBeingStopped = (vm: VMKind, launcherPod: PodKind = null): VMStatus => {
+const isBeingStopped = (vm: VMILikeEntityKind, launcherPod: PodKind = null): VMStatus => {
+  if (isVMI(vm)) {
+    return NOT_HANDLED;
+  }
+
   if (isVMReady(vm) || isVMCreated(vm)) {
     const podStatus = getPodStatus(launcherPod);
     const containerStatuses = getPodContainerStatuses(launcherPod);
@@ -83,8 +91,7 @@ const isBeingStopped = (vm: VMKind, launcherPod: PodKind = null): VMStatus => {
   return NOT_HANDLED;
 };
 
-const isRunning = (vm: VMKind): VMStatus =>
-  isVMRunning(vm) ? NOT_HANDLED : { status: VM_STATUS_OFF };
+const isOff = (vm: VMKind): VMStatus => (isVMRunning(vm) ? NOT_HANDLED : { status: VM_STATUS_OFF });
 
 const isReady = (vmi: VMIKind, launcherPod: PodKind): VMStatus => {
   if ((getStatusPhase(vmi) || '').toLowerCase() === 'running') {
@@ -97,7 +104,10 @@ const isReady = (vmi: VMIKind, launcherPod: PodKind): VMStatus => {
   return NOT_HANDLED;
 };
 
-const isVMError = (vm: VMKind): VMStatus => {
+const isPaused = (vmi: VMIKind): VMStatus =>
+  isVMIPaused(vmi) ? { status: VM_STATUS_PAUSED } : NOT_HANDLED;
+
+const isVMError = (vm: VMILikeEntityKind): VMStatus => {
   // is an issue with the VM definition?
   const condition = getVMStatusConditions(vm)[0];
   if (condition) {
@@ -109,7 +119,11 @@ const isVMError = (vm: VMKind): VMStatus => {
   return NOT_HANDLED;
 };
 
-const isCreated = (vm: VMKind, launcherPod: PodKind = null): VMStatus => {
+const isCreated = (vm: VMILikeEntityKind, launcherPod: PodKind = null): VMStatus => {
+  if (isVMI(vm)) {
+    return NOT_HANDLED;
+  }
+
   if (isVMCreated(vm)) {
     // created but not yet ready
     if (launcherPod) {
@@ -178,7 +192,7 @@ const isBeingImported = (vm: VMKind, pods?: PodKind[]): VMStatus => {
   return NOT_HANDLED;
 };
 
-const isV2VConversion = (vm: VMKind, pods?: PodKind[]): VMStatus => {
+const isV2VConversion = (vm: VMILikeEntityKind, pods?: PodKind[]): VMStatus => {
   const conversionPod = findConversionPod(vm, pods);
   const podPhase = getPodStatusPhase(conversionPod);
   if (conversionPod && podPhase !== POD_PHASE_SUCEEDED) {
@@ -231,36 +245,32 @@ export const getVMStatus = ({
   pods,
   migrations,
 }: {
-  vm: VMKind;
+  vm?: VMKind;
   vmi?: VMIKind;
   pods?: PodKind[];
   migrations?: K8sResourceKind[];
 }): VMStatus => {
-  const launcherPod = findVMPod(vm, pods);
+  const vmLike = vm || vmi;
+  const launcherPod = findVMIPod(vmi, pods);
   return (
-    isV2VConversion(vm, pods) || // these statuses must precede isRunning() because they do not rely on ready vms
-    isBeingMigrated(vm, migrations) || //  -||-
-    isBeingImported(vm, pods) || //  -||-
-    isBeingStopped(vm, launcherPod) ||
-    isRunning(vm) ||
+    isPaused(vmi) ||
+    isV2VConversion(vmLike, pods) || // these statuses must precede isRunning() because they do not rely on ready vms
+    isBeingMigrated(vmLike, migrations) || //  -||-
+    (vm && isBeingImported(vm, pods)) || //  -||-
+    isBeingStopped(vmLike, launcherPod) ||
+    (vm && isOff(vm)) ||
     isReady(vmi, launcherPod) ||
-    isVMError(vm) ||
-    isCreated(vm, launcherPod) ||
-    isWaitingForVMI(vm) || { status: VM_STATUS_UNKNOWN }
+    isVMError(vmLike) ||
+    isCreated(vmLike, launcherPod) ||
+    (!vmi && vm && isWaitingForVMI(vm)) ||
+    (getPhase(vmi) === 'Running' && { status: VM_STATUS_RUNNING }) ||
+    (['Scheduling', 'Scheduled'].includes(getPhase(vmi)) && { status: VM_STATUS_STARTING }) ||
+    (getPhase(vmi) === 'Pending' && { status: VM_STATUS_VMI_WAITING }) ||
+    (getPhase(vmi) === 'Failed' && { status: VM_STATUS_ERROR }) || { status: VM_STATUS_UNKNOWN }
   );
 };
 
-export const getSimpleVMStatus = (
-  vm: VMKind,
-  pods?: PodKind[],
-  migrations?: K8sResourceKind[],
-  vmi?: VMIKind,
-) => {
-  const vmStatus = getVMStatus({ vm, vmi, pods, migrations }).status;
-  return vmStatus === VM_STATUS_OFF || vmStatus === VM_STATUS_RUNNING
-    ? vmStatus
-    : VM_SIMPLE_STATUS_OTHER;
-};
+export const isVmOff = (vmStatus: VMStatus) => vmStatus.status === VM_STATUS_OFF;
 
 export type VMStatus = Status & {
   pod?: PodKind;
