@@ -14,7 +14,7 @@ import {
   getKind,
   getUID,
 } from '@console/shared/src/selectors';
-import { CPU } from '../types';
+import { VM_TEMPLATE_NAME_PARAMETER } from '../constants/vm-templates';
 
 export const getBasicID = <A extends K8sResourceKind = K8sResourceKind>(entity: A) =>
   `${getNamespace(entity)}-${getName(entity)}`;
@@ -57,18 +57,26 @@ export const getLoadError = (
   return null;
 };
 
+export const insertName = (value: string, name) => {
+  if (value.indexOf(VM_TEMPLATE_NAME_PARAMETER) > -1) {
+    return value.replace(VM_TEMPLATE_NAME_PARAMETER, name);
+  }
+  return joinIDs(name, value);
+};
+
 export const parseNumber = (value, defaultValue = null) =>
   _.isFinite(value) ? Number(value) : defaultValue;
 
 export const buildOwnerReference = (
   owner: K8sResourceKind,
-  blockOwnerDeletion = true,
+  opts: { blockOwnerDeletion?: boolean; controller?: boolean } = { blockOwnerDeletion: true },
 ): OwnerReference => ({
   apiVersion: getAPIVersion(owner),
   kind: getKind(owner),
   name: getName(owner),
   uid: getUID(owner),
-  blockOwnerDeletion,
+  blockOwnerDeletion: opts && opts.blockOwnerDeletion,
+  controller: opts && opts.controller,
 });
 
 export const buildOwnerReferenceForModel = (
@@ -82,31 +90,6 @@ export const buildOwnerReferenceForModel = (
   uid,
 });
 
-export const compareOwnerReference = (
-  obj: OwnerReference,
-  otherObj: OwnerReference,
-  compareModelOnly?: boolean,
-) => {
-  if (obj === otherObj) {
-    return true;
-  }
-  if (!obj || !otherObj) {
-    return false;
-  }
-  const isUIDEqual = obj.uid && otherObj.uid ? compareModelOnly || obj.uid === otherObj.uid : true;
-  const isNameEqual = compareModelOnly || obj.name === otherObj.name;
-
-  return (
-    obj.apiVersion === otherObj.apiVersion &&
-    obj.kind === otherObj.kind &&
-    isNameEqual &&
-    isUIDEqual
-  );
-};
-
-export const isCPUEqual = (a: CPU, b: CPU) =>
-  a.sockets === b.sockets && a.cores === b.cores && a.threads === b.threads;
-
 // FIXME: Avoid this helper! The implementation is not correct. We should remove this.
 export const getResource = (
   model: K8sResourceKind,
