@@ -1,6 +1,6 @@
 import { K8sKind } from '@console/internal/module/k8s';
 
-export const BaremetalHostModel: K8sKind = {
+export const BareMetalHostModel: K8sKind = {
   label: 'Bare Metal Host',
   labelPlural: 'Bare Metal Hosts',
   apiVersion: 'v1alpha1',
