@@ -18,7 +18,6 @@ import {
   ExternalLink,
   Firehose,
   HandlePromiseProps,
-  NsDropdown,
   RequestSizeInput,
   withHandlePromise,
 } from '@console/internal/components/utils';
@@ -29,11 +28,10 @@ import {
   K8sResourceKind,
 } from '@console/internal/module/k8s';
 import { ModalComponentProps } from '@console/internal/components/factory';
-import ResourceDropdown from '@console/dev-console/src/components/dropdown/ResourceDropdown';
+import { ResourceDropdown, getAPIVersion, getName } from '@console/shared';
 import { SecretModel } from '@console/internal/models';
 import { DashboardCardPopupLink } from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardLink';
 import { SecretType } from '@console/internal/components/secrets/create-secret';
-import { getAPIVersion, getName } from '@console/shared';
 import { history } from '@console/internal/components/utils/router';
 import { StorageClassDropdown } from '@console/internal/components/utils/storage-class-dropdown';
 import { NooBaaBackingStoreModel } from '../../models';
@@ -193,6 +191,12 @@ const PVCType: React.FC<PVCTypeProps> = ({ state, dispatch }) => {
     TiB: 'TiB',
   };
 
+  // Noobaa expected Ti console standrad is to show TiB
+  const unitConverter = {
+    GiB: 'Gi',
+    TiB: 'Ti',
+  };
+
   // Fix for updating the storage class by force rerender
   const forceUpdate = React.useCallback(() => updateState({}), []);
 
@@ -202,7 +206,7 @@ const PVCType: React.FC<PVCTypeProps> = ({ state, dispatch }) => {
 
   const onChange = (event) => {
     const { value, unit } = event;
-    const input = `${value} ${unit}`;
+    const input = `${value}${unitConverter[unit]}`;
     setSize(value);
     dispatch({ type: 'setVolumeSize', value: input });
   };
@@ -382,6 +386,20 @@ type Action =
   | { type: 'setVolumeSize'; value: string }
   | { type: 'setStorageClass'; value: string };
 
+type BSPayload = {
+  apiVersion: string;
+  kind: string;
+  metadata: {
+    namespace: string;
+    name: string;
+  };
+  spec: {
+    type: string;
+    ssl: boolean;
+    [key: string]: any;
+  };
+};
+
 const initialState: ProviderDataState = {
   secretName: '',
   secretKey: '',
@@ -391,7 +409,7 @@ const initialState: ProviderDataState = {
   target: '',
   endpoint: '',
   numVolumes: 1,
-  volumeSize: '',
+  volumeSize: '50Gi',
   storageClass: '',
 };
 
@@ -466,7 +484,6 @@ const secretPayloadCreator = (
 const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandlePromise<
   CreateBackingStoreFormProps & HandlePromiseProps
 >((props) => {
-  const [namespace, setNamespace] = React.useState(props.namespace);
   const [bsName, setBsName] = React.useState('');
   const [provider, setProvider] = React.useState(BC_PROVIDERS.AWS);
   const [providerDataState, providerDataDispatch] = React.useReducer(
@@ -474,7 +491,17 @@ const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandle
     initialState,
   );
 
-  const { cancel, className, close, inProgress, errorMessage, handlePromise, isPage, csv } = props;
+  const {
+    cancel,
+    className,
+    close,
+    inProgress,
+    errorMessage,
+    handlePromise,
+    isPage,
+    csv,
+    namespace,
+  } = props;
 
   const onSubmit = (event) => {
     event.preventDefault();
@@ -495,7 +522,7 @@ const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandle
       promises.push(k8sCreate(SecretModel, secretPayload));
     }
     /** Payload for bs */
-    const bsPayload = {
+    const bsPayload: BSPayload = {
       apiVersion: apiVersionForModel(NooBaaBackingStoreModel),
       kind: NooBaaBackingStoreModel.kind,
       metadata: {
@@ -512,6 +539,11 @@ const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandle
       bsPayload.spec['pvPool'] = {
         numVolumes: providerDataState.numVolumes,
         storageClass: providerDataState.storageClass,
+        resources: {
+          requests: {
+            storage: providerDataState.volumeSize,
+          },
+        },
       };
     } else if (externalProviders.includes(provider)) {
       bsPayload.spec = {
@@ -519,7 +551,7 @@ const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandle
         [PROVIDERS_NOOBAA_MAP[provider]]: {
           [BUCKET_LABEL_NOOBAA_MAP[provider]]: providerDataState.target,
           secret: {
-            name: providerDataState.secretName,
+            name: secretName,
             namespace,
           },
         },
@@ -535,8 +567,7 @@ const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandle
     }
     // Add region in the end
     if (provider === BC_PROVIDERS.AWS) {
-      // eslint-disable-next-line
-      bsPayload.spec['awsS3'] = { ...bsPayload.spec['awsS3'], region: providerDataState.region };
+      bsPayload.spec.awsS3 = { ...bsPayload.spec.awsS3, region: providerDataState.region };
     }
 
     promises.push(k8sCreate(NooBaaBackingStoreModel, bsPayload));
@@ -554,19 +585,11 @@ const CreateBackingStoreForm: React.FC<CreateBackingStoreFormProps> = withHandle
 
   return (
     <Form className={classNames('nb-bs-form', className)} onSubmit={onSubmit}>
-      <FormGroup label="Namespace" fieldId="namespace" className="nb-bs-form-entry" isRequired>
-        <NsDropdown
-          onChange={setNamespace}
-          selectedKey={namespace}
-          id="nb-bs-form__entry-namespace"
-        />
-      </FormGroup>
-
       <FormGroup
         label="Backing Store Name"
         fieldId="backingstore-name"
         className="nb-bs-form-entry"
-        helperText="If not provided, a generic name will be generated."
+        helperText="A unique name for the Backing Store within the project"
         isRequired
       >
         <TextInput
