@@ -3,6 +3,7 @@ import { shallow, ShallowWrapper, mount, ReactWrapper } from 'enzyme';
 import { Link } from 'react-router-dom';
 import * as _ from 'lodash';
 import { CardHeader, CardBody, CardFooter } from '@patternfly/react-core';
+import { ErrorBoundary } from '@console/shared/src/components/error/error-boundary';
 import {
   DetailsPage,
   TableInnerProps,
@@ -14,7 +15,6 @@ import {
   Timestamp,
   ResourceLink,
   ResourceKebab,
-  ErrorBoundary,
   ScrollToTopOnMount,
   SectionHeading,
   resourceObjPath,
@@ -30,8 +30,8 @@ import {
   testCatalogSource,
   testInstallPlan,
 } from '../../mocks';
-import { ClusterServiceVersionModel, SubscriptionModel } from '../models';
-import { ClusterServiceVersionKind, CSVConditionReason } from '../types';
+import { ClusterServiceVersionModel, SubscriptionModel, CatalogSourceModel } from '../models';
+import { ClusterServiceVersionKind, ClusterServiceVersionPhase } from '../types';
 import {
   ClusterServiceVersionsDetailsPage,
   ClusterServiceVersionsDetailsPageProps,
@@ -48,7 +48,7 @@ import {
   CSVSubscription,
   CSVSubscriptionProps,
 } from './clusterserviceversion';
-import { SubscriptionUpdates } from './subscription';
+import { SubscriptionUpdates, SubscriptionDetails } from './subscription';
 import {
   ClusterServiceVersionLogo,
   ClusterServiceVersionLogoProps,
@@ -99,7 +99,7 @@ describe(ClusterServiceVersionTableRow.displayName, () => {
     expect(col.find(ResourceKebab).props().kind).toEqual(
       referenceForModel(ClusterServiceVersionModel),
     );
-    expect(col.find(ResourceKebab).props().actions.length).toEqual(3);
+    expect(col.find(ResourceKebab).props().actions.length).toEqual(2);
   });
 
   it('renders clickable column for app logo and name', () => {
@@ -128,7 +128,7 @@ describe(ClusterServiceVersionTableRow.displayName, () => {
   });
 
   it('renders column with link to Operator deployment', () => {
-    const col = wrapper.find(TableRow).childAt(2);
+    const col = wrapper.find(TableRow).childAt(3);
 
     expect(col.find(ResourceLink).props().kind).toEqual('Deployment');
     expect(col.find(ResourceLink).props().name).toEqual(
@@ -137,10 +137,10 @@ describe(ClusterServiceVersionTableRow.displayName, () => {
   });
 
   it('renders column for app status', () => {
-    const col = wrapper.find(TableRow).childAt(3);
-    const statusComponent = col.childAt(0).find('SuccessStatus');
+    const col = wrapper.find(TableRow).childAt(2);
+    const statusComponent = col.childAt(0).find('ClusterServiceVersionStatus');
     expect(statusComponent.exists()).toBeTruthy();
-    expect(statusComponent.prop('title')).toEqual(CSVConditionReason.CSVReasonInstallSuccessful);
+    expect(statusComponent.render().text()).toContain(ClusterServiceVersionPhase.CSVPhaseSucceeded);
   });
 
   it('renders "disabling" status if CSV has `deletionTimestamp`', () => {
@@ -149,9 +149,15 @@ describe(ClusterServiceVersionTableRow.displayName, () => {
         k === 'metadata' ? { ...v, deletionTimestamp: Date.now() } : undefined,
       ),
     });
-    const col = wrapper.find(TableRow).childAt(3);
+    const col = wrapper.find(TableRow).childAt(2);
 
-    expect(col.childAt(0).text()).toEqual('Disabling');
+    expect(
+      col
+        .childAt(0)
+        .find('ClusterServiceVersionStatus')
+        .render()
+        .text(),
+    ).toEqual('Deleting');
   });
 
   it('renders column with each CRD provided by the Operator', () => {
@@ -192,9 +198,7 @@ describe(ClusterServiceVersionLogo.displayName, () => {
     const image: ReactWrapper<React.ImgHTMLAttributes<any>> = wrapper.find('img');
 
     expect(image.props().src).toEqual(
-      `data:${testClusterServiceVersion.spec.icon[0].mediatype};base64,${
-        testClusterServiceVersion.spec.icon[0].base64data
-      }`,
+      `data:${testClusterServiceVersion.spec.icon[0].mediatype};base64,${testClusterServiceVersion.spec.icon[0].base64data}`,
     );
   });
 
@@ -249,9 +253,18 @@ describe(ClusterServiceVersionsPage.displayName, () => {
       {
         kind: referenceForModel(ClusterServiceVersionModel),
         namespace: 'foo',
-        prop: 'clusterServiceVersion',
+        prop: 'clusterServiceVersions',
+      },
+      {
+        kind: referenceForModel(SubscriptionModel),
+        prop: 'subscriptions',
+        optional: true,
+      },
+      {
+        kind: referenceForModel(CatalogSourceModel),
+        prop: 'catalogSources',
+        optional: true,
       },
-      { kind: referenceForModel(SubscriptionModel), optional: true, prop: 'subscription' },
     ]);
     expect(listPage.props().ListComponent).toEqual(ClusterServiceVersionList);
     expect(listPage.props().showTitle).toBe(false);
@@ -410,7 +423,7 @@ describe(ClusterServiceVersionDetails.displayName, () => {
         .at(1)
         .find(SectionHeading)
         .props().text,
-    ).toEqual('ClusterServiceVersion Overview');
+    ).toEqual('ClusterServiceVersion Details');
   });
 
   it('renders conditions section for ClusterServiceVersion', () => {
@@ -461,10 +474,14 @@ describe(CSVSubscription.displayName, () => {
       />,
     );
 
-    expect(wrapper.find(StatusBox).props().data).toEqual(subscription);
-    expect(wrapper.find(SubscriptionUpdates).props().obj).toEqual(subscription);
-    expect(wrapper.find(SubscriptionUpdates).props().installedCSV).toEqual(obj);
-    expect(wrapper.find(SubscriptionUpdates).props().pkg).toEqual(testPackageManifest);
+    const subscriptionUpdates = wrapper
+      .find(StatusBox)
+      .find(SubscriptionDetails)
+      .dive()
+      .find(SubscriptionUpdates);
+    expect(subscriptionUpdates.props().obj).toEqual(subscription);
+    expect(subscriptionUpdates.props().installedCSV).toEqual(obj);
+    expect(subscriptionUpdates.props().pkg).toEqual(testPackageManifest);
   });
 
   it('passes the matching `PackageManifest` if there are multiple with the same `metadata.name`', () => {
@@ -490,7 +507,14 @@ describe(CSVSubscription.displayName, () => {
       />,
     );
 
-    expect(wrapper.find(SubscriptionUpdates).props().pkg).toEqual(testPackageManifest);
+    expect(
+      wrapper
+        .find(StatusBox)
+        .find(SubscriptionDetails)
+        .dive()
+        .find(SubscriptionUpdates)
+        .props().pkg,
+    ).toEqual(testPackageManifest);
   });
 });
 
@@ -519,7 +543,7 @@ describe(ClusterServiceVersionsDetailsPage.displayName, () => {
   it('renders a `DetailsPage` with the correct subpages', () => {
     const detailsPage = wrapper.find(DetailsPage);
 
-    expect(detailsPage.props().pagesFor(testClusterServiceVersion)[0].name).toEqual('Overview');
+    expect(detailsPage.props().pagesFor(testClusterServiceVersion)[0].name).toEqual('Details');
     expect(detailsPage.props().pagesFor(testClusterServiceVersion)[0].href).toEqual('');
     expect(detailsPage.props().pagesFor(testClusterServiceVersion)[0].component).toEqual(
       ClusterServiceVersionDetails,
