@@ -2,23 +2,30 @@ import * as React from 'react';
 import * as _ from 'lodash';
 import { Helmet } from 'react-helmet';
 import { match } from 'react-router';
-import { ActionGroup, Alert, Button, Tooltip } from '@patternfly/react-core';
+import { ActionGroup, Alert, Button, Checkbox, Tooltip } from '@patternfly/react-core';
 import {
+  Dropdown,
+  ExternalLink,
   Firehose,
   history,
   NsDropdown,
+  openshiftHelpBase,
   BreadCrumbs,
   MsgBox,
   StatusBox,
+  ResourceIcon,
+  ResourceName,
   resourceListPathFromModel,
 } from '@console/internal/components/utils';
 import {
-  referenceForModel,
-  k8sCreate,
+  K8sResourceCommon,
   apiVersionForModel,
-  kindForReference,
   apiVersionForReference,
+  k8sCreate,
+  k8sGet,
   k8sListPartialMetadata,
+  kindForReference,
+  referenceForModel,
 } from '@console/internal/module/k8s';
 import { RadioGroup, RadioInput } from '@console/internal/components/radio';
 import { fromRequirements } from '@console/internal/module/k8s/selector';
@@ -28,6 +35,7 @@ import {
   PackageManifestModel,
   ClusterServiceVersionModel,
 } from '../../models';
+import { NamespaceModel, RoleBindingModel, RoleModel } from '@console/internal/models';
 import {
   OperatorGroupKind,
   PackageManifestKind,
@@ -52,6 +60,12 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
   const [updateChannel, setUpdateChannel] = React.useState(null);
   const [approval, setApproval] = React.useState(InstallPlanApproval.Automatic);
   const [cannotResolve, setCannotResolve] = React.useState(false);
+  const [suggestedNamespaceExists, setSuggestedNamespaceExists] = React.useState(false);
+  const [
+    useSuggestedNSForSingleInstallMode,
+    setUseSuggestedNSForSingleInstallMode,
+  ] = React.useState(true);
+  const [enableMonitoring, setEnableMonitoring] = React.useState(false);
   const [error, setError] = React.useState('');
 
   const { name: pkgName } = props.packageManifest.data[0].metadata;
@@ -73,27 +87,58 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
           : preferredInstallMode,
       InstallModeType.InstallModeTypeOwnNamespace,
     );
+
+  const { currentCSVDesc } = channels.find((ch) => ch.name === selectedUpdateChannel);
+  const { installModes = [] } = currentCSVDesc;
+  const suggestedNamespace =
+    currentCSVDesc.annotations?.['operatorframework.io/suggested-namespace'];
+  const operatorRequestsMonitoring =
+    currentCSVDesc.annotations?.['operatorframework.io/cluster-monitoring'] === 'true';
+
+  const globalNS =
+    (props.operatorGroup?.data || ([] as OperatorGroupKind[])).find(
+      (og) => og.metadata.name === 'global-operators',
+    )?.metadata?.namespace || 'openshift-operators';
+  const items = {
+    [globalNS]: <ResourceName kind="Project" name={globalNS} />,
+  };
+
   let selectedTargetNamespace = targetNamespace || props.targetNamespace;
   if (selectedInstallMode === InstallModeType.InstallModeTypeAllNamespaces) {
-    selectedTargetNamespace = _.get(props.operatorGroup, 'data', [] as OperatorGroupKind[]).find(
-      (og) => og.metadata.name === 'global-operators',
-    ).metadata.namespace;
+    if (suggestedNamespace) {
+      items[suggestedNamespace] = (
+        <ResourceName kind="Project" name={`${suggestedNamespace} (Operator recommended)`} />
+      );
+      selectedTargetNamespace = targetNamespace || suggestedNamespace;
+    } else {
+      selectedTargetNamespace = globalNS;
+    }
   }
+  const isSuggestedNamespaceSelected =
+    suggestedNamespace && suggestedNamespace === selectedTargetNamespace;
   const selectedApproval = approval || InstallPlanApproval.Automatic;
 
   React.useEffect(() => {
-    if (selectedTargetNamespace) {
-      k8sListPartialMetadata(PackageManifestModel, {
-        ns: selectedTargetNamespace,
-        fieldSelector: `metadata.name=${pkgName}`,
-        labelSelector: fromRequirements([
-          { key: 'catalog', operator: 'Equals', values: [catalogSource] },
-          { key: 'catalog-namespace', operator: 'Equals', values: [catalogSourceNamespace] },
-        ]),
-      })
-        .then((list) => setCannotResolve(_.isEmpty(list)))
-        .catch(() => setCannotResolve(true));
+    if (!suggestedNamespace) {
+      return;
     }
+    setTargetNamespace(suggestedNamespace);
+    k8sGet(NamespaceModel, suggestedNamespace)
+      .then(() => setSuggestedNamespaceExists(true))
+      .catch(() => setSuggestedNamespaceExists(false));
+  }, [suggestedNamespace]);
+
+  React.useEffect(() => {
+    k8sListPartialMetadata(PackageManifestModel, {
+      ns: selectedTargetNamespace,
+      fieldSelector: `metadata.name=${pkgName}`,
+      labelSelector: fromRequirements([
+        { key: 'catalog', operator: 'Equals', values: [catalogSource] },
+        { key: 'catalog-namespace', operator: 'Equals', values: [catalogSourceNamespace] },
+      ]),
+    })
+      .then((list) => setCannotResolve(_.isEmpty(list)))
+      .catch(() => setCannotResolve(true));
   }, [
     catalogSource,
     catalogSourceNamespace,
@@ -102,7 +147,6 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
     selectedTargetNamespace,
   ]);
 
-  const { installModes } = channels.find((ch) => ch.name === selectedUpdateChannel).currentCSVDesc;
   const singleInstallMode = installModes.find(
     (m) => m.type === InstallModeType.InstallModeTypeOwnNamespace,
   );
@@ -156,9 +200,60 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
     return _.intersection(existingAPIs, providedAPIs);
   };
 
-  const submit = () => {
+  const submit = async () => {
     // Clear any previous errors.
     setError('');
+
+    const ns: K8sResourceCommon = {
+      metadata: {
+        name: selectedTargetNamespace,
+        labels:
+          operatorRequestsMonitoring && enableMonitoring
+            ? {
+                'openshift.io/cluster-monitoring': 'true',
+              }
+            : {},
+      },
+    };
+
+    const rbacName = `${selectedTargetNamespace}-prometheus`;
+    const prometheusRole = {
+      kind: RoleModel.kind,
+      apiVersion: `${RoleModel.apiGroup}/${RoleModel.apiVersion}`,
+      metadata: {
+        name: rbacName,
+        namespace: selectedTargetNamespace,
+      },
+      rules: [
+        {
+          apiGroups: [''],
+          resources: ['services', 'endpoints', 'pods'],
+          verbs: ['get', 'list', 'watch'],
+        },
+      ],
+    };
+
+    const prometheusRoleBinding = {
+      kind: RoleBindingModel.kind,
+      apiVersion: `${RoleBindingModel.apiGroup}/${RoleBindingModel.apiVersion}`,
+      metadata: {
+        name: rbacName,
+        namespace: selectedTargetNamespace,
+      },
+      roleRef: {
+        kind: 'Role',
+        name: rbacName,
+        apiGroup: RoleBindingModel.apiGroup,
+      },
+      subjects: [
+        {
+          kind: 'ServiceAccount',
+          name: 'prometheus-operator',
+          namespace: 'openshift-monitoring',
+        },
+      ],
+    };
+
     const operatorGroup: OperatorGroupKind = {
       apiVersion: apiVersionForModel(OperatorGroupModel) as OperatorGroupKind['apiVersion'],
       kind: 'OperatorGroup',
@@ -166,9 +261,13 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
         generateName: `${selectedTargetNamespace}-`,
         namespace: selectedTargetNamespace,
       },
-      spec: {
-        targetNamespaces: [selectedTargetNamespace],
-      },
+      ...(selectedInstallMode === InstallModeType.InstallModeTypeAllNamespaces
+        ? {}
+        : {
+            spec: {
+              targetNamespaces: [selectedTargetNamespace],
+            },
+          }),
     };
 
     const subscription: SubscriptionKind = {
@@ -188,22 +287,31 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
       },
     };
 
-    return (props.operatorGroup.data.some(
-      (group) => group.metadata.namespace === selectedTargetNamespace,
-    )
-      ? Promise.resolve()
-      : k8sCreate(OperatorGroupModel, operatorGroup)
-    )
-      .then(() => k8sCreate(SubscriptionModel, subscription))
-      .then(() =>
-        history.push(
-          resourceListPathFromModel(
-            ClusterServiceVersionModel,
-            targetNamespace || props.targetNamespace || selectedTargetNamespace,
-          ),
+    try {
+      if (isSuggestedNamespaceSelected && !suggestedNamespaceExists) {
+        await k8sCreate(NamespaceModel, ns);
+        if (operatorRequestsMonitoring && enableMonitoring) {
+          await k8sCreate(RoleModel, prometheusRole);
+          await k8sCreate(RoleBindingModel, prometheusRoleBinding);
+        }
+      }
+      if (
+        !props.operatorGroup.data.some(
+          (group) => group.metadata.namespace === selectedTargetNamespace,
+        )
+      ) {
+        await k8sCreate(OperatorGroupModel, operatorGroup);
+      }
+      await k8sCreate(SubscriptionModel, subscription);
+      history.push(
+        resourceListPathFromModel(
+          ClusterServiceVersionModel,
+          targetNamespace || props.targetNamespace || selectedTargetNamespace,
         ),
-      )
-      .catch(({ message = 'Could not create operator subscription.' }) => setError(message));
+      );
+    } catch (err) {
+      setError(err.message || 'Could not create operator subscription.');
+    }
   };
 
   const formValid = () =>
@@ -232,8 +340,14 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
           isInline
           className="co-alert"
           variant="danger"
-          title="Namespace does not support install modes for this Operator"
-        />
+          title="Namespace does not support installation mode"
+        >
+          The operator group in the {selectedTargetNamespace} namespace does not support the
+          {selectedInstallMode === InstallModeType.InstallModeTypeAllNamespaces
+            ? 'global'
+            : 'single namespace'}
+          installation mode.
+        </Alert>
       )) ||
       (subscriptionExists(selectedTargetNamespace) && (
         <Alert
@@ -267,6 +381,121 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
     );
   };
 
+  const showMonitoringCheckbox =
+    operatorRequestsMonitoring && _.startsWith(selectedTargetNamespace, 'openshift-');
+
+  const createNamespaceDetails = isSuggestedNamespaceSelected && !suggestedNamespaceExists && (
+    <>
+      <Alert
+        isInline
+        className="co-alert co-alert--scrollable"
+        variant="info"
+        title="Namespace creation"
+      >
+        Namespace <b>{suggestedNamespace}</b> does not exist and will be created.
+      </Alert>
+      {showMonitoringCheckbox && (
+        <div className="co-form-subsection">
+          <Checkbox
+            id="enable-monitoring-checkbox"
+            label="Enable operator recommended cluster monitoring on this namespace"
+            onChange={setEnableMonitoring}
+            isChecked={enableMonitoring}
+          />
+          {props.packageManifest.data[0].metadata.labels['opsrc-provider'] !== 'redhat' && (
+            <Alert
+              isInline
+              className="co-alert pf-c-alert--top-margin"
+              variant="warning"
+              title="Namespace monitoring"
+            >
+              Please note that installing non Red Hat operators into openshift namespaces and
+              enabling monitoring voids user support. Enabling cluster monitoring for non Red Hat
+              operators can lead to malicious metrics data overriding existing cluster metrics. For
+              more information, see the{' '}
+              <ExternalLink
+                href={`${openshiftHelpBase}monitoring/cluster-monitoring/configuring-the-monitoring-stack.html#maintenance-and-support_configuring-monitoring`}
+                text="cluster monitoring documentation"
+              />{' '}
+              .
+            </Alert>
+          )}
+        </div>
+      )}
+    </>
+  );
+
+  const globalNamespaceInstallMode = (
+    <>
+      <div className="form-group">
+        <Dropdown
+          id="dropdown-selectbox"
+          dropDownClassName="dropdown--full-width"
+          menuClassName="dropdown-menu--text-wrap"
+          items={items}
+          title={
+            <ResourceName
+              kind="Project"
+              name={
+                isSuggestedNamespaceSelected
+                  ? `${selectedTargetNamespace} (Operator recommended)`
+                  : selectedTargetNamespace
+              }
+            />
+          }
+          disabled={_.size(items) === 1}
+          selectedKey={selectedTargetNamespace}
+          onChange={(ns: string) => {
+            setTargetNamespace(ns);
+            setCannotResolve(false);
+          }}
+        />
+      </div>
+      {createNamespaceDetails}
+    </>
+  );
+
+  const singleNamespaceInstallMode = !suggestedNamespace ? (
+    <NsDropdown
+      id="dropdown-selectbox"
+      selectedKey={selectedTargetNamespace}
+      onChange={setTargetNamespace}
+    />
+  ) : (
+    <div className="form-group">
+      <RadioInput
+        onChange={() => {
+          setUseSuggestedNSForSingleInstallMode(true);
+          setTargetNamespace(suggestedNamespace);
+        }}
+        value={suggestedNamespace}
+        checked={useSuggestedNSForSingleInstallMode}
+        title="Operator recommended namespace:"
+      >
+        {' '}
+        <ResourceIcon kind="Project" />
+        <b>{suggestedNamespace}</b>
+      </RadioInput>
+      {useSuggestedNSForSingleInstallMode && createNamespaceDetails}
+      <RadioInput
+        onChange={() => {
+          setUseSuggestedNSForSingleInstallMode(false);
+          setTargetNamespace(null);
+        }}
+        value={suggestedNamespace}
+        checked={!useSuggestedNSForSingleInstallMode}
+        title="Pick an existing namespace"
+      />
+      {!useSuggestedNSForSingleInstallMode && (
+        <NsDropdown
+          id="dropdown-selectbox"
+          selectedKey={selectedTargetNamespace}
+          onChange={setTargetNamespace}
+        />
+      )}
+    </div>
+  );
+
   return (
     <div className="row">
       <div className="col-xs-6">
@@ -297,7 +526,9 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
               <RadioInput
                 onChange={(e) => {
                   setInstallMode(e.target.value);
-                  setTargetNamespace(null);
+                  setTargetNamespace(
+                    useSuggestedNSForSingleInstallMode ? suggestedNamespace : null,
+                  );
                   setCannotResolve(false);
                 }}
                 value={InstallModeType.InstallModeTypeOwnNamespace}
@@ -310,21 +541,16 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
                     {descFor(InstallModeType.InstallModeTypeOwnNamespace)}
                   </p>
                 </div>
-                {selectedInstallMode === InstallModeType.InstallModeTypeOwnNamespace && (
-                  <div style={{ marginLeft: '20px' }}>
-                    <NsDropdown
-                      id="dropdown-selectbox"
-                      selectedKey={selectedTargetNamespace}
-                      onChange={(ns: string) => {
-                        setTargetNamespace(ns);
-                        setCannotResolve(false);
-                      }}
-                    />
-                  </div>
-                )}
               </RadioInput>
             </div>
           </div>
+          <div className="form-group">
+            <h5 className="co-required">Installed Namespace</h5>
+            {selectedInstallMode === InstallModeType.InstallModeTypeAllNamespaces &&
+              globalNamespaceInstallMode}
+            {selectedInstallMode === InstallModeType.InstallModeTypeOwnNamespace &&
+              singleNamespaceInstallMode}
+          </div>
           <div className="form-group">
             <Tooltip content="The channel to track and receive the updates from.">
               <h5 className="co-required">Update Channel</h5>
@@ -335,8 +561,6 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
               onChange={(e) => {
                 setUpdateChannel(e.currentTarget.value);
                 setInstallMode(null);
-                setTargetNamespace(null);
-                setCannotResolve(false);
               }}
             />
           </div>
@@ -378,16 +602,11 @@ export const OperatorHubSubscribeForm: React.FC<OperatorHubSubscribeFormProps> =
           ) ? (
             <span className="text-muted">No Kubernetes APIs are provided by this Operator.</span>
           ) : (
-            providedAPIsForChannel(props.packageManifest.data[0])(selectedUpdateChannel).map(
-              (api) => (
-                <CRDCard
-                  key={referenceForProvidedAPI(api)}
-                  canCreate={false}
-                  crd={api}
-                  csv={null}
-                />
-              ),
-            )
+            providedAPIsForChannel(props.packageManifest.data[0])(
+              selectedUpdateChannel,
+            ).map((api) => (
+              <CRDCard key={referenceForProvidedAPI(api)} canCreate={false} crd={api} csv={null} />
+            ))
           )}
         </div>
       </div>
@@ -457,7 +676,7 @@ export const OperatorHubSubscribePage: React.SFC<OperatorHubSubscribePageProps>
         >
           {/* FIXME(alecmerdler): Hack because `Firehose` injects props without TypeScript knowing about it */}
           <OperatorHubSubscribe
-            {...props as any}
+            {...(props as any)}
             targetNamespace={
               new URLSearchParams(window.location.search).get('targetNamespace') || null
             }
