@@ -195,9 +195,7 @@ const menuActions = [
     const installedCSV = _.get(obj, 'status.installedCSV');
     return {
       label: `View ${ClusterServiceVersionModel.kind}...`,
-      href: `/k8s/ns/${obj.metadata.namespace}/${
-        ClusterServiceVersionModel.plural
-      }/${installedCSV}`,
+      href: `/k8s/ns/${obj.metadata.namespace}/${ClusterServiceVersionModel.plural}/${installedCSV}`,
       hidden: !installedCSV,
     };
   },
@@ -290,8 +288,6 @@ export const SubscriptionsPage: React.SFC<SubscriptionsPageProps> = (props) => {
       ]}
       flatten={(resources) => _.get(resources.subscription, 'data', [])}
       title="Subscriptions"
-      helpText="Operator Subscriptions keep your services up to date by tracking a channel in a package. The approval strategy determines either manual or automatic updates."
-      showTitle={false}
       canCreate
       createProps={{ to: '/operatorhub' }}
       createButtonText="Create Subscription"
@@ -337,7 +333,7 @@ export const SubscriptionDetails: React.FC<SubscriptionDetailsProps> = ({
           title={`${installStatusPhase}: ${installStatusMessage}`}
         />
       )}
-      <SectionHeading text="Subscription Overview" />
+      <SectionHeading text="Subscription Details" />
       <div className="co-m-pane__body-group">
         <SubscriptionUpdates
           catalogSource={catalogSource}
@@ -419,8 +415,8 @@ export class SubscriptionUpdates extends React.Component<
   static getDerivedStateFromProps(nextProps, prevState) {
     const stillWaiting =
       prevState.waitingForUpdate &&
-      (_.get(nextProps, 'obj.spec.channel') === prevState.channel &&
-        _.get(nextProps, 'obj.spec.installPlanApproval') === prevState.installPlanApproval);
+      _.get(nextProps, 'obj.spec.channel') === prevState.channel &&
+      _.get(nextProps, 'obj.spec.installPlanApproval') === prevState.installPlanApproval;
 
     return stillWaiting
       ? null
@@ -461,9 +457,15 @@ export class SubscriptionUpdates extends React.Component<
                 {this.state.waitingForUpdate ? (
                   <LoadingInline />
                 ) : (
-                  <Button type="button" isInline onClick={() => channelModal()} variant="link">
+                  <Button
+                    type="button"
+                    isInline
+                    onClick={channelModal}
+                    variant="link"
+                    isDisabled={!pkg}
+                  >
                     {obj.spec.channel || 'default'}
-                    <PencilAltIcon className="co-icon-space-l pf-c-button-icon--plain" />
+                    {pkg && <PencilAltIcon className="co-icon-space-l pf-c-button-icon--plain" />}
                   </Button>
                 )}
               </dd>
@@ -476,7 +478,7 @@ export class SubscriptionUpdates extends React.Component<
                 {this.state.waitingForUpdate ? (
                   <LoadingInline />
                 ) : (
-                  <Button type="button" isInline onClick={() => approvalModal()} variant="link">
+                  <Button type="button" isInline onClick={approvalModal} variant="link">
                     {obj.spec.installPlanApproval || 'Automatic'}
                     <PencilAltIcon className="co-icon-space-l pf-c-button-icon--plain" />
                   </Button>
@@ -579,7 +581,7 @@ export type SubscriptionsPageProps = {
 export type SubscriptionsListProps = {
   loaded: boolean;
   loadError?: string;
-  data: (SubscriptionKind)[];
+  data: SubscriptionKind[];
   operatorGroup: { loaded: boolean; data?: OperatorGroupKind[] };
 };
 
