@@ -1,9 +1,11 @@
 export * from './anchor-utils';
 export { default as ControllerContext } from './ControllerContext';
 export { default as ElementContext } from './ElementContext';
+export * from './element-utils';
 export * from './geom-utils';
 export * from './svg-utils';
 export { default as useCallbackRef } from './useCallbackRef';
 export { default as useCombineRefs } from './useCombineRefs';
 export { default as useHover } from './useHover';
 export * from './useSize';
+export * from './createAggregateEdges';
