@@ -1,18 +1,22 @@
 import { Base64 } from 'js-base64';
 import { action, ActionType as Action } from 'typesafe-actions';
+import * as _ from 'lodash-es';
 
 // FIXME(alecmerdler): Do not `import store`
 import store from '../redux';
 import { history } from '../components/utils/router';
+import { OverviewItem } from '@console/shared';
 import {
   ALL_NAMESPACES_KEY,
   LAST_NAMESPACE_NAME_LOCAL_STORAGE_KEY,
   LAST_PERSPECTIVE_LOCAL_STORAGE_KEY,
-} from '../const';
+} from '@console/shared/src/constants';
+import { K8sResourceKind, PodKind } from '../module/k8s';
 import { allModels } from '../module/k8s/k8s-models';
 import { detectFeatures, clearSSARFlags } from './features';
 import { OverviewSpecialGroup } from '../components/overview/constants';
-import { OverviewItem } from '@console/shared';
+import { setClusterID, setCreateProjectMessage, setUser, setConsoleLinks } from './common';
+
 export enum ActionType {
   DismissOverviewDetails = 'dismissOverviewDetails',
   SelectOverviewDetailsTab = 'selectOverviewDetailsTab',
@@ -22,8 +26,16 @@ export enum ActionType {
   SetActivePerspective = 'setActivePerspective',
   SetCreateProjectMessage = 'setCreateProjectMessage',
   SetCurrentLocation = 'setCurrentLocation',
+  MonitoringDashboardsClearVariables = 'monitoringDashboardsClearVariables',
+  MonitoringDashboardsPatchVariable = 'monitoringDashboardsPatchVariable',
+  MonitoringDashboardsPatchAllVariables = 'monitoringDashboardsPatchAllVariables',
+  MonitoringDashboardsSetPollInterval = 'monitoringDashboardsSetPollInterval',
+  MonitoringDashboardsSetTimespan = 'monitoringDashboardsSetTimespan',
+  MonitoringDashboardsVariableOptionsLoaded = 'monitoringDashboardsVariableOptionsLoaded',
   SetMonitoringData = 'setMonitoringData',
   ToggleMonitoringGraphs = 'monitoringToggleGraphs',
+  NotificationDrawerToggleExpanded = 'notificationDrawerExpanded',
+  NotificationDrawerToggleRead = 'notificationDrawerRead',
   QueryBrowserAddQuery = 'queryBrowserAddQuery',
   QueryBrowserDeleteAllQueries = 'queryBrowserDeleteAllQueries',
   QueryBrowserDeleteQuery = 'queryBrowserDeleteQuery',
@@ -47,8 +59,28 @@ export enum ActionType {
   UpdateOverviewFilterValue = 'updateOverviewFilterValue',
   UpdateTimestamps = 'updateTimestamps',
   SetConsoleLinks = 'setConsoleLinks',
+  SetPodMetrics = 'setPodMetrics',
+  SetNamespaceMetrics = 'setNamespaceMetrics',
 }
 
+type MetricValuesByName = {
+  [name: string]: number;
+};
+
+export type NamespaceMetrics = {
+  cpu: MetricValuesByName;
+  memory: MetricValuesByName;
+};
+
+type MetricValuesByNamespace = {
+  [namespace: string]: MetricValuesByName;
+};
+
+export type PodMetrics = {
+  cpu: MetricValuesByNamespace;
+  memory: MetricValuesByNamespace;
+};
+
 // URL routes that can be namespaced
 export const namespacedResources = new Set();
 
@@ -66,13 +98,14 @@ allModels().forEach((v, k) => {
 
 export const getActiveNamespace = (): string => store.getState().UI.get('activeNamespace');
 
-export const formatNamespacedRouteForResource = (
-  resource,
-  activeNamespace = getActiveNamespace(),
-) => {
-  return activeNamespace === ALL_NAMESPACES_KEY
-    ? `/k8s/all-namespaces/${resource}`
-    : `/k8s/ns/${activeNamespace}/${resource}`;
+export const getNamespaceMetric = (ns: K8sResourceKind, metric: string): number => {
+  const metrics = store.getState().UI.getIn(['metrics', 'namespace']);
+  return _.get(metrics, [metric, ns.metadata.name], 0);
+};
+
+export const getPodMetric = (pod: PodKind, metric: string): number => {
+  const metrics = store.getState().UI.getIn(['metrics', 'pod']);
+  return _.get(metrics, [metric, pod.metadata.namespace, pod.metadata.name], 0);
 };
 
 export const formatNamespaceRoute = (activeNamespace, originalPath, location?) => {
@@ -217,10 +250,6 @@ export const sortList = (
 
   return action(ActionType.SortList, { listId, field, func, sortAsNumber, orderBy });
 };
-export const setCreateProjectMessage = (message: string) =>
-  action(ActionType.SetCreateProjectMessage, { message });
-export const setClusterID = (clusterID: string) => action(ActionType.SetClusterID, { clusterID });
-export const setUser = (user: any) => action(ActionType.SetUser, { user });
 export const selectOverviewItem = (uid: string) => action(ActionType.SelectOverviewItem, { uid });
 export const selectOverviewDetailsTab = (tab: string) =>
   action(ActionType.SelectOverviewDetailsTab, { tab });
@@ -237,16 +266,33 @@ export const updateOverviewLabels = (labels: string[]) =>
   action(ActionType.UpdateOverviewLabels, { labels });
 export const updateOverviewFilterValue = (value: string) =>
   action(ActionType.UpdateOverviewFilterValue, { value });
-export const monitoringLoading = (key: 'alerts' | 'silences') =>
+export const monitoringDashboardsClearVariables = () =>
+  action(ActionType.MonitoringDashboardsClearVariables);
+export const monitoringDashboardsPatchVariable = (key: string, patch: any) =>
+  action(ActionType.MonitoringDashboardsPatchVariable, { key, patch });
+export const monitoringDashboardsPatchAllVariables = (variables: any) =>
+  action(ActionType.MonitoringDashboardsPatchAllVariables, { variables });
+export const monitoringDashboardsSetPollInterval = (pollInterval: number) =>
+  action(ActionType.MonitoringDashboardsSetPollInterval, { pollInterval });
+export const monitoringDashboardsSetTimespan = (timespan: number) =>
+  action(ActionType.MonitoringDashboardsSetTimespan, { timespan });
+export const monitoringDashboardsVariableOptionsLoaded = (key: string, newOptions: string[]) =>
+  action(ActionType.MonitoringDashboardsVariableOptionsLoaded, { key, newOptions });
+export const monitoringLoading = (key: 'alerts' | 'silences' | 'notificationAlerts') =>
   action(ActionType.SetMonitoringData, {
     key,
     data: { loaded: false, loadError: null, data: null },
   });
-export const monitoringLoaded = (key: 'alerts' | 'silences', data: any) =>
+export const monitoringLoaded = (key: 'alerts' | 'silences' | 'notificationAlerts', data: any) =>
   action(ActionType.SetMonitoringData, { key, data: { loaded: true, loadError: null, data } });
-export const monitoringErrored = (key: 'alerts' | 'silences', loadError: any) =>
-  action(ActionType.SetMonitoringData, { key, data: { loaded: true, loadError, data: null } });
+export const monitoringErrored = (
+  key: 'alerts' | 'silences' | 'notificationAlerts',
+  loadError: any,
+) => action(ActionType.SetMonitoringData, { key, data: { loaded: true, loadError, data: null } });
 export const monitoringToggleGraphs = () => action(ActionType.ToggleMonitoringGraphs);
+export const notificationDrawerToggleExpanded = () =>
+  action(ActionType.NotificationDrawerToggleExpanded);
+export const notificationDrawerToggleRead = () => action(ActionType.NotificationDrawerToggleRead);
 export const queryBrowserAddQuery = () => action(ActionType.QueryBrowserAddQuery);
 export const queryBrowserDeleteAllQueries = () => action(ActionType.QueryBrowserDeleteAllQueries);
 export const queryBrowserDismissNamespaceAlert = () =>
@@ -275,8 +321,10 @@ export const queryBrowserToggleIsEnabled = (index: number) =>
 export const queryBrowserToggleSeries = (index: number, labels: { [key: string]: unknown }) => {
   return action(ActionType.QueryBrowserToggleSeries, { index, labels });
 };
-export const setConsoleLinks = (consoleLinks: string[]) =>
-  action(ActionType.SetConsoleLinks, { consoleLinks });
+export const setPodMetrics = (podMetrics: PodMetrics) =>
+  action(ActionType.SetPodMetrics, { podMetrics });
+export const setNamespaceMetrics = (namespaceMetrics: NamespaceMetrics) =>
+  action(ActionType.SetNamespaceMetrics, { namespaceMetrics });
 
 // TODO(alecmerdler): Implement all actions using `typesafe-actions` and add them to this export
 const uiActions = {
@@ -299,6 +347,12 @@ const uiActions = {
   updateOverviewSelectedGroup,
   updateOverviewLabels,
   updateOverviewFilterValue,
+  monitoringDashboardsClearVariables,
+  monitoringDashboardsPatchVariable,
+  monitoringDashboardsPatchAllVariables,
+  monitoringDashboardsSetPollInterval,
+  monitoringDashboardsSetTimespan,
+  monitoringDashboardsVariableOptionsLoaded,
   monitoringLoading,
   monitoringLoaded,
   monitoringErrored,
@@ -315,6 +369,10 @@ const uiActions = {
   queryBrowserToggleIsEnabled,
   queryBrowserToggleSeries,
   setConsoleLinks,
+  setPodMetrics,
+  setNamespaceMetrics,
+  notificationDrawerToggleExpanded,
+  notificationDrawerToggleRead,
 };
 
 export type UIAction = Action<typeof uiActions>;
