@@ -175,7 +175,7 @@ export const PipelineBuildStrategyAlert: React.FC<BuildsDetailsProps> = () => {
     <Alert isInline className="co-alert" variant="info" title="Pipeline build strategy deprecation">
       With the release of{' '}
       <ExternalLink
-        href="https://openshift.github.io/pipelines-docs/docs/"
+        href="https://openshift.github.io/pipelines-docs/"
         text="OpenShift Pipelines based on Tekton"
       />
       , the pipelines build strategy has been deprecated. Users should either use Jenkins files
@@ -198,7 +198,7 @@ export const BuildsDetails: React.SFC<BuildsDetailsProps> = ({ obj: build }) =>
     <>
       <div className="co-m-pane__body">
         {hasPipeline && <PipelineBuildStrategyAlert obj={build} />}
-        <SectionHeading text="Build Overview" />
+        <SectionHeading text="Build Details" />
         <BuildGraphs build={build} />
         {hasPipeline && (
           <div className="row">
