@@ -17,7 +17,6 @@ import {
 } from './utils';
 
 const { common } = Kebab.factory;
-const menuActions = [...Kebab.getExtensionsActionsForKind(), ...common];
 
 const tableColumnClasses = [
   classNames('col-xs-6', 'col-sm-4'),
@@ -55,6 +54,9 @@ const TableHeader = () => {
 TableHeader.displayName = 'TableHeader';
 
 const TableRowForKind = ({ obj, index, key, style, customData }) => {
+  const kind = referenceFor(obj) || customData.kind;
+  const menuActions = [...Kebab.getExtensionsActionsForKind(kindObj(kind)), ...common];
+
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -80,11 +82,7 @@ const TableRowForKind = ({ obj, index, key, style, customData }) => {
         {fromNow(obj.metadata.creationTimestamp)}
       </TableData>
       <TableData className={tableColumnClasses[3]}>
-        <ResourceKebab
-          actions={menuActions}
-          kind={referenceFor(obj) || customData.kind}
-          resource={obj}
-        />
+        <ResourceKebab actions={menuActions} kind={kind} resource={obj} />
       </TableData>
     </TableRow>
   );
@@ -93,17 +91,16 @@ TableRowForKind.displayName = 'TableRowForKind';
 
 const DetailsForKind = (kind) =>
   function DetailsForKind_({ obj }) {
-    const conditions = obj.status && obj.status.conditions;
     return (
       <>
         <div className="co-m-pane__body">
-          <SectionHeading text={`${kindForReference(kind)} Overview`} />
+          <SectionHeading text={`${kindForReference(kind)} Details`} />
           <ResourceSummary resource={obj} podSelector="spec.podSelector" showNodeSelector={false} />
         </div>
-        {conditions && (
+        {_.isArray(obj?.status?.conditions) && (
           <div className="co-m-pane__body">
             <SectionHeading text="Conditions" />
-            <Conditions conditions={conditions} />
+            <Conditions conditions={obj.status.conditions} />
           </div>
         )}
       </>
@@ -125,7 +122,7 @@ export const DefaultList = (props) => {
     />
   );
 };
-DefaultList.displayName = DefaultList;
+DefaultList.displayName = 'DefaultList';
 
 export const DefaultPage = (props) => (
   <ListPage
@@ -138,6 +135,8 @@ DefaultPage.displayName = 'DefaultPage';
 
 export const DefaultDetailsPage = (props) => {
   const pages = [navFactory.details(DetailsForKind(props.kind)), navFactory.editYaml()];
+  const menuActions = [...Kebab.getExtensionsActionsForKind(kindObj(props.kind)), ...common];
+
   return <DetailsPage {...props} menuActions={menuActions} pages={pages} />;
 };
 DefaultDetailsPage.displayName = 'DefaultDetailsPage';
