@@ -12,12 +12,17 @@ import {
   global_BackgroundColor_300 as lineNumberForeground,
   global_BackgroundColor_dark_100 as editorBackground,
 } from '@patternfly/react-tokens';
-import { getBadgeFromType, Shortcut, ShortcutTable } from '@console/shared';
+import {
+  FLAGS,
+  ALL_NAMESPACES_KEY,
+  getBadgeFromType,
+  Shortcut,
+  ShortcutTable,
+} from '@console/shared';
 
 import { connectToFlags } from '../reducers/features';
 import { errorModal } from './modals';
 import { Firehose, checkAccess, history, Loading, resourceObjPath } from './utils';
-import { FLAGS, ALL_NAMESPACES_KEY } from '../const';
 import {
   referenceForModel,
   k8sCreate,
@@ -78,8 +83,8 @@ const desktopGutter = 30;
  * This component loads the entire Monaco editor library with it.
  * Consider using `AsyncComponent` to dynamically load this component when needed.
  */
-/** @augments {React.Component<{obj?: any, create: boolean, kind: string, redirectURL?: string, resourceObjPath?: (obj: K8sResourceKind, objRef: string) => string}>} */
-const EditYAML_ = connect(stateToProps)(
+/** @augments {React.Component<{obj?: any, create: boolean, kind: string, redirectURL?: string, resourceObjPath?: (obj: K8sResourceKind, objRef: string) => string}, onChange?: (yaml: string) => void>} */
+export const EditYAML_ = connect(stateToProps)(
   class EditYAML extends React.Component {
     constructor(props) {
       super(props);
@@ -106,6 +111,7 @@ const EditYAML_ = connect(stateToProps)(
       this.onCancel = 'onCancel' in props ? props.onCancel : history.goBack;
       this.downloadSampleYaml_ = this.downloadSampleYaml_.bind(this);
       this.editorDidMount = this.editorDidMount.bind(this);
+      this.buttons = this.props.buttonsRef;
 
       if (this.props.error) {
         this.handleError(this.props.error);
@@ -138,17 +144,15 @@ const EditYAML_ = connect(stateToProps)(
     componentDidMount() {
       this.loadYaml();
       window.addEventListener('resize', this.resize);
-      window.addEventListener('nav_toggle', this.resize);
       window.addEventListener('sidebar_toggle', this.resize);
     }
 
     componentWillUnmount() {
       window.removeEventListener('resize', this.resize);
-      window.removeEventListener('nav_toggle', this.resize);
       window.removeEventListener('sidebar_toggle', this.resize);
     }
 
-    componentWillReceiveProps(nextProps) {
+    UNSAFE_componentWillReceiveProps(nextProps) {
       if (nextProps.isOver) {
         return;
       }
@@ -182,7 +186,7 @@ const EditYAML_ = connect(stateToProps)(
     }
 
     get editorHeight() {
-      const buttonsHeight = this.buttons.getBoundingClientRect().height;
+      const buttonsHeight = this.buttons ? this.buttons.getBoundingClientRect().height : 0;
       // if viewport width is > 767, also subtract top padding on .yaml-editor
       return isDesktop()
         ? Math.floor(this.height - buttonsHeight - desktopGutter)
@@ -215,7 +219,8 @@ const EditYAML_ = connect(stateToProps)(
 
     // Unfortunately, `editor.focus()` doesn't work when hiding the shortcuts
     // popover. We need to find the actual DOM element.
-    focusEditor = () => setTimeout(() => document.querySelector('.monaco-editor textarea').focus());
+    focusEditor = () =>
+      setTimeout(() => document.querySelector('.monaco-editor textarea')?.focus());
 
     reload() {
       this.loadYaml(true);
@@ -332,7 +337,14 @@ const EditYAML_ = connect(stateToProps)(
     }
 
     save() {
+      const { onSave } = this.props;
       let obj;
+
+      if (onSave) {
+        onSave(this.getEditor().getValue());
+        return;
+      }
+
       try {
         obj = safeLoad(this.getEditor().getValue());
       } catch (e) {
@@ -353,9 +365,7 @@ const EditYAML_ = connect(stateToProps)(
       const model = this.getModel(obj);
       if (!model) {
         this.handleError(
-          `The server doesn't have a resource type "kind: ${obj.kind}, apiVersion: ${
-            obj.apiVersion
-          }".`,
+          `The server doesn't have a resource type "kind: ${obj.kind}, apiVersion: ${obj.apiVersion}".`,
         );
         return;
       }
@@ -388,9 +398,7 @@ const EditYAML_ = connect(stateToProps)(
         }
         if (this.props.obj.kind !== obj.kind) {
           this.handleError(
-            `Cannot change resource kind (original: "${this.props.obj.kind}", updated: "${
-              obj.kind
-            }").`,
+            `Cannot change resource kind (original: "${this.props.obj.kind}", updated: "${obj.kind}").`,
           );
           return;
         }
@@ -454,10 +462,12 @@ const EditYAML_ = connect(stateToProps)(
         const sampleObj = generateObjToLoad(kind, id, yaml, this.props.obj.metadata.namespace);
         this.setState({ sampleObj });
         return sampleObj;
-      } catch ({ message, name }) {
+      } catch (error) {
         errorModal({
           title: 'Failed to Parse YAML Sample',
-          error: <div className="co-pre-line">{message || name || 'An error occurred.'}</div>,
+          error: (
+            <div className="co-pre-line">{error.message || error.name || 'An error occurred.'}</div>
+          ),
         });
       }
     }
@@ -679,13 +689,28 @@ const EditYAML_ = connect(stateToProps)(
         return <Loading />;
       }
 
-      const { connectDropTarget, isOver, canDrop, create, yamlSamplesList } = this.props;
+      const {
+        connectDropTarget,
+        isOver,
+        canDrop,
+        create,
+        yamlSamplesList,
+        customClass,
+        onChange = () => null,
+        hideActions = false,
+      } = this.props;
       const klass = classNames('co-file-dropzone-container', {
         'co-file-dropzone--drop-over': isOver,
       });
 
       const { error, success, stale, yaml, height, showSidebar } = this.state;
-      const { obj, download = true, header } = this.props;
+      const {
+        obj,
+        download = true,
+        header,
+        genericYAML = false,
+        children: customAlerts,
+      } = this.props;
       const readOnly = this.props.readOnly || this.state.notAllowed;
       const options = { readOnly, scrollBeyondLastLine: false };
       const model = this.getModel(obj);
@@ -721,38 +746,43 @@ const EditYAML_ = connect(stateToProps)(
             <div className="pf-c-form">
               <div className="co-p-has-sidebar">
                 <div className="co-p-has-sidebar__body">
-                  <div className="yaml-editor" ref={(r) => (this.editor = r)}>
+                  <div
+                    className={classNames('yaml-editor', customClass)}
+                    ref={(r) => (this.editor = r)}
+                  >
                     <div className="yaml-editor__links">
-                      <div className="yaml-editor__link">
-                        <Popover
-                          aria-label="Shortcuts"
-                          bodyContent={
-                            <ShortcutTable>
-                              <Shortcut ctrl keyName="space">
-                                Activate auto complete
-                              </Shortcut>
-                              <Shortcut ctrlCmd shift keyName="o">
-                                View document outline
-                              </Shortcut>
-                              <Shortcut hover>View property descriptions</Shortcut>
-                              <Shortcut ctrlCmd keyName="s">
-                                Save
-                              </Shortcut>
-                            </ShortcutTable>
-                          }
-                          maxWidth="25rem"
-                          distance={18}
-                          onHide={this.focusEditor}
-                        >
-                          <Button type="button" variant="link" isInline>
-                            <QuestionCircleIcon className="co-icon-space-r co-p-has-sidebar__sidebar-link-icon" />
-                            View shortcuts
-                          </Button>
-                        </Popover>
-                      </div>
+                      {!genericYAML && (
+                        <div className="yaml-editor__link">
+                          <Popover
+                            aria-label="Shortcuts"
+                            bodyContent={
+                              <ShortcutTable>
+                                <Shortcut ctrl keyName="space">
+                                  Activate auto complete
+                                </Shortcut>
+                                <Shortcut ctrlCmd shift keyName="o">
+                                  View document outline
+                                </Shortcut>
+                                <Shortcut hover>View property descriptions</Shortcut>
+                                <Shortcut ctrlCmd keyName="s">
+                                  Save
+                                </Shortcut>
+                              </ShortcutTable>
+                            }
+                            maxWidth="25rem"
+                            distance={18}
+                            onHide={this.focusEditor}
+                          >
+                            <Button type="button" variant="link" isInline>
+                              <QuestionCircleIcon className="co-icon-space-r co-p-has-sidebar__sidebar-link-icon" />
+                              View shortcuts
+                            </Button>
+                          </Popover>
+                        </div>
+                      )}
                       {!showSidebar && hasSidebarContent && (
                         <>
-                          <div className="co-action-divider--spaced">|</div>
+                          <div className="co-action-divider">|</div>
                           <div className="yaml-editor__link">
                             <Button
                               type="button"
@@ -774,78 +804,83 @@ const EditYAML_ = connect(stateToProps)(
                       value={yaml}
                       options={options}
                       editorDidMount={this.editorDidMount}
-                      onChange={(newValue) => this.setState({ yaml: newValue })}
+                      onChange={(newValue) =>
+                        this.setState({ yaml: newValue }, () => onChange(newValue))
+                      }
                     />
-                    <div className="yaml-editor__buttons" ref={(r) => (this.buttons = r)}>
-                      {error && (
-                        <Alert
-                          isInline
-                          className="co-alert co-alert--scrollable"
-                          variant="danger"
-                          title="An error occurred"
-                        >
-                          <div className="co-pre-line">{error}</div>
-                        </Alert>
-                      )}
-                      {success && (
-                        <Alert isInline className="co-alert" variant="success" title={success} />
-                      )}
-                      {stale && (
-                        <Alert
-                          isInline
-                          className="co-alert"
-                          variant="info"
-                          title="This object has been updated."
-                        >
-                          Click reload to see the new version.
-                        </Alert>
-                      )}
-                      <ActionGroup className="pf-c-form__group--no-top-margin">
-                        {create && (
-                          <Button
-                            type="submit"
-                            variant="primary"
-                            id="save-changes"
-                            onClick={() => this.save()}
+                    {!hideActions && (
+                      <div className="yaml-editor__buttons" ref={(r) => (this.buttons = r)}>
+                        {customAlerts}
+                        {error && (
+                          <Alert
+                            isInline
+                            className="co-alert co-alert--scrollable"
+                            variant="danger"
+                            title="An error occurred"
                           >
-                            Create
-                          </Button>
+                            <div className="co-pre-line">{error}</div>
+                          </Alert>
                         )}
-                        {!create && !readOnly && (
-                          <Button
-                            type="submit"
-                            variant="primary"
-                            id="save-changes"
-                            onClick={() => this.save()}
+                        {success && (
+                          <Alert isInline className="co-alert" variant="success" title={success} />
+                        )}
+                        {stale && (
+                          <Alert
+                            isInline
+                            className="co-alert"
+                            variant="info"
+                            title="This object has been updated."
                           >
-                            Save
-                          </Button>
+                            Click reload to see the new version.
+                          </Alert>
                         )}
-                        {!create && (
-                          <Button
-                            type="submit"
-                            variant="secondary"
-                            id="reload-object"
-                            onClick={() => this.reload()}
-                          >
-                            Reload
+                        <ActionGroup className="pf-c-form__group--no-top-margin">
+                          {create && (
+                            <Button
+                              type="submit"
+                              variant="primary"
+                              id="save-changes"
+                              onClick={() => this.save()}
+                            >
+                              Create
+                            </Button>
+                          )}
+                          {!create && !readOnly && (
+                            <Button
+                              type="submit"
+                              variant="primary"
+                              id="save-changes"
+                              onClick={() => this.save()}
+                            >
+                              Save
+                            </Button>
+                          )}
+                          {!create && !genericYAML && (
+                            <Button
+                              type="submit"
+                              variant="secondary"
+                              id="reload-object"
+                              onClick={() => this.reload()}
+                            >
+                              Reload
+                            </Button>
+                          )}
+                          <Button variant="secondary" id="cancel" onClick={() => this.onCancel()}>
+                            Cancel
                           </Button>
-                        )}
-                        <Button variant="secondary" id="cancel" onClick={() => this.onCancel()}>
-                          Cancel
-                        </Button>
-                        {download && (
-                          <Button
-                            type="submit"
-                            variant="secondary"
-                            className="pf-c-button--align-right hidden-sm hidden-xs"
-                            onClick={() => this.download()}
-                          >
-                            <DownloadIcon /> Download
-                          </Button>
-                        )}
-                      </ActionGroup>
-                    </div>
+                          {download && (
+                            <Button
+                              type="submit"
+                              variant="secondary"
+                              className="pf-c-button--align-right hidden-sm hidden-xs"
+                              onClick={() => this.download()}
+                            >
+                              <DownloadIcon /> Download
+                            </Button>
+                          )}
+                        </ActionGroup>
+                      </div>
+                    )}
                   </div>
                 </div>
                 {hasSidebarContent && (
