@@ -4,6 +4,8 @@ import * as classNames from 'classnames';
 import * as PropTypes from 'prop-types';
 import { Link } from 'react-router-dom';
 import { Helmet } from 'react-helmet';
+import { Button, Chip, ChipGroup, ChipGroupToolbarItem } from '@patternfly/react-core';
+import { CloseIcon } from '@patternfly/react-icons';
 
 import { namespaceProptype } from '../propTypes';
 import { ResourceListDropdown } from './resource-dropdown';
@@ -20,13 +22,14 @@ import { withStartGuide } from './start-guide';
 import { WSFactory } from '../module/ws-factory';
 import { EventModel, NodeModel } from '../models';
 import { connectToFlags } from '../reducers/features';
-import { FLAGS } from '../const';
+import { FLAGS } from '@console/shared/src/constants';
 import {
   Box,
   Dropdown,
   Loading,
   PageHeading,
   pluralize,
+  ResourceIcon,
   ResourceLink,
   resourcePathFromModel,
   Timestamp,
@@ -48,30 +51,32 @@ export const sortEvents = (events) => {
   return _.orderBy(events, [getLastTime, getFirstTime, 'name'], ['desc', 'desc', 'asc']);
 };
 
-// Predicate function to filter by event "category" (info, error, or all)
-export const categoryFilter = (category, event) => {
-  if (category === 'all') {
+// Predicate function to filter by event "type" (normal, warning, or all)
+export const typeFilter = (eventType, event) => {
+  if (eventType === 'all') {
     return true;
   }
-  const { reason = '' } = event;
-  const errorSubstrings = ['error', 'failed', 'unhealthy', 'nodenotready'];
-  const isError =
-    reason && errorSubstrings.find((substring) => reason.toLowerCase().includes(substring));
-  return category === 'error' ? isError : !isError;
+  const { type = 'normal' } = event;
+  return type.toLowerCase() === eventType;
 };
 
 const kindFilter = (reference, { involvedObject }) => {
   if (reference === 'all') {
     return true;
   }
-
-  if (isGroupVersionKind(reference)) {
-    const group = apiGroupForReference(reference);
-    const kind = kindForReference(reference);
-    const { group: eventGroup } = groupVersionFor(involvedObject.apiVersion);
-    return involvedObject.kind === kind && eventGroup === group;
-  }
-  return involvedObject.kind === reference;
+  const kinds = reference.split(',');
+  return kinds.some((ref) => {
+    if (isGroupVersionKind(ref)) {
+      const group = apiGroupForReference(ref);
+      const kind = kindForReference(ref);
+      if (typeof involvedObject.apiVersion === 'undefined') {
+        return false;
+      }
+      const { group: eventGroup } = groupVersionFor(involvedObject.apiVersion);
+      return involvedObject.kind === kind && eventGroup === group;
+    }
+    return involvedObject.kind === ref;
+  });
 };
 
 const Inner = connectToFlags(FLAGS.CAN_LIST_NODE)(
@@ -80,13 +85,13 @@ const Inner = connectToFlags(FLAGS.CAN_LIST_NODE)(
       const { event, flags } = this.props;
       const { involvedObject: obj, source, message, reason, series } = event;
       const tooltipMsg = `${reason} (${obj.kind})`;
-      const isError = categoryFilter('error', event);
+      const isWarning = typeFilter('warning', event);
       const firstTime = getFirstTime(event);
       const lastTime = getLastTime(event);
       const count = series ? series.count : event.count;
 
       return (
-        <div className={classNames('co-sysevent', { 'co-sysevent--error': isError })}>
+        <div className={classNames('co-sysevent', { 'co-sysevent--warning': isWarning })}>
           <div className="co-sysevent__icon-box">
             <i className="co-sysevent-icon" title={tooltipMsg} />
             <div className="co-sysevent__icon-line" />
@@ -149,54 +154,86 @@ const Inner = connectToFlags(FLAGS.CAN_LIST_NODE)(
   },
 );
 
-const categories = { all: 'All Categories', info: 'Info', error: 'Error' };
+const eventTypes = { all: 'All Types', normal: 'Normal', warning: 'Warning' };
 
 export class EventsList extends React.Component {
   constructor(props) {
     super(props);
     this.state = {
-      category: 'all',
-      kind: 'all',
+      type: 'all',
       textFilter: '',
+      selected: new Set(['All']),
     };
   }
 
+  toggleSelected = (selection) => {
+    if (this.state.selected.has('All') || selection === 'All') {
+      this.setState({ selected: new Set([selection]) });
+    } else {
+      const updateItems = new Set(this.state.selected);
+      updateItems.has(selection) ? updateItems.delete(selection) : updateItems.add(selection);
+      this.setState({ selected: updateItems });
+    }
+  };
+
+  clearSelection = () => {
+    this.setState({ selected: new Set(['All']) });
+  };
+
   render() {
-    const { category, kind, textFilter } = this.state;
-    const { autoFocus = true, mock } = this.props;
+    const { type, selected, textFilter } = this.state;
+    const { autoFocus = true } = this.props;
 
     return (
       <>
-        <div className="co-m-pane__filter-bar">
-          <div className="co-m-pane__filter-bar-group">
+        <PageHeading detail={true} title={this.props.title}>
+          <div className="co-search-group">
             <ResourceListDropdown
-              className="btn-group"
-              onChange={(v) => this.setState({ kind: v })}
-              selected={kind}
+              onChange={this.toggleSelected}
+              selected={Array.from(selected)}
               showAll
-              title="All Types"
+              clearSelection={this.clearSelection}
+              className="co-search-group__resource"
             />
             <Dropdown
-              className="btn-group"
-              items={categories}
-              onChange={(v) => this.setState({ category: v })}
-              selectedKey={this.state.category}
-              title="All Categories"
+              className="btn-group co-search-group__resource"
+              items={eventTypes}
+              onChange={(v) => this.setState({ type: v })}
+              selectedKey={type}
+              title="All Types"
             />
-          </div>
-          <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
             <TextFilter
               autoFocus={autoFocus}
               label="Events by name or message"
               onChange={(e) => this.setState({ textFilter: e.target.value || '' })}
             />
           </div>
-        </div>
+          <div className="form-group">
+            <ChipGroup withToolbar defaultIsOpen={false}>
+              <ChipGroupToolbarItem key="resources-category" categoryName="Resource">
+                {[...selected].map((chip) => (
+                  <Chip key={chip} onClick={() => this.toggleSelected(chip)}>
+                    <ResourceIcon kind={chip} />
+                    {kindForReference(chip)}
+                  </Chip>
+                ))}
+                {selected.size > 0 && (
+                  <>
+                    <Button variant="plain" aria-label="Close" onClick={this.clearSelection}>
+                      <CloseIcon />
+                    </Button>
+                  </>
+                )}
+              </ChipGroupToolbarItem>
+            </ChipGroup>
+          </div>
+        </PageHeading>
         <EventStream
           {...this.props}
-          category={category}
-          kind={kind}
-          mock={mock}
+          key={[...selected].join(',')}
+          type={type}
+          kind={selected.has('All') || selected.size === 0 ? 'all' : [...selected].join(',')}
+          mock={this.props.mock}
           textFilter={textFilter}
         />
       </>
@@ -234,8 +271,12 @@ export const EventStreamPage = withStartGuide(({ noProjectsAvailable, ...rest })
     <Helmet>
       <title>Events</title>
     </Helmet>
-    <PageHeading title="Events" />
-    <EventsList {...rest} autoFocus={!noProjectsAvailable} mock={noProjectsAvailable} />
+    <EventsList
+      {...rest}
+      autoFocus={!noProjectsAvailable}
+      mock={noProjectsAvailable}
+      title="Events"
+    />
   </>
 ));
 
@@ -320,7 +361,7 @@ class EventStream extends React.Component {
     this.ws && this.ws.destroy();
   }
 
-  static filterEvents(messages, { kind, category, filter, textFilter }) {
+  static filterEvents(messages, { kind, type, filter, textFilter }) {
     // Don't use `fuzzy` because it results in some surprising matches in long event messages.
     // Instead perform an exact substring match on each word in the text filter.
     const words = _.uniq(_.toLower(textFilter).match(/\S+/g)).sort((a, b) => {
@@ -338,7 +379,7 @@ class EventStream extends React.Component {
     };
 
     const f = (obj) => {
-      if (category && !categoryFilter(category, obj)) {
+      if (type && !typeFilter(type, obj)) {
         return false;
       }
       if (kind && !kindFilter(kind, obj)) {
@@ -357,12 +398,12 @@ class EventStream extends React.Component {
   }
 
   static getDerivedStateFromProps(nextProps, prevState) {
-    const { filter, kind, category, textFilter, loading } = prevState;
+    const { filter, kind, type, textFilter, loading } = prevState;
 
     if (
       _.isEqual(filter, nextProps.filter) &&
       kind === nextProps.kind &&
-      category === nextProps.category &&
+      type === nextProps.type &&
       textFilter === nextProps.textFilter
     ) {
       return {};
@@ -376,7 +417,7 @@ class EventStream extends React.Component {
       // we need these for bookkeeping because getDerivedStateFromProps doesn't get prevProps
       textFilter: nextProps.textFilter,
       kind: nextProps.kind,
-      category: nextProps.category,
+      type: nextProps.type,
       filter: nextProps.filter,
     };
   }
@@ -486,13 +527,13 @@ class EventStream extends React.Component {
 }
 
 EventStream.defaultProps = {
-  category: 'all',
+  type: 'all',
   kind: 'all',
   mock: false,
 };
 
 EventStream.propTypes = {
-  category: PropTypes.string,
+  type: PropTypes.string,
   filter: PropTypes.array,
   kind: PropTypes.string.isRequired,
   mock: PropTypes.bool,
