@@ -5,6 +5,7 @@ import { routeStatus } from '../routes';
 import { secretTypeFilterReducer } from '../secret';
 import { bindingType, roleType } from '../RBAC';
 import {
+  K8sResourceKind,
   MachineKind,
   podPhaseFilterReducer,
   serviceCatalogStatus,
@@ -23,6 +24,8 @@ export const fuzzyCaseInsensitive = (a: string, b: string): boolean =>
 export const tableFilters: TableFilterMap = {
   name: (filter, obj) => fuzzyCaseInsensitive(filter, obj.metadata.name),
 
+  'catalog-source-name': (filter, obj) => fuzzyCaseInsensitive(filter, obj.name),
+
   'alert-name': (filter, alert) => fuzzyCaseInsensitive(filter, _.get(alert, 'labels.alertname')),
 
   'alert-state': (filter, alert) => filter.selected.has(alertState(alert)),
@@ -147,6 +150,13 @@ export const tableFilters: TableFilterMap = {
     return types.selected.has(type) || !_.includes(types.all, type);
   },
 
+  'project-name': (str: string, project: K8sResourceKind) => {
+    const displayName = _.get(project, ['metadata', 'annotations', 'openshift.io/display-name']);
+    return (
+      fuzzyCaseInsensitive(str, project.metadata.name) || fuzzyCaseInsensitive(str, displayName)
+    );
+  },
+
   'pvc-status': (phases, pvc) => {
     if (!phases || !phases.selected || !phases.selected.size) {
       return true;
@@ -193,7 +203,7 @@ export const tableFilters: TableFilterMap = {
   },
 };
 
-interface TableFilterGroups {
+export interface TableFilterGroups {
   selected: Set<string>;
   all: string[];
   values: Set<string>;
