@@ -8,10 +8,18 @@ import { Tooltip, Button } from '@patternfly/react-core';
 import { PencilAltIcon } from '@patternfly/react-icons';
 import { Link } from 'react-router-dom';
 import * as fuzzy from 'fuzzysearch';
-import { Status, getRequester } from '@console/shared';
+import {
+  Status,
+  getRequester,
+  ALL_NAMESPACES_KEY,
+  KEYBOARD_SHORTCUTS,
+  NAMESPACE_LOCAL_STORAGE_KEY,
+  FLAGS,
+} from '@console/shared';
 import { ByteDataTypes } from '@console/shared/src/graph-helper/data-utils';
 
 import { NamespaceModel, ProjectModel, SecretModel } from '../models';
+import { coFetchJSON } from '../co-fetch';
 import { k8sGet } from '../module/k8s';
 import * as UIActions from '../actions/ui';
 import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
@@ -29,11 +37,14 @@ import {
   ResourceLink,
   ResourceSummary,
   SectionHeading,
+  formatBytesAsMiB,
+  formatCores,
   humanizeBinaryBytes,
   humanizeCpuCores,
   navFactory,
   useAccessReview,
 } from './utils';
+import { fromNow } from './utils/datetime';
 import {
   createNamespaceModal,
   createProjectModal,
@@ -41,13 +52,7 @@ import {
   configureNamespacePullSecretModal,
 } from './modals';
 import { RoleBindingsPage } from './RBAC';
-import { Bar, Area, requirePrometheus } from './graphs';
-import {
-  ALL_NAMESPACES_KEY,
-  KEYBOARD_SHORTCUTS,
-  NAMESPACE_LOCAL_STORAGE_KEY,
-  FLAGS,
-} from '../const';
+import { Bar, Area, PROMETHEUS_BASE_PATH, requirePrometheus } from './graphs';
 import { featureReducerName, flagPending, connectToFlags } from '../reducers/features';
 import { setFlag } from '../actions/features';
 import { OpenShiftGettingStarted } from './start-guide';
@@ -93,10 +98,34 @@ const nsMenuActions = [
   deleteModal,
 ];
 
+const fetchNamespaceMetrics = () => {
+  const metrics = [
+    {
+      key: 'memory',
+      query: 'sum by(namespace) (container_memory_working_set_bytes{container="",pod!=""})',
+    },
+    {
+      key: 'cpu',
+      query: 'namespace:container_cpu_usage:sum',
+    },
+  ];
+  const promises = metrics.map(({ key, query }) => {
+    const url = `${PROMETHEUS_BASE_PATH}/api/v1/query?&query=${query}`;
+    return coFetchJSON(url).then(({ data: { result } }) => {
+      return result.reduce((acc, data) => {
+        const value = Number(data.value[1]);
+        return _.set(acc, [key, data.metric.namespace], value);
+      }, {});
+    });
+  });
+  return Promise.all(promises).then((data) => _.assign({}, ...data));
+};
+
 const namespacesColumnClasses = [
-  classNames('col-sm-4', 'col-xs-6'),
-  classNames('col-sm-4', 'col-xs-6'),
-  classNames('col-sm-4', 'hidden-xs'),
+  '', // name
+  '', // status
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm'), // labels
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg pf-u-w-16-on-lg'), // created
   Kebab.columnClass,
 ];
 
@@ -120,7 +149,13 @@ const NamespacesTableHeader = () => {
       transforms: [sortable],
       props: { className: namespacesColumnClasses[2] },
     },
-    { title: '', props: { className: namespacesColumnClasses[3] } },
+    {
+      title: 'Created',
+      sortField: 'metadata.creationTimestamp',
+      transforms: [sortable],
+      props: { className: namespacesColumnClasses[3] },
+    },
+    { title: '', props: { className: namespacesColumnClasses[4] } },
   ];
 };
 NamespacesTableHeader.displayName = 'NamespacesTableHeader';
@@ -138,6 +173,9 @@ const NamespacesTableRow = ({ obj: ns, index, key, style }) => {
         <LabelList kind="Namespace" labels={ns.metadata.labels} />
       </TableData>
       <TableData className={namespacesColumnClasses[3]}>
+        {fromNow(ns.metadata.creationTimestamp)}
+      </TableData>
+      <TableData className={namespacesColumnClasses[4]}>
         <ResourceKebab actions={nsMenuActions} kind="Namespace" resource={ns} />
       </TableData>
     </TableRow>
@@ -167,14 +205,17 @@ export const NamespacesPage = (props) => (
 const projectMenuActions = [Kebab.factory.Edit, deleteModal];
 
 const projectColumnClasses = [
-  classNames('col-md-3', 'col-sm-6', 'col-xs-8'),
-  classNames('col-md-3', 'col-sm-3', 'col-xs-4'),
-  classNames('col-md-3', 'col-sm-3', 'hidden-xs'),
-  classNames('col-md-3', 'hidden-sm', 'hidden-xs'),
+  '', // name
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm'), // display name
+  '', // status
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'), // requester
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'), // memory
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'), // cpu
+  classNames('pf-m-hidden', 'pf-m-visible-on-2xl'), // created
   Kebab.columnClass,
 ];
 
-const ProjectTableHeader = () => {
+const projectTableHeader = ({ showMetrics, showActions }) => {
   return [
     {
       title: 'Name',
@@ -182,98 +223,167 @@ const ProjectTableHeader = () => {
       transforms: [sortable],
       props: { className: projectColumnClasses[0] },
     },
+    {
+      title: 'Display Name',
+      sortField: 'metadata.annotations["openshift.io/display-name"]',
+      transforms: [sortable],
+      props: { className: projectColumnClasses[1] },
+    },
     {
       title: 'Status',
       sortField: 'status.phase',
       transforms: [sortable],
-      props: { className: projectColumnClasses[1] },
+      props: { className: projectColumnClasses[2] },
     },
     {
       title: 'Requester',
       sortField: "metadata.annotations.['openshift.io/requester']",
       transforms: [sortable],
-      props: { className: projectColumnClasses[2] },
-    },
-    {
-      title: 'Labels',
-      sortField: 'metadata.labels',
-      transforms: [sortable],
       props: { className: projectColumnClasses[3] },
     },
-    { title: '', props: { className: projectColumnClasses[4] } },
+    ...(showMetrics
+      ? [
+          {
+            title: 'Memory',
+            sortFunc: 'namespaceMemory',
+            transforms: [sortable],
+            props: { className: projectColumnClasses[4] },
+          },
+          {
+            title: 'CPU',
+            sortFunc: 'namespaceCPU',
+            transforms: [sortable],
+            props: { className: projectColumnClasses[5] },
+          },
+        ]
+      : []),
+    {
+      title: 'Created',
+      sortField: 'metadata.creationTimestamp',
+      transforms: [sortable],
+      props: { className: projectColumnClasses[6] },
+    },
+    ...(showActions ? [{ title: '', props: { className: projectColumnClasses[7] } }] : []),
   ];
 };
-ProjectTableHeader.displayName = 'ProjectTableHeader';
 
-const ProjectLink = connect(
-  null,
-  { setActiveNamespace: UIActions.setActiveNamespace },
-)(({ project, setActiveNamespace }) => (
-  <span className="co-resource-item co-resource-item--truncate">
-    <ResourceIcon kind="Project" />
-    <Button
-      isInline
-      title={project.metadata.name}
-      type="button"
-      className="co-resource-item__resource-name"
-      onClick={() => setActiveNamespace(project.metadata.name)}
-      variant="link"
-    >
-      {project.metadata.name}
-    </Button>
-  </span>
-));
-const projectHeaderWithoutActions = () => _.dropRight(ProjectTableHeader());
+const ProjectLink = connect(null, { setActiveNamespace: UIActions.setActiveNamespace })(
+  ({ project, setActiveNamespace }) => (
+    <span className="co-resource-item co-resource-item--truncate">
+      <ResourceIcon kind="Project" />
+      <Button
+        isInline
+        title={project.metadata.name}
+        type="button"
+        className="co-resource-item__resource-name"
+        onClick={() => setActiveNamespace(project.metadata.name)}
+        variant="link"
+      >
+        {project.metadata.name}
+      </Button>
+    </span>
+  ),
+);
+const projectHeaderWithoutActions = () =>
+  projectTableHeader({ showMetrics: false, showActions: false });
 
-const ProjectTableRow = ({ obj: project, index, key, style, customData = {} }) => {
-  const requester = getRequester(project);
-  const { ProjectLinkComponent, actionsEnabled = true } = customData;
-  return (
-    <TableRow id={project.metadata.uid} index={index} trKey={key} style={style}>
-      <TableData className={projectColumnClasses[0]}>
-        {customData && ProjectLinkComponent ? (
-          <ProjectLinkComponent project={project} />
-        ) : (
-          <span className="co-resource-item">
-            <ResourceLink
-              kind="Project"
-              name={project.metadata.name}
-              title={project.metadata.uid}
-            />
-          </span>
-        )}
-      </TableData>
-      <TableData className={projectColumnClasses[1]}>
-        <Status status={project.status.phase} />
-      </TableData>
-      <TableData className={classNames(projectColumnClasses[2], 'co-break-word')}>
-        {requester || <span className="text-muted">No requester</span>}
-      </TableData>
-      <TableData className={projectColumnClasses[3]}>
-        <LabelList kind="Project" labels={project.metadata.labels} />
-      </TableData>
-      {actionsEnabled && (
-        <TableData className={projectColumnClasses[4]}>
-          <ResourceKebab actions={projectMenuActions} kind="Project" resource={project} />
+const projectRowStateToProps = ({ UI }) => ({
+  metrics: UI.getIn(['metrics', 'namespace']),
+});
+
+const ProjectTableRow = connect(projectRowStateToProps)(
+  ({ obj: project, index, key, style, customData = {}, metrics }) => {
+    const requester = getRequester(project);
+    const { ProjectLinkComponent, actionsEnabled = true, showMetrics } = customData;
+    const bytes = _.get(metrics, ['memory', project.metadata.name]);
+    const cores = _.get(metrics, ['cpu', project.metadata.name]);
+    return (
+      <TableRow id={project.metadata.uid} index={index} trKey={key} style={style}>
+        <TableData className={projectColumnClasses[0]}>
+          {customData && ProjectLinkComponent ? (
+            <ProjectLinkComponent project={project} />
+          ) : (
+            <span className="co-resource-item">
+              <ResourceLink
+                kind="Project"
+                name={project.metadata.name}
+                title={project.metadata.uid}
+              />
+            </span>
+          )}
         </TableData>
-      )}
-    </TableRow>
-  );
-};
+        <TableData className={projectColumnClasses[1]}>
+          <span className="co-break-word co-line-clamp">
+            {getDisplayName(project) || <span className="text-muted">No display name</span>}
+          </span>
+        </TableData>
+        <TableData className={projectColumnClasses[2]}>
+          <Status status={project.status.phase} />
+        </TableData>
+        <TableData className={classNames(projectColumnClasses[3], 'co-break-word')}>
+          {requester || <span className="text-muted">No requester</span>}
+        </TableData>
+        {showMetrics && (
+          <>
+            <TableData className={projectColumnClasses[4]}>
+              {bytes ? `${formatBytesAsMiB(bytes)} MiB` : '-'}
+            </TableData>
+            <TableData className={projectColumnClasses[5]}>
+              {cores ? `${formatCores(cores)} cores` : '-'}
+            </TableData>
+          </>
+        )}
+        <TableData className={projectColumnClasses[6]}>
+          {fromNow(project.metadata.creationTimestamp)}
+        </TableData>
+        {actionsEnabled && (
+          <TableData className={projectColumnClasses[7]}>
+            <ResourceKebab actions={projectMenuActions} kind="Project" resource={project} />
+          </TableData>
+        )}
+      </TableRow>
+    );
+  },
+);
 ProjectTableRow.displayName = 'ProjectTableRow';
 
+const Row = (rowProps) => <ProjectTableRow {...rowProps} />;
 export const ProjectsTable = (props) => (
   <Table
     {...props}
     aria-label="Projects"
     Header={projectHeaderWithoutActions}
-    Row={ProjectTableRow}
+    Row={Row}
     customData={{ ProjectLinkComponent: ProjectLink, actionsEnabled: false }}
     virtualize
   />
 );
 
-export const ProjectList = connectToFlags(FLAGS.CAN_CREATE_PROJECT)(({ data, flags, ...rest }) => {
+const headerWithMetrics = () => projectTableHeader({ showMetrics: true, showActions: true });
+const headerNoMetrics = () => projectTableHeader({ showMetrics: false, showActions: true });
+const ProjectList_ = connectToFlags(
+  FLAGS.CAN_CREATE_PROJECT,
+  FLAGS.CAN_GET_NS,
+)(({ data, flags, setNamespaceMetrics, ...tableProps }) => {
+  const canGetNS = flags[FLAGS.CAN_GET_NS];
+  const showMetrics = PROMETHEUS_BASE_PATH && canGetNS && window.screen.width >= 1200;
+  /* eslint-disable react-hooks/exhaustive-deps */
+  React.useEffect(() => {
+    if (showMetrics) {
+      const updateMetrics = () => fetchNamespaceMetrics().then(setNamespaceMetrics);
+      updateMetrics();
+      const id = setInterval(updateMetrics, 30 * 1000);
+      return () => clearInterval(id);
+    }
+  }, [showMetrics]);
+  /* eslint-enable react-hooks/exhaustive-deps */
+
+  // Don't render the table until we know whether we can get metrics. It's
+  // not possible to change the table headers once the component is mounted.
+  if (flagPending(canGetNS)) {
+    return null;
+  }
+
   const ProjectEmptyMessage = () => (
     <MsgBox
       title="Welcome to OpenShift"
@@ -283,16 +393,20 @@ export const ProjectList = connectToFlags(FLAGS.CAN_CREATE_PROJECT)(({ data, fla
   const ProjectNotFoundMessage = () => <MsgBox title="No Projects Found" />;
   return (
     <Table
-      {...rest}
+      {...tableProps}
       aria-label="Projects"
       data={data}
-      Header={ProjectTableHeader}
-      Row={ProjectTableRow}
+      Header={showMetrics ? headerWithMetrics : headerNoMetrics}
+      Row={Row}
       EmptyMsg={data.length > 0 ? ProjectNotFoundMessage : ProjectEmptyMessage}
+      customData={{ showMetrics }}
       virtualize
     />
   );
 });
+export const ProjectList = connect(null, (dispatch) => ({
+  setNamespaceMetrics: (metrics) => dispatch(UIActions.setNamespaceMetrics(metrics)),
+}))(connectToFlags(FLAGS.CAN_CREATE_PROJET, FLAGS.CAN_GET_NS)(ProjectList_));
 
 export const ProjectsPage = connectToFlags(FLAGS.CAN_CREATE_PROJECT)(({ flags, ...rest }) => (
   // Skip self-subject access review for projects since they use a special project request API.
@@ -301,8 +415,10 @@ export const ProjectsPage = connectToFlags(FLAGS.CAN_CREATE_PROJECT)(({ flags, .
     {...rest}
     ListComponent={ProjectList}
     canCreate={flags[FLAGS.CAN_CREATE_PROJECT]}
-    skipAccessReview
     createHandler={() => createProjectModal({ blocking: true })}
+    filterLabel="by name or display name"
+    skipAccessReview
+    textFilter="project-name"
   />
 ));
 
@@ -335,12 +451,12 @@ export const PullSecret = (props) => {
   const modal = () =>
     configureNamespacePullSecretModal({ namespace: props.namespace, pullSecret: data });
 
-  return ((
+  return (
     <Button variant="link" type="button" isInline onClick={modal}>
       {_.get(data, 'metadata.name') || 'Not Configured'}
       <PencilAltIcon className="co-icon-space-l pf-c-button-icon--plain" />
     </Button>
-  ));
+  );
 };
 
 export const NamespaceLineCharts = ({ ns }) => (
@@ -359,9 +475,7 @@ export const NamespaceLineCharts = ({ ns }) => (
         humanize={humanizeBinaryBytes}
         byteDataType={ByteDataTypes.BinaryBytes}
         namespace={ns.metadata.name}
-        query={`sum by(namespace) (container_memory_working_set_bytes{namespace="${
-          ns.metadata.name
-        }",container="",pod!=""})`}
+        query={`sum by(namespace) (container_memory_working_set_bytes{namespace="${ns.metadata.name}",container="",pod!=""})`}
       />
     </div>
   </div>
@@ -371,9 +485,7 @@ export const TopPodsBarChart = ({ ns }) => (
   <Bar
     title="Memory Usage by Pod (Top 10)"
     namespace={ns.metadata.name}
-    query={`sort_desc(topk(10, sum by (pod)(container_memory_working_set_bytes{container="",pod!="",namespace="${
-      ns.metadata.name
-    }"})))`}
+    query={`sort_desc(topk(10, sum by (pod)(container_memory_working_set_bytes{container="",pod!="",namespace="${ns.metadata.name}"})))`}
     humanize={humanizeBinaryBytes}
     metric="pod"
   />
@@ -429,12 +541,12 @@ export const NamespaceSummary = ({ ns }) => {
   );
 };
 
-const Details_ = ({ obj: ns, consoleLinks }) => {
+const NamespaceDetails_ = ({ obj: ns, consoleLinks }) => {
   const links = getNamespaceDashboardConsoleLinks(ns, consoleLinks);
   return (
     <div>
       <div className="co-m-pane__body">
-        <SectionHeading text={`${ns.kind} Overview`} />
+        <SectionHeading text={`${ns.kind} Details`} />
         <NamespaceSummary ns={ns} />
       </div>
       {ns.kind === 'Namespace' && <ResourceUsage ns={ns} />}
@@ -460,7 +572,7 @@ const DetailsStateToProps = ({ UI }) => ({
   consoleLinks: UI.get('consoleLinks'),
 });
 
-const Details = connect(DetailsStateToProps)(Details_);
+const NamespaceDetails = connect(DetailsStateToProps)(NamespaceDetails_);
 
 const RolesPage = ({ obj: { metadata } }) => (
   <RoleBindingsPage
@@ -477,8 +589,9 @@ const defaultBookmarks = {};
 const namespaceBarDropdownStateToProps = (state) => {
   const activeNamespace = state.UI.get('activeNamespace');
   const canListNS = state[featureReducerName].get(FLAGS.CAN_LIST_NS);
+  const canCreateProject = state[featureReducerName].get(FLAGS.CAN_CREATE_PROJECT);
 
-  return { activeNamespace, canListNS };
+  return { activeNamespace, canListNS, canCreateProject };
 };
 const namespaceBarDropdownDispatchToProps = (dispatch) => ({
   setActiveNamespace: (ns) => dispatch(UIActions.setActiveNamespace(ns)),
@@ -500,6 +613,7 @@ class NamespaceBarDropdowns_ extends React.Component {
       onNamespaceChange,
       setActiveNamespace,
       canListNS,
+      canCreateProject,
       useProjects,
       children,
       disabled,
@@ -527,12 +641,14 @@ class NamespaceBarDropdowns_ extends React.Component {
       // If the currently active namespace is not found in the list of all namespaces, put it in anyway
       items[title] = title;
     }
-    const defaultActionItem = [
-      {
-        actionTitle: `Create ${model.label}`,
-        actionKey: CREATE_NEW_RESOURCE,
-      },
-    ];
+    const defaultActionItem = canCreateProject
+      ? [
+          {
+            actionTitle: `Create ${model.label}`,
+            actionKey: CREATE_NEW_RESOURCE,
+          },
+        ]
+      : [];
 
     const onChange = (newNamespace) => {
       if (newNamespace === CREATE_NEW_RESOURCE) {
@@ -606,7 +722,11 @@ export const NamespacesDetailsPage = (props) => (
   <DetailsPage
     {...props}
     menuActions={nsMenuActions}
-    pages={[navFactory.details(Details), navFactory.editYaml(), navFactory.roles(RolesPage)]}
+    pages={[
+      navFactory.details(NamespaceDetails),
+      navFactory.editYaml(),
+      navFactory.roles(RolesPage),
+    ]}
   />
 );
 
@@ -617,13 +737,13 @@ export const ProjectsDetailsPage = (props) => (
     pages={[
       {
         href: '',
-        name: 'Dashboard',
+        name: 'Overview',
         component: ProjectDashboard,
       },
       {
-        href: 'overview',
-        name: 'Overview',
-        component: Details,
+        href: 'details',
+        name: 'Details',
+        component: NamespaceDetails,
       },
       navFactory.editYaml(),
       navFactory.workloads(Overview),
