@@ -1,19 +1,19 @@
 import * as React from 'react';
 import * as _ from 'lodash-es';
 import { connect } from 'react-redux';
-import * as PropTypes from 'prop-types';
 import { Map as ImmutableMap, OrderedMap, Set as ImmutableSet } from 'immutable';
 import * as classNames from 'classnames';
 import * as fuzzy from 'fuzzysearch';
 
 import { Dropdown, ResourceIcon } from './utils';
 import {
+  apiVersionForReference,
   K8sKind,
   K8sResourceKindReference,
+  modelFor,
   referenceForModel,
-  apiVersionForReference,
-  kindForReference,
 } from '../module/k8s';
+import { Badge, Checkbox } from '@patternfly/react-core';
 
 // Blacklist known duplicate resources.
 const blacklistGroups = ImmutableSet([
@@ -22,42 +22,30 @@ const blacklistGroups = ImmutableSet([
 ]);
 
 const blacklistResources = ImmutableSet([
-  // Unfortunately a few resources we want to show like Ingress exist only in extensions/v1beta1,
-  // so we can't blacklist the entire group. The API group is eventually going away.
-  // https://github.com/kubernetes/kubernetes/issues/43214
-
-  // Prefer apps/v1
-  'extensions/v1beta1.DaemonSet',
-  'extensions/v1beta1.Deployment',
-  'extensions/v1beta1.NetworkPolicy',
-  'extensions/v1beta1.ReplicaSet',
-
-  // Prefer policy/v1beta1
-  'extensions/v1beta1.PodSecurityPolicy',
-
   // Prefer core/v1
   'events.k8s.io/v1beta1.Event',
-  'security.openshift.io/v1.SecurityContextConstraints',
-
-  // Hide dummy resource
-  'extensions/v1beta1.ReplicationControllerDummy',
 ]);
 
-const DropdownItem: React.SFC<DropdownItemProps> = ({ model, showGroup }) => (
+const DropdownItem: React.SFC<DropdownItemProps> = ({ model, showGroup, checked }) => (
   <>
-    <span className="co-resource-item">
+    <span className={'co-resource-item'}>
+      <Checkbox
+        tabIndex={-1}
+        id={`${model.apiGroup}:${model.apiVersion}:${model.kind}`}
+        isChecked={checked}
+      />
       <span className="co-resource-icon--fixed-width">
         <ResourceIcon kind={referenceForModel(model)} />
       </span>
       <span className="co-resource-item__resource-name">
-        {model.kind}
+        <span>
+          {model.kind}
+          {model.badge && <span className="co-resource-item__tech-dev-preview">{model.badge}</span>}
+        </span>
         {showGroup && (
-          <>
-            &nbsp;
-            <div className="co-resource-item__resource-api text-muted co-truncate show co-nowrap small">
-              {model.apiGroup || 'core'}/{model.apiVersion}
-            </div>
-          </>
+          <span className="co-resource-item__resource-api text-muted co-truncate show co-nowrap small">
+            {model.apiGroup || 'core'}/{model.apiVersion}
+          </span>
         )}
       </span>
     </span>
@@ -99,30 +87,36 @@ const ResourceListDropdown_: React.SFC<ResourceListDropdownProps> = (props) => {
   const kinds = resources.groupBy((m) => m.kind);
   const isDup = (kind) => kinds.get(kind).size > 1;
 
+  const isKindSelected = (kind: string) => {
+    return _.includes(selected, kind);
+  };
   // Create dropdown items for each resource.
   const items = resources.map((model) => (
-    <DropdownItem key={referenceForModel(model)} model={model} showGroup={isDup(model.kind)} />
+    <DropdownItem
+      key={referenceForModel(model)}
+      model={model}
+      showGroup={isDup(model.kind)}
+      checked={isKindSelected(referenceForModel(model))}
+    />
   )) as OrderedMap<string, JSX.Element>;
-
   // Add an "All" item to the top if `showAll`.
   const allItems = (showAll
     ? OrderedMap({
-        all: (
+        All: (
           <>
             <span className="co-resource-item">
+              <Checkbox id="all-resources" isChecked={isKindSelected('All')} />
               <span className="co-resource-icon--fixed-width">
                 <ResourceIcon kind="All" />
               </span>
-              <span className="co-resource-item__resource-name">All Types</span>
+              <span className="co-resource-item__resource-name">All Resources</span>
             </span>
-            {/* <ResourceIcon kind="All" /> */}
           </>
         ),
       }).concat(items)
     : items
   ).toJS() as { [s: string]: JSX.Element };
 
-  const selectedKey = allItems[selected] ? selected : kindForReference(selected);
   const autocompleteFilter = (text, item) => {
     const { model } = item.props;
     if (!model) {
@@ -132,16 +126,26 @@ const ResourceListDropdown_: React.SFC<ResourceListDropdownProps> = (props) => {
     return fuzzy(_.toLower(text), _.toLower(model.kind));
   };
 
+  const handleSelected = (value: string) => {
+    onChange(referenceForModel(modelFor(value)));
+  };
+
   return (
     <Dropdown
       menuClassName="dropdown-menu--text-wrap"
       className={classNames('co-type-selector', className)}
       items={allItems}
-      title={allItems[selectedKey]}
-      onChange={onChange}
+      title={
+        <div key="title-resource">
+          Resources{' '}
+          <Badge isRead>
+            {selected.length === 1 && selected[0] === 'All' ? 'All' : selected.length}
+          </Badge>
+        </div>
+      }
+      onChange={handleSelected}
       autocompleteFilter={autocompleteFilter}
       autocompletePlaceholder="Select Resource"
-      selectedKey={selectedKey}
     />
   );
 };
@@ -155,18 +159,9 @@ export const ResourceListDropdown = connect(resourceListDropdownStateToProps)(
   ResourceListDropdown_,
 );
 
-ResourceListDropdown.propTypes = {
-  onChange: PropTypes.func.isRequired,
-  selected: PropTypes.string,
-  showAll: PropTypes.bool,
-  className: PropTypes.string,
-  id: PropTypes.string,
-};
-
 export type ResourceListDropdownProps = {
-  // FIXME: `selected` should be GroupVersionKind
-  selected: K8sResourceKindReference;
-  onChange: Function;
+  selected: K8sResourceKindReference[];
+  onChange: (value: string) => void;
   allModels: ImmutableMap<K8sResourceKindReference, K8sKind>;
   preferredVersions: { groupVersion: string; version: string }[];
   className?: string;
@@ -177,4 +172,5 @@ export type ResourceListDropdownProps = {
 type DropdownItemProps = {
   model: K8sKind;
   showGroup?: boolean;
+  checked?: boolean;
 };
