@@ -20,9 +20,15 @@ import {
   navFactory,
 } from './utils';
 import { MaskedData } from './configmap-and-secret-data';
-import { K8sResourceKindReference, RouteKind, RouteIngress, RouteTarget } from '../module/k8s';
+import {
+  K8sResourceKindReference,
+  RouteKind,
+  RouteIngress,
+  RouteTarget,
+  K8sResourceCondition,
+} from '../module/k8s';
 import { RouteModel } from '../models';
-import { Conditions, conditionProps } from './conditions';
+import { Conditions } from './conditions';
 import { RouteCharts } from './routes/route-charts';
 
 const RoutesReference: K8sResourceKindReference = 'Route';
@@ -31,7 +37,7 @@ const menuActions = [...Kebab.getExtensionsActionsForKind(RouteModel), ...Kebab.
 export type IngressStatusProps = {
   host: string;
   routerName: string;
-  conditions: conditionProps[];
+  conditions: K8sResourceCondition[];
   wildcardPolicy: string;
   routerCanonicalHostname: string;
 };
@@ -134,11 +140,11 @@ export const RouteStatus: React.FC<RouteStatusProps> = ({ obj: route }) => {
 RouteStatus.displayName = 'RouteStatus';
 
 const tableColumnClasses = [
-  classNames('col-lg-3', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-3', 'col-md-3', 'col-sm-4', 'hidden-xs'),
-  classNames('col-lg-2', 'col-md-3', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
+  '',
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm', 'pf-u-w-16-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
   Kebab.columnClass,
 ];
 
@@ -158,20 +164,20 @@ const RouteTableHeader = () => {
       transforms: [sortable],
       props: { className: tableColumnClasses[1] },
     },
+    {
+      title: 'Status',
+      props: { className: tableColumnClasses[2] },
+    },
     {
       title: 'Location',
       sortField: 'spec.host',
       transforms: [sortable],
-      props: { className: tableColumnClasses[2] },
+      props: { className: tableColumnClasses[3] },
     },
     {
       title: 'Service',
       sortField: 'spec.to.name',
       transforms: [sortable],
-      props: { className: tableColumnClasses[3] },
-    },
-    {
-      title: 'Status',
       props: { className: tableColumnClasses[4] },
     },
     {
@@ -200,10 +206,13 @@ const RouteTableRow: React.FC<RouteTableRowProps> = ({ obj: route, index, key, s
           title={route.metadata.namespace}
         />
       </TableData>
-      <TableData className={classNames(tableColumnClasses[2], 'co-break-word')}>
+      <TableData className={tableColumnClasses[2]}>
+        <RouteStatus obj={route} />
+      </TableData>
+      <TableData className={classNames(tableColumnClasses[3], 'co-break-word')}>
         <RouteLocation obj={route} />
       </TableData>
-      <TableData className={tableColumnClasses[3]}>
+      <TableData className={tableColumnClasses[4]}>
         <ResourceLink
           kind="Service"
           name={route.spec.to.name}
@@ -211,9 +220,6 @@ const RouteTableRow: React.FC<RouteTableRowProps> = ({ obj: route, index, key, s
           title={route.spec.to.name}
         />
       </TableData>
-      <TableData className={tableColumnClasses[4]}>
-        <RouteStatus obj={route} />
-      </TableData>
       <TableData className={tableColumnClasses[5]}>
         <ResourceKebab actions={menuActions} kind={kind} resource={route} />
       </TableData>
@@ -411,7 +417,7 @@ const RouteDetails: React.FC<RoutesDetailsProps> = ({ obj: route }) => {
   return (
     <>
       <div className="co-m-pane__body">
-        <SectionHeading text="Route Overview" />
+        <SectionHeading text="Route Details" />
         <RouteCharts namespace={route.metadata.namespace} route={route.metadata.name} />
         <div className="row">
           <div className="col-sm-6">
