@@ -15,8 +15,15 @@ import {
 } from './index';
 import { K8sResourceKind, modelFor, referenceFor, Toleration } from '../../module/k8s';
 
-export const pluralize = (i: number, singular: string, plural: string = `${singular}s`) =>
-  `${i || 0} ${i === 1 ? singular : plural}`;
+export const pluralize = (
+  i: number,
+  singular: string,
+  plural: string = `${singular}s`,
+  includeCount: boolean = true,
+) => {
+  const pluralized = `${i === 1 ? singular : plural}`;
+  return includeCount ? `${i || 0} ${pluralized}` : pluralized;
+};
 
 export const detailsPage = <T extends {}>(Component: React.ComponentType<T>) =>
   function DetailsPage(props: T) {
@@ -28,27 +35,22 @@ const getTolerationsPath = (obj: K8sResourceKind): string => {
   return obj.kind === 'Pod' ? 'spec.tolerations' : 'spec.template.spec.tolerations';
 };
 
-const getNodeSelectorPath = (obj: K8sResourceKind): string => {
-  // FIXME: Is this correct for all types (jobs, cron jobs)? It would be better for the embedding page to pass in the path.
-  return obj.kind === 'Pod' ? 'spec.nodeSelector' : 'spec.template.spec.nodeSelector';
-};
-
 export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
   children,
   resource,
+  customPathName,
   showPodSelector = false,
   showNodeSelector = false,
   showAnnotations = true,
   showTolerations = false,
   podSelector = 'spec.selector',
+  nodeSelector = 'spec.template.spec.nodeSelector',
 }) => {
   const { metadata, type } = resource;
   const reference = referenceFor(resource);
   const model = modelFor(reference);
-  const nodeSelectorPath = getNodeSelectorPath(resource);
   const tolerationsPath = getTolerationsPath(resource);
   const tolerations: Toleration[] = _.get(resource, tolerationsPath);
-
   const canUpdate = useAccessReview({
     group: model.apiGroup,
     resource: model.plural,
@@ -59,7 +61,7 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
 
   return (
     <dl data-test-id="resource-summary" className="co-m-pane__details">
-      <DetailsItem label="Name" obj={resource} path="metadata.name" />
+      <DetailsItem label="Name" obj={resource} path={customPathName || 'metadata.name'} />
       {metadata.namespace && (
         <DetailsItem label="Namespace" obj={resource} path="metadata.namespace">
           <ResourceLink
@@ -84,8 +86,8 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
         </DetailsItem>
       )}
       {showNodeSelector && (
-        <DetailsItem label="Node Selector" obj={resource} path={nodeSelectorPath}>
-          <Selector kind="Node" selector={_.get(resource, nodeSelectorPath)} />
+        <DetailsItem label="Node Selector" obj={resource} path={nodeSelector}>
+          <Selector kind="Node" selector={_.get(resource, nodeSelector)} />
         </DetailsItem>
       )}
       {showTolerations && (
@@ -148,7 +150,9 @@ export type ResourceSummaryProps = {
   showAnnotations?: boolean;
   showTolerations?: boolean;
   podSelector?: string;
+  nodeSelector?: string;
   children?: React.ReactNode;
+  customPathName?: string;
 };
 
 export type ResourcePodCountProps = {
