@@ -1,8 +1,9 @@
 import * as _ from 'lodash-es';
+import { plural } from 'pluralize';
 
 import { coFetchJSON } from '../../co-fetch';
 import { K8sKind, K8sVerb } from '../../module/k8s';
-import { API_DISCOVERY_RESOURCES_LOCAL_STORAGE_KEY } from '../../const';
+import { API_DISCOVERY_RESOURCES_LOCAL_STORAGE_KEY } from '@console/shared/src/constants';
 
 const ADMIN_RESOURCES = new Set([
   'roles',
@@ -81,7 +82,17 @@ export type DiscoveryResources = {
   safeResources: string[];
 };
 
-const getResources_ = () =>
+export const pluralizeKind = (kind: string): string => {
+  // Use startCase to separate words so the last can be pluralized but remove spaces so as not to humanize
+  const pluralized = plural(_.startCase(kind)).replace(/\s+/g, '');
+  // Handle special cases like DB -> DBs (instead of DBS).
+  if (pluralized === `${kind}S`) {
+    return `${kind}s`;
+  }
+  return pluralized;
+};
+
+export const getResources = () =>
   coFetchJSON('api/kubernetes/apis').then((res) => {
     const preferredVersions = res.groups.map((group) => group.preferredVersion);
     const all: Promise<APIResourceList>[] = _.flatten(
@@ -123,7 +134,7 @@ const getResources_ = () =>
               apiVersion,
               abbr: kindToAbbr(kind),
               ...(apiGroup ? { apiGroup } : {}),
-              labelPlural: `${kind}${kind.endsWith('s') ? 'es' : 's'}`,
+              labelPlural: pluralizeKind(kind),
               path: name,
               id: singularName,
               crd: true,
@@ -152,11 +163,6 @@ const getResources_ = () =>
     });
   });
 
-// Never attemp to re-run API discovery more than once every 30s. This will
-// prevent the console from thrashing when one of the API services is
-// misbehaving, which can cause frequent WebSocket updates.
-export const getResources = _.throttle(getResources_, 30 * 1000);
-
 export type APIResourceList = {
   kind: 'APIResourceList';
   apiVersion: 'v1';
