@@ -1,5 +1,5 @@
 import { JSONSchema6 } from 'json-schema';
-import { BadgeType } from '@console/shared';
+import { BadgeType, NodeAddress } from '@console/shared';
 import { EventInvolvedObject } from './event';
 
 export * from './job';
@@ -66,12 +66,12 @@ export enum K8sResourceConditionStatus {
   Unknown = 'Unknown',
 }
 
-export type K8sResourceCondition<T> = {
-  type: T;
-  status: K8sResourceConditionStatus;
-  lastTransitionTime: string;
-  reason: string;
-  message: string;
+export type K8sResourceCondition = {
+  type: string;
+  status: keyof typeof K8sResourceConditionStatus;
+  lastTransitionTime?: string;
+  reason?: string;
+  message?: string;
 };
 
 export type MatchExpression =
@@ -107,17 +107,14 @@ export type Toleration = {
 
 // Properties common to (almost) all Kubernetes resources.
 export type K8sResourceCommon = {
-  apiVersion: string;
-  kind: string;
-  metadata: ObjectMetadata;
+  apiVersion?: string;
+  kind?: string;
+  metadata?: ObjectMetadata;
 };
 
 // Generic, unknown kind. Avoid when possible since it allows any key in spec
 // or status, weakening type checking.
-export type K8sResourceKind = {
-  apiVersion?: string;
-  kind?: string;
-  metadata?: ObjectMetadata;
+export type K8sResourceKind = K8sResourceCommon & {
   spec?: {
     selector?: Selector | MatchLabels;
     [key: string]: any;
@@ -307,13 +304,8 @@ export type ContainerStatus = {
 };
 
 export type PodCondition = {
-  type?: string;
-  status?: string;
-  reason?: string;
-  message?: string;
-  lastTransitionTime?: string;
   lastProbeTime?: string;
-};
+} & K8sResourceCondition;
 
 export type PodStatus = {
   phase: PodPhase;
@@ -336,6 +328,10 @@ export type PodKind = {
 } & K8sResourceCommon &
   PodTemplate;
 
+export type DeploymentCondition = {
+  lastUpdateTime?: string;
+} & K8sResourceCondition;
+
 export type DeploymentKind = {
   spec: {
     minReadySeconds?: number;
@@ -356,7 +352,7 @@ export type DeploymentKind = {
   status?: {
     availableReplicas?: number;
     collisionCount?: number;
-    conditions?: any[];
+    conditions?: DeploymentCondition[];
     observedGeneration?: number;
     readyReplicas?: number;
     replicas?: number;
@@ -370,13 +366,17 @@ export type StorageClassResourceKind = {
   reclaimPolicy: string;
 } & K8sResourceCommon;
 
+export type NodeCondition = {
+  lastHeartbeatTime?: string;
+} & K8sResourceCondition;
+
 export type NodeKind = {
   spec: {
     taints?: Taint[];
     unschedulable?: boolean;
   };
   status?: {
-    conditions?: any;
+    conditions?: NodeCondition[];
     images?: {
       names: string[];
       sizeBytes?: number;
@@ -410,7 +410,7 @@ export type JobKind = {
   status: {
     active?: number;
     completionTime?: string;
-    conditions?: any;
+    conditions?: K8sResourceCondition[];
     failed?: number;
     startTime?: string;
     succeeded?: number;
@@ -444,6 +444,12 @@ export type CronJobKind = {
   };
 };
 
+export type CRDVersion = {
+  name: string;
+  served: boolean;
+  storage: boolean;
+};
+
 export type CustomResourceDefinitionKind = {
   spec: {
     version: string;
@@ -460,9 +466,10 @@ export type CustomResourceDefinitionKind = {
       // NOTE: Actually a subset of JSONSchema, but using this type for convenience
       openAPIV3Schema: JSONSchema6;
     };
+    versions?: CRDVersion[];
   };
   status?: {
-    conditions?: any[];
+    conditions?: K8sResourceCondition[];
   };
 } & K8sResourceCommon;
 
@@ -482,7 +489,7 @@ export type RouteTLS = {
 };
 
 export type RouteIngress = {
-  conditions: any[];
+  conditions: K8sResourceCondition[];
   host?: string;
   routerCanonicalHostname?: string;
   routerName?: string;
@@ -541,14 +548,21 @@ export type TemplateInstanceKind = {
     };
   };
   status?: {
-    conditions: any[];
+    conditions: K8sResourceCondition[];
     objects: TemplateInstanceObject[];
   };
 } & K8sResourceCommon;
 
+export type MachineAWSPlacement = {
+  availabilityZone?: string;
+  region?: string;
+};
+
 export type MachineSpec = {
   providerSpec: {
-    value: K8sResourceKind;
+    value?: {
+      placement?: MachineAWSPlacement;
+    };
   };
   versions: {
     kubelet: string;
@@ -560,10 +574,7 @@ export type MachineKind = {
   spec: MachineSpec;
   status?: {
     phase?: string;
-    addresses: {
-      address?: string;
-      type: string;
-    };
+    addresses: NodeAddress[];
     lastUpdated: string;
     nodeRef: {
       kind: string;
@@ -572,7 +583,7 @@ export type MachineKind = {
     };
     providerStatus: {
       kind: string;
-      conditions?: any[];
+      conditions?: K8sResourceCondition[];
       [key: string]: any;
     };
   };
@@ -643,7 +654,9 @@ export enum MachineConfigPoolConditionType {
   Degraded = 'Degraded',
 }
 
-export type MachineConfigPoolCondition = K8sResourceCondition<MachineConfigPoolConditionType>;
+export type MachineConfigPoolCondition = {
+  type: keyof typeof MachineConfigPoolConditionType;
+} & K8sResourceCondition;
 
 export type MachineConfigPoolStatus = {
   observedGeneration?: number;
@@ -660,7 +673,7 @@ export type MachineConfigPoolStatus = {
 
 export type MachineConfigPoolSpec = {
   machineConfigSelector?: Selector;
-  machineSelector?: Selector;
+  nodeSelector?: Selector;
   paused: boolean;
   maxUnavailable: number | string;
 };
@@ -691,7 +704,9 @@ export enum ClusterVersionConditionType {
   Invalid = 'Invalid',
 }
 
-export type ClusterVersionCondition = K8sResourceCondition<ClusterVersionConditionType>;
+export type ClusterVersionCondition = {
+  type: keyof typeof ClusterVersionConditionType;
+} & K8sResourceCondition;
 
 type ClusterVersionStatus = {
   availableUpdates: ClusterUpdate[];
@@ -727,7 +742,7 @@ type ClusterOperatorObjectReference = {
 export type ClusterOperator = {
   spec: {};
   status: {
-    conditions?: any[];
+    conditions?: K8sResourceCondition[];
     versions?: OperandVersion[];
     relatedObjects?: ClusterOperatorObjectReference[];
   };
