@@ -1,8 +1,8 @@
 import * as _ from 'lodash-es';
 
-import { STORAGE_PREFIX } from '../../const';
+import { STORAGE_PREFIX } from '@console/shared/src/constants';
 import { coFetchJSON } from '../../co-fetch';
-import { K8sKind, referenceForModel, SwaggerDefinitions } from './';
+import { K8sKind, referenceForModel } from './';
 
 const SWAGGER_LOCAL_STORAGE_KEY = `${STORAGE_PREFIX}/swagger-definitions`;
 
@@ -132,6 +132,7 @@ export const getResourceDescription = _.memoize((kindObj: K8sKind): string => {
 export type SwaggerDefinition = {
   description?: string;
   type?: string;
+  enum?: string[];
   $ref?: string;
   items?: SwaggerDefinition;
   required?: string[];
