@@ -1,7 +1,6 @@
 package server
 
 import (
-	"encoding/json"
 	"fmt"
 	"html/template"
 	"io"
@@ -15,7 +14,9 @@ import (
 	"github.com/coreos/pkg/health"
 
 	"github.com/openshift/console/pkg/auth"
+	helmhandlerspkg "github.com/openshift/console/pkg/helm/handlers"
 	"github.com/openshift/console/pkg/proxy"
+	"github.com/openshift/console/pkg/serverutils"
 	"github.com/openshift/console/pkg/version"
 )
 
@@ -34,6 +35,7 @@ const (
 	alertManagerProxyEndpoint      = "/api/alertmanager"
 	meteringProxyEndpoint          = "/api/metering"
 	customLogoEndpoint             = "/custom-logo"
+	helmChartRepoProxyEndpoint     = "/api/helm/charts/"
 )
 
 var (
@@ -62,7 +64,13 @@ type jsGlobals struct {
 	CustomLogoURL            string `json:"customLogoURL"`
 	StatuspageID             string `json:"statuspageID"`
 	DocumentationBaseURL     string `json:"documentationBaseURL"`
+	AlertManagerPublicURL    string `json:"alertManagerPublicURL"`
+	GrafanaPublicURL         string `json:"grafanaPublicURL"`
+	PrometheusPublicURL      string `json:"prometheusPublicURL"`
+	ThanosPublicURL          string `json:"thanosPublicURL"`
 	LoadTestFactor           int    `json:"loadTestFactor"`
+	GOARCH                   string `json:"GOARCH"`
+	GOOS                     string `json:"GOOS"`
 }
 
 type Server struct {
@@ -89,6 +97,16 @@ type Server struct {
 	ThanosTenancyProxyConfig *proxy.Config
 	AlertManagerProxyConfig  *proxy.Config
 	MeteringProxyConfig      *proxy.Config
+	// A lister for resource listing of a particular kind
+	MonitoringDashboardConfigMapLister *ResourceLister
+	HelmChartRepoProxyConfig           *proxy.Config
+	GOARCH                             string
+	GOOS                               string
+	// Monitoring and Logging related URLs
+	AlertManagerPublicURL *url.URL
+	GrafanaPublicURL      *url.URL
+	PrometheusPublicURL   *url.URL
+	ThanosPublicURL       *url.URL
 }
 
 func (s *Server) authDisabled() bool {
@@ -292,50 +310,55 @@ func (s *Server) HTTPHandler() http.Handler {
 		)
 	}
 
+	handle("/api/console/monitoring-dashboard-config", authHandler(s.handleMonitoringDashboardConfigmaps))
 	handle("/api/console/version", authHandler(s.versionHandler))
+
+	// Helm Endpoints
+	helmHandlers := helmhandlerspkg.New(s.KubeAPIServerURL, s.K8sClient.Transport)
+	handle("/api/helm/template", authHandlerWithUser(helmHandlers.HandleHelmRenderManifests))
+	handle("/api/helm/releases", authHandlerWithUser(helmHandlers.HandleHelmList))
+	handle("/api/helm/release", authHandlerWithUser(helmHandlers.HandleHelmInstall))
+	handle("/api/helm/chart", authHandlerWithUser(helmHandlers.HandleChartGet))
+
+	helmChartRepoProxy := proxy.NewProxy(s.HelmChartRepoProxyConfig)
+
+	// Only proxy requests to chart repo index file
+	handle(helmChartRepoProxyEndpoint+"index.yaml", http.StripPrefix(
+		proxy.SingleJoiningSlash(s.BaseURL.Path, helmChartRepoProxyEndpoint),
+		http.HandlerFunc(helmChartRepoProxy.ServeHTTP)))
+
 	mux.HandleFunc(s.BaseURL.Path, s.indexHandler)
 
 	return securityHeadersMiddleware(http.Handler(mux))
 }
 
-func sendResponse(rw http.ResponseWriter, code int, resp interface{}) {
-	enc, err := json.Marshal(resp)
-	if err != nil {
-		plog.Printf("Failed JSON-encoding HTTP response: %v", err)
-		rw.WriteHeader(http.StatusInternalServerError)
-		return
-	}
-
-	rw.Header().Set("Content-Type", "application/json")
-	rw.WriteHeader(code)
-
-	_, err = rw.Write(enc)
-	if err != nil {
-		plog.Errorf("Failed sending HTTP response body: %v", err)
-	}
-}
-
-type apiError struct {
-	Err string `json:"error"`
+func (s *Server) handleMonitoringDashboardConfigmaps(w http.ResponseWriter, r *http.Request) {
+	s.MonitoringDashboardConfigMapLister.handleResources(w, r)
 }
 
 func (s *Server) indexHandler(w http.ResponseWriter, r *http.Request) {
 	jsg := &jsGlobals{
-		ConsoleVersion:       version.Version,
-		AuthDisabled:         s.authDisabled(),
-		KubectlClientID:      s.KubectlClientID,
-		BasePath:             s.BaseURL.Path,
-		LoginURL:             proxy.SingleJoiningSlash(s.BaseURL.String(), authLoginEndpoint),
-		LoginSuccessURL:      proxy.SingleJoiningSlash(s.BaseURL.String(), AuthLoginSuccessEndpoint),
-		LoginErrorURL:        proxy.SingleJoiningSlash(s.BaseURL.String(), AuthLoginErrorEndpoint),
-		LogoutURL:            proxy.SingleJoiningSlash(s.BaseURL.String(), authLogoutEndpoint),
-		LogoutRedirect:       s.LogoutRedirect.String(),
-		KubeAPIServerURL:     s.KubeAPIServerURL,
-		Branding:             s.Branding,
-		CustomProductName:    s.CustomProductName,
-		StatuspageID:         s.StatuspageID,
-		DocumentationBaseURL: s.DocumentationBaseURL.String(),
-		LoadTestFactor:       s.LoadTestFactor,
+		ConsoleVersion:        version.Version,
+		AuthDisabled:          s.authDisabled(),
+		KubectlClientID:       s.KubectlClientID,
+		BasePath:              s.BaseURL.Path,
+		LoginURL:              proxy.SingleJoiningSlash(s.BaseURL.String(), authLoginEndpoint),
+		LoginSuccessURL:       proxy.SingleJoiningSlash(s.BaseURL.String(), AuthLoginSuccessEndpoint),
+		LoginErrorURL:         proxy.SingleJoiningSlash(s.BaseURL.String(), AuthLoginErrorEndpoint),
+		LogoutURL:             proxy.SingleJoiningSlash(s.BaseURL.String(), authLogoutEndpoint),
+		LogoutRedirect:        s.LogoutRedirect.String(),
+		KubeAPIServerURL:      s.KubeAPIServerURL,
+		Branding:              s.Branding,
+		CustomProductName:     s.CustomProductName,
+		StatuspageID:          s.StatuspageID,
+		DocumentationBaseURL:  s.DocumentationBaseURL.String(),
+		AlertManagerPublicURL: s.AlertManagerPublicURL.String(),
+		GrafanaPublicURL:      s.GrafanaPublicURL.String(),
+		PrometheusPublicURL:   s.PrometheusPublicURL.String(),
+		ThanosPublicURL:       s.ThanosPublicURL.String(),
+		GOARCH:                s.GOARCH,
+		GOOS:                  s.GOOS,
+		LoadTestFactor:        s.LoadTestFactor,
 	}
 
 	if !s.authDisabled() {
@@ -379,7 +402,7 @@ func (s *Server) indexHandler(w http.ResponseWriter, r *http.Request) {
 }
 
 func (s *Server) versionHandler(w http.ResponseWriter, r *http.Request) {
-	sendResponse(w, http.StatusOK, struct {
+	serverutils.SendResponse(w, http.StatusOK, struct {
 		Version string `json:"version"`
 	}{
 		Version: version.Version,
@@ -393,7 +416,7 @@ func notFoundHandler(w http.ResponseWriter, r *http.Request) {
 
 func (s *Server) handleOpenShiftTokenDeletion(user *auth.User, w http.ResponseWriter, r *http.Request) {
 	if r.Method != "POST" {
-		sendResponse(w, http.StatusMethodNotAllowed, apiError{"Invalid method: only POST is allowed"})
+		serverutils.SendResponse(w, http.StatusMethodNotAllowed, serverutils.ApiError{Err: "Invalid method: only POST is allowed"})
 		return
 	}
 
@@ -402,14 +425,14 @@ func (s *Server) handleOpenShiftTokenDeletion(user *auth.User, w http.ResponseWr
 	url := proxy.SingleJoiningSlash(s.K8sProxyConfig.Endpoint.String(), path)
 	req, err := http.NewRequest("DELETE", url, nil)
 	if err != nil {
-		sendResponse(w, http.StatusInternalServerError, apiError{fmt.Sprintf("Failed to create token DELETE request: %v", err)})
+		serverutils.SendResponse(w, http.StatusInternalServerError, serverutils.ApiError{Err: fmt.Sprintf("Failed to create token DELETE request: %v", err)})
 		return
 	}
 
 	r.Header.Set("Authorization", fmt.Sprintf("Bearer %s", user.Token))
 	resp, err := s.K8sClient.Do(req)
 	if err != nil {
-		sendResponse(w, http.StatusBadGateway, apiError{fmt.Sprintf("Failed to delete token: %v", err)})
+		serverutils.SendResponse(w, http.StatusBadGateway, serverutils.ApiError{Err: fmt.Sprintf("Failed to delete token: %v", err)})
 		return
 	}
 
