@@ -6,13 +6,15 @@ package serverconfig
 
 // Config is the top-level console server cli configuration.
 type Config struct {
-	APIVersion    string `yaml:"apiVersion"`
-	Kind          string `yaml:"kind"`
-	ServingInfo   `yaml:"servingInfo"`
-	ClusterInfo   `yaml:"clusterInfo"`
-	Auth          `yaml:"auth"`
-	Customization `yaml:"customization"`
-	Providers     `yaml:"providers"`
+	APIVersion     string `yaml:"apiVersion"`
+	Kind           string `yaml:"kind"`
+	ServingInfo    `yaml:"servingInfo"`
+	ClusterInfo    `yaml:"clusterInfo"`
+	Auth           `yaml:"auth"`
+	Customization  `yaml:"customization"`
+	Providers      `yaml:"providers"`
+	Helm           `yaml:"helm"`
+	MonitoringInfo `yaml:"monitoringInfo,omitempty"`
 }
 
 // ServingInfo holds configuration for serving HTTP.
@@ -32,6 +34,14 @@ type ServingInfo struct {
 	RequestTimeoutSeconds int64         `yaml:"requestTimeoutSeconds,omitempty"`
 }
 
+// Monitoring holds URLs for monitoring related services
+type MonitoringInfo struct {
+	AlertmanagerPublicURL string `yaml:"alertmanagerPublicURL,omitempty"`
+	GrafanaPublicURL      string `yaml:"grafanaPublicURL,omitempty"`
+	PrometheusPublicURL   string `yaml:"prometheusPublicURL,omitempty"`
+	ThanosPublicURL       string `yaml:"thanosPublicURL,omitempty"`
+}
+
 // ClusterInfo holds information the about the cluster such as master public URL and console public URL.
 type ClusterInfo struct {
 	ConsoleBaseAddress string `yaml:"consoleBaseAddress,omitempty"`
@@ -58,3 +68,12 @@ type Customization struct {
 type Providers struct {
 	StatuspageID string `yaml:"statuspageID,omitempty"`
 }
+
+type HelmChartRepo struct {
+	URL    string `yaml:"url,omitempty"`
+	CAFile string `yaml:"caFile,omitempty"`
+}
+
+type Helm struct {
+	ChartRepo HelmChartRepo `yaml:"chartRepository"`
+}
