@@ -25,10 +25,8 @@ export BRIDGE_BASE_ADDRESS="$(oc get consoles.config.openshift.io cluster -o jso
 oc apply -f ./frontend/integration-tests/data/htpasswd-secret.yaml
 oc patch oauths cluster --patch "$(cat ./frontend/integration-tests/data/patch-htpasswd.yaml)" --type=merge
 
-# Chrome Version 76.0.3809.0 (Developer Build) (64-bit)
-# get the branch base position for a specific chrmoe version using https://omahaproxy.appspot.com/
-export FORCE_CHROME_BRANCH_BASE="665006"
-export FORCE_CHROME_BRANCH_SHA256SUM="a1ae2e0950828f991119825f62c24464ab3765aa219d150a94fb782a4c66a744"
+# get the branch base position for a specific chromium version using https://omahaproxy.appspot.com/
+source ./chromium-version.sh
 
 ./test-gui.sh ${1:-e2e}
 
